% File src/library/base/man/NumericConstants.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{NumericConstants}
\alias{NumericConstants}
\alias{1L}
\alias{0x1}
\alias{1i}
\title{Numeric Constants}
\description{
  どのように \R は数値定数を構文解析するか．
}
\details{
  \R は入力中の数値定数を C99 の浮動小数点定数と極似した流儀で構文解析する．

  \code{\link{Inf}} と \code{\link{NaN}} は数値定数である(
  \code{\link{typeof}(.) "double"}).  テキスト入力(例えば 
  \code{\link{scan}} と \code{\link{as.double}})では，これらは 
大・小文字が無視され，\code{infinity} は \code{Inf} と同じとされる．
  \code{\link{NA_real_}} と \code{\link{NA_integer_}} は型 
  \code{"double"} と \code{"integer"} で欠損値を意味する．
  他のすべての数値定数は数字もしくはピリオッドで始まり，
10進数もしくは16進数で，オプションで \code{L} が後に付く．

16進数は \code{0x} か \code{0X} で始まり，
 \code{0-9 a-f A-F .} からの空でない列が続き，16進数と解釈される．2進数の指数がオプションで付く．
2進数の指数は \code{P} か \code{p} の後にオプションのプラス・マイナス符号，
そして空でない(10進法の)数字が続き，2の巾乗を意味する．従って，
 \code{0x123p456} は \eqn{291 \times 2^{456}}{291 * 2^456} となる．

10進数定数は空でない数字の列で，ピリオッド(小数点)を含む可能性があり，
オプションで10進指数が続く．10進指数は \code{E} か \code{e} の
後にオプションのプラス・マイナス符号，そして空でない
数字の列が続き，10の巾乗を意味する．

大きすぎるか小さすぎて表示不可能な値は桁溢れ \code{Inf} か桁落ち \code{0.0} する．

数値定数の直後に \code{i} が続くと虚数見做される．

数値定数の直後に \code{L} が続くと可能なら整数 
  と見做される(もし \code{"."} を含めば警告が出る)．

言語が数字の他の表現を持っていても，アスキー数字 0--9 のみが数字と見做される．
\sQuote{10進法の分離記号}は常にピリオッドで，決してカンマではない．

先頭のプラスやマイナスは構文解析では数値定数の一部とは見做されず，
定数に適用された単項演算子とされる．
}
\note{
文字列が数値定数の入力として構文解析されると，数値は使われている C の倍精度型として
正確に表現できないかもしれない．その時は表示可能な最も近い数値の一つが
返される．

\R 自体の C コードが定数を2進数に変換することに使われるので，
結果は完全な IEC 600559 算術規則を移植しているすべてのプラットフォームで
同一になると期待することが出来る(最もありそうな違いは 
 \code{\link{.Machine}$double.xmin} 以下の数である).
同じコードが \code{\link{scan}} で使われる．
}
\seealso{
  \code{\link{Syntax}}.
  複素数には \code{\link{complex}} を見よ．
  文字定数の構文解析には \code{\link{Quotes}}，
\R の予約語については \code{\link{Reserved}}．
}
\examples{
## 固定または科学的書式で数を作ることが出来る．
2.1
2.1e10
-2.1E-10

## 結果のオブジェクトは数値クラスで倍精度型．
class(2.1)
typeof(2.1)

## これは整数のようにタイプしても同じこと．
class(2)
typeof(2)

## もし本当に整数が必要なら接尾辞 "L" を使う．
class(2L)
typeof(2L)

## これらは等しいが同値ではない
2 == 2L
identical(2, 2L)

## 0と1の間の数は先頭の0無しで書いても良い
## (しかし普通これは可読性を損なう)
.1234

sqrt(1i) # 初等数学を覚えている?
utils::str(0xA0)
identical(1L, as.integer(1))

## 接頭辞 "0x" を接尾辞 "L" と一緒に使うことが出来る:
identical(0xFL, as.integer(15))
}
\keyword{documentation}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/NumericConstants.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{NumericConstants}
%\alias{NumericConstants}
%\alias{1L}
%\alias{0x1}
%\alias{1i}
%\title{Numeric Constants}
%\description{
%  How \R parses numeric constants.
%}
%\details{
%  \R parses numeric constants in its input in a very similar way to C99
%  floating-point constants.
%
%  \code{\link{Inf}} and \code{\link{NaN}} are numeric constants (with
%  \code{\link{typeof}(.) "double"}).  In text input (e.g., in
%  \code{\link{scan}} and \code{\link{as.double}}), these are recognized
%  ignoring case as is \code{infinity} as an alternative to \code{Inf}.
%  \code{\link{NA_real_}} and \code{\link{NA_integer_}} are constants of
%  types \code{"double"} and \code{"integer"} representing missing
%  values.  All other numeric constants start with a digit or period and
%  are either a decimal or hexadecimal constant optionally followed by
%  \code{L}.
%
%  Hexadecimal constants start with \code{0x} or \code{0X} followed by
%  a nonempty sequence from \code{0-9 a-f A-F .} which is interpreted as a
%  hexadecimal number, optionally followed by a binary exponent.  A binary
%  exponent consists of a \code{P} or \code{p} followed by an optional
%  plus or minus sign followed by a non-empty sequence of (decimal)
%  digits, and indicates multiplication by a power of two.  Thus
%  \code{0x123p456} is \eqn{291 \times 2^{456}}{291 * 2^456}.
%
%  Decimal constants consist of a nonempty sequence of digits possibly
%  containing a period (the decimal point), optionally followed by a
%  decimal exponent.  A decimal exponent consists of an \code{E} or
%  \code{e} followed by an optional plus or minus sign followed by a
%  non-empty sequence of digits, and indicates multiplication by a power
%  of ten.
%
%  Values which are too large or too small to be representable will
%  overflow to \code{Inf} or underflow to \code{0.0}.
%
%  A numeric constant immediately followed by \code{i} is regarded as an
%  imaginary \link{complex} number.
%
%  An numeric constant immediately followed by \code{L} is regarded as an
%  \code{\link{integer}} number when possible (and with a warning if it
%  contains a \code{"."}).
%
%  Only the ASCII digits 0--9 are recognized as digits, even in languages
%  which have other representations of digits.  The \sQuote{decimal
%    separator} is always a period and never a comma.
%
%  Note that a leading plus or minus is not regarded by the parser as
%  part of a numeric constant but as a unary operator applied to the constant.
%}
%\note{
%  When a string is parsed to input a numeric constant, the number may or
%  may not be representable exactly in the C double type used.  If not
%  one of the nearest representable numbers will be returned.
%
%  \R's own C code is used to convert constants to binary numbers, so the
%  effect can be expected to be the same on all platforms implementing
%  full IEC 600559 arithmetic (the most likely area of difference being
%  the handling of numbers less than \code{\link{.Machine}$double.xmin}).
%  The same code is used by \code{\link{scan}}.
%}
%\seealso{
%  \code{\link{Syntax}}.
%  For complex numbers, see \code{\link{complex}}.
%  \code{\link{Quotes}} for the parsing of character constants,
%  \code{\link{Reserved}} for the \dQuote{reserved words} in \R{}.
%}
%\examples{
%## You can create numbers using fixed or scientific formatting.
%2.1
%2.1e10
%-2.1E-10
%
%## The resulting objects have class numeric and type double.
%class(2.1)
%typeof(2.1)
%
%## This holds even if what you typed looked like an integer.
%class(2)
%typeof(2)
%
%## If you actually wanted integers, use an "L" suffix.
%class(2L)
%typeof(2L)
%
%## These are equal but not identical
%2 == 2L
%identical(2, 2L)
%
%## You can write numbers between 0 and 1 without a leading "0"
%## (but typically this makes code harder to read)
%.1234
%
%sqrt(1i) # remember elementary math?
%utils::str(0xA0)
%identical(1L, as.integer(1))
%
%## You can combine the "0x" prefix with the "L" suffix :
%identical(0xFL, as.integer(15))
%}
%\keyword{documentation}
%
\encoding{UTF8}
