% File src/library/base/man/Platform.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{.Platform}
\title{Platform Specific Variables}
\usage{
.Platform
}
\alias{.Platform}
\description{
  \code{.Platform} は \R が構築されたプラットフォームの幾つかの詳細の
リストである．これはOSが異なっても動作する \R コードを書く手段を提供する．
}
\value{
  少なくとも以下の成分を持つリスト：

  \item{OS.type}{
    文字列で計算機のOS(ファミリ)を与える．
    \code{"unix"} か \code{"windows"} の一つ．
  }
  \item{file.sep}{
    文字列で，プラットフォームで使用するファイル分離記号を与える：
    ユニックス風システムとWindowsでは \code{"/"} (しかし Classic Mac OS の
以前の移植ではそうではなかった)．
  }
  \item{dynlib.ext}{
文字列で，動的に読み込めるライブラリのファイル名拡張子を与える．
例えば，Windows では \code{".dll"} でユニックス風OSでは \code{".sl"}．
(OS X ユーザへの注意：これらは \code{\link{dyn.load}} で読み込まれる共有
オブジェクトで，dynlib ではない：\code{\link{dyn.load}} を見よ．)
  }
  \item{GUI}{
文字列で，使用される GUI のタイプを与える．GUI が仮定できない場合は \code{"unknown"}．
ユニックス風システムでの可能な値はオプション \option{-g} のコマンドラインフラグで与えられる
値(\code{"X11"}, \code{"Tk"}), \code{"AQUA"} (OS X の \code{R.app} 下で稼働の場合)，
 \code{"Rgui"} と \code{"RTerm"} (Windows)，そして別のフロントエンドや埋め込み \R では
恐らく別のもの．
  }
  \item{endian}{
文字列 \code{"big"} か \code{"little"} で，使用中のプロセッサの 
    \sQuote{エンディアン} を与える．これはバイトの読み書きの順序を
知るために必要になる．例えばコネクションから/への整数や倍精度実数．
 \code{\link{readBin}} を見よ．
  }
  \item{pkgType}{
文字列で \code{\link{options}("pkgType")} の好ましい設定を与える．
値 \code{"source"}, \code{"mac.binary"}, \code{"mac.binary.mavericks"} そして 
 \code{"win.binary"} が現在使われている．

    これは OS の特定に使ってはならない．
  }
  \item{path.sep}{
文字列でプラットフォームで使われるパスの分離器号を与える．
例えば，ユニックス風システムでは \code{":"} で Windows では 
    \code{";"}．\code{PATH} や \code{TEXINPUTS} といった環境変数中で
パスを分離するのに使われる．
  }
  \item{r_arch}{
文字列で，\code{""} の可能性もある．\R の構築で使われた
アーキテクチャ固有のディレクトリ．
  }
}

\section{AQUA}{
OS X GUI の  \code{R.app} の下では \code{.Platform$GUI} は \code{"AQUA"} に設定される．
これは幾つかの結論を持つ：
  \itemize{
%%     \item the \env{DISPLAY} environment variable is set to \code{":0"}
%%     if unset. (However, it will be set on a machine which has
%%     XQuartz installed.)
    \item \file{/usr/local/bin} は \env{PATH} 環境変数に追加される．
    \item 既定のグラフィックスデバイスは \code{quartz} に設定される．
    \item \code{\link{menu}} と \code{\link{select.list}} の
 \code{graphics = TRUE} オプションに対してネイティブの(Tk ではなく)ウィジェットを
選択する．
    \item HTML ヘルプは内部ブラウザに表示される．
    \item 表計算ソフト風のデータエディタ/ビューアは X11 では無く Quartz 版を使う．
  }
}
\seealso{
  \code{\link{R.version}} と \code{\link{Sys.info}} は OS に関する
より詳細を与える．特に，\code{R.version$platform} は \R がコンパイルされた
プラットフォームの標準的名称を与える．

使用される算術の詳細については \code{\link{.Machine}} を見よ．
プラットフォーム固有のシステム命令の起動には 
  \code{\link{system}}．
}

\examples{
## 注意：これは dir.exists() によりシステムに依存しない仕方で行える
if(.Platform$OS.type == "unix") {
   system.test <- function(...) system(paste("test", ...)) == 0L
   dir.exists2 <- function(dir)
       sapply(dir, function(d) system.test("-d", d))
   dir.exists2(c(R.home(), "/tmp", "~", "/NO")) # > T T T F
}
}
\keyword{file}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Platform.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{.Platform}
%\title{Platform Specific Variables}
%\usage{
%.Platform
%}
%\alias{.Platform}
%\description{
%  \code{.Platform} is a list with some details of the platform under
%  which \R was built.  This provides means to write OS-portable \R
%  code.
%}
%\value{
%  A list with at least the following components:
%
%  \item{OS.type}{
%    character string, giving the \bold{O}perating \bold{S}ystem
%    (family) of the computer.  One of \code{"unix"} or \code{"windows"}.
%  }
%  \item{file.sep}{
%    character string, giving the \bold{file} \bold{sep}arator used on your
%    platform: \code{"/"} on both Unix-alikes \emph{and} on Windows (but
%    not on the former port to Classic Mac OS).
%  }
%  \item{dynlib.ext}{
%    character string, giving the file name \bold{ext}ension of
%    \bold{dyn}amically loadable \bold{lib}raries, e.g., \code{".dll"} on
%    Windows and \code{".so"} or \code{".sl"} on Unix-alikes.  (Note for
%    OS X users: these are shared objects as loaded by
%    \code{\link{dyn.load}} and not dylibs: see \code{\link{dyn.load}}.)
%  }
%  \item{GUI}{
%    character string, giving the type of GUI in use, or \code{"unknown"}
%    if no GUI can be assumed.  Possible values are for Unix-alikes the
%    values given via the \option{-g} command-line flag (\code{"X11"},
%    \code{"Tk"}), \code{"AQUA"} (running under \code{R.app} on OS X),
%    \code{"Rgui"} and \code{"RTerm"} (Windows) and perhaps others under
%    alternative front-ends or embedded \R.
%  }
%  \item{endian}{
%    character string, \code{"big"} or \code{"little"}, giving the
%    \sQuote{endianness} of the processor in use.  This is relevant when it is
%    necessary to know the order to read/write bytes of e.g.\sspace{}an
%    integer or double from/to a \link{connection}: see
%    \code{\link{readBin}}.
%  }
%  \item{pkgType}{
%    character string, the preferred setting for
%    \code{\link{options}("pkgType")}.  Values \code{"source"},
%    \code{"mac.binary"}, \code{"mac.binary.mavericks"} and
%    \code{"win.binary"} are currently in use.
%
%    This should \strong{not} be used to identify the OS.
%  }
%  \item{path.sep}{
%    character string, giving the \bold{path} \bold{sep}arator,
%    used on your platform, e.g., \code{":"} on Unix-alikes and
%    \code{";"} on Windows.  Used to separate paths in environment
%    variables such as \code{PATH} and \code{TEXINPUTS}.
%  }
%  \item{r_arch}{
%    character string, possibly \code{""}.  The name of an
%    architecture-specific directory used in this build of \R.
%  }
%}
%
%\section{AQUA}{
%  \code{.Platform$GUI} is set to \code{"AQUA"} under the OS X GUI,
%  \code{R.app}. This has a number of consequences:
%  \itemize{
%%%     \item the \env{DISPLAY} environment variable is set to \code{":0"}
%%%     if unset. (However, it will be set on a machine which has
%%%     XQuartz installed.)
%    \item \file{/usr/local/bin} is \emph{appended} to the \env{PATH}
%    environment variable.
%    \item the default graphics device is set to \code{quartz}.
%    \item selects native (rather than Tk) widgets for the \code{graphics
%      = TRUE} options of \code{\link{menu}} and \code{\link{select.list}}.
%    \item HTML help is displayed in the internal browser.
%    \item the spreadsheet-like data editor/viewer uses a Quartz version
%    rather than the X11 one.
%  }
%}
%\seealso{
%  \code{\link{R.version}} and \code{\link{Sys.info}} give more details
%  about the OS.  In particular, \code{R.version$platform} is the
%  canonical name of the platform under which \R was compiled.
%
%  \code{\link{.Machine}} for details of the arithmetic used, and
%  \code{\link{system}} for invoking platform-specific system commands.
%}
%
%\examples{
%## Note: this can be done in a system-independent way by dir.exists()
%if(.Platform$OS.type == "unix") {
%   system.test <- function(...) system(paste("test", ...)) == 0L
%   dir.exists2 <- function(dir)
%       sapply(dir, function(d) system.test("-d", d))
%   dir.exists2(c(R.home(), "/tmp", "~", "/NO")) # > T T T F
%}
%}
%\keyword{file}
%\keyword{utilities}
%

\encoding{UTF8}
