% File src/library/base/man/Sys.sleep.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{Sys.sleep}
\alias{Sys.sleep}
\title{Suspend Execution for a Time Interval}
\description{
  指定された時間の間 \R の表現式の実行を中断する．
}
\usage{
Sys.sleep(time)
}
\arguments{
  \item{time}{実行を中断する時間間隔，秒単位．}
}
\details{
  この関数を使うと \R は一時的に非常に低い優先度を
与えられ，従ってより重要なおもての作業の邪魔をしない．
典型的な用法は \R から派生したプロセスが立ち上がり，
\R の実行が再開する前にその入力ファイルを読み込むのを許すことである．

意図していることはこの関数は \R 表現式の実行を中断するが，
プロセスが GUI のイベントに反応するのにしばしば十分なだけ
覚醒させておくことである．典型的には半秒毎．
これは停止させることが出来る(例えば \R コンソールに
\samp{Ctrl-C} や \samp{Esc} を入力する)．

プロセスが指定された間隔全部で中断待機する保証はなく
(待機は中断されるかもしれない)，実行を再開するためには実時間で多少
長くかかるかもしれない．

\code{time} は非負でなければならず(そして \code{NA} でも
 \code{NaN} でもいけない)；
 \code{Inf} は許される(中断までいつまでも待機するつもりなら適当かもしれない)．
時間間隔の解像度はシステム依存であるが，普通 20ms かそれ以下である．
(最近の Unix 風システムでは 1ms 以下である．)
}
\value{
  不可視の \code{NULL}．
}
\note{
  名前にかかわらず，これは現在 \code{sleep} システムコールを使っていない
(Windows では \code{Sleep} を使っている)．
}

\examples{\donttest{
testit <- function(x)
{
    p1 <- proc.time()
    Sys.sleep(x)
    proc.time() - p1 # cpu 使用時間は無視できるはず
}
testit(3.7)
}}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Sys.sleep.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Sys.sleep}
%\alias{Sys.sleep}
%\title{Suspend Execution for a Time Interval}
%\description{
%  Suspend execution of \R expressions for a specified time interval.
%}
%\usage{
%Sys.sleep(time)
%}
%\arguments{
%  \item{time}{The time interval to suspend execution for, in seconds.}
%}
%\details{
%  Using this function allows \R to temporarily be given very low
%  priority and hence not to interfere with more important foreground
%  tasks.  A typical use is to allow a process launched from \R to set
%  itself up and read its input files before \R execution is resumed.
%
%  The intention is that this function suspends execution of \R
%  expressions but wakes the process up often enough to respond to GUI
%  events, typically every half second.  It can be interrupted
%  (e.g.\sspace{}by \samp{Ctrl-C} or \samp{Esc} at the \R console).
%
%  There is no guarantee that the process will sleep for the whole of the
%  specified interval (sleep might be interrupted), and it may well take
%  slightly longer in real time to resume execution.
%
%  \code{time} must be non-negative (and not \code{NA} nor \code{NaN}):
%  \code{Inf} is allowed (and might be appropriate if the intention is to
%  wait indefinitely for an interrupt).  The resolution of the time
%  interval is system-dependent, but will normally be 20ms or better.
%  (On modern Unix-alikes it will be better than 1ms.)
%}
%\value{
%  Invisible \code{NULL}.
%}
%\note{
%  Despite its name, this is not currently implemented using the
%  \code{sleep} system call (although on Windows it does make use of
%  \code{Sleep}).
%}
%
%\examples{\donttest{
%testit <- function(x)
%{
%    p1 <- proc.time()
%    Sys.sleep(x)
%    proc.time() - p1 # The cpu usage should be negligible
%}
%testit(3.7)
%}}
%\keyword{utilities}
%
\encoding{UTF8}
