% File src/library/base/man/Version.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{R.Version}
\title{Version Information}
\alias{R.Version}
\alias{R.version}
\alias{version}
\alias{R.version.string}
\usage{
R.Version()
R.version
R.version.string
version
}
\description{
  \code{R.Version()} は稼働中の \R のバージョンに関する詳細な情報を与える．

  \code{R.version} はこの情報を保持するリスト変数である
(そして \code{version} はそのコピーで S との互換性のため存在する)．
}
\value{
 \code{R.Version} は以下の文字列成分を持つリストを返す
 \item{platform}{\R が構築されたプラットフォーム．CPU-VENDOR-OS の
形の三組でコンフィギュアスクリプトにより決定される．例えば 
 \code{"i686-unknown-linux-gnu"} や \code{"i386-pc-mingw32"}．
 }
  \item{arch}{\R が構築された，または目的のアーキテクチャ (CPU)．}
  \item{os}{基礎にあるオペレーティング・システム．}
  \item{system}{CPU と OS，コンマで仕切られる．}
  \item{status}{バージョンのステータス(例えば \code{"alpha"})}
  \item{major}{主バージョン数}
  \item{minor}{副バージョン数，パッチレベルを含む}
  \item{year}{バージョンが作られた年}
  \item{month}{バージョンがリリースされた月}
  \item{day}{バージョンがリリースされた日}
  \item{svn rev}{副バージョンの改定数，\code{"unknown"} か一つの数
でなければならない．(数の範囲や，\samp{M} または \samp{S} がついた数はこの \R を
構築したソースが一貫していないことを指示する．)
  }
  \item{language}{常に \code{"R"}．}
  \item{version.string}{上の情報を連結した文字列で，プロット等に有用．}

  \code{R.version} と \code{version} は \code{print} メソッドを持つクラス 
 \code{"simple.list"} のリスト．
}
\note{
  \code{R.version$os} をコードを実行中のプラットフォームのテストのために
使わないこと．代わりに \code{.Platform$OS.type} を使う．OS が少々異なれば，
\R のバージョンが異なった時のように，異なった \code{R.version$os} の値を報告するかもしれない．

  \code{R.version.string} は単純化と後方互換性のための \code{R.version$version.string} 
のコピーである．
}
\details{
  これは \R が構築された OS の詳細を与え，現在それが稼働している OS の
ものではない(そのためには \code{\link{Sys.info}} を見よ)．

OS 名は期待されるものと異なるかもしれない：例えば
OS X Mavericks 10.9.4 は自分を \samp{darwin13.3.0} と識別し，Linux は
普通 \samp{linux-gnu}，そして Solaris 10 は \samp{solaris2.10} になる．
}
\seealso{
  追加情報は \code{\link{sessionInfo}}；
  典型的に R コードの内部で使われる \code{\link{getRversion}}, 
  \code{\link{.Platform}}, \code{\link{Sys.info}}．
}
\examples{
require(graphics)

R.version$os # 自分がどれだけ幸運かチェックするため...
plot(0) # 任意のプロット
mtext(R.version.string, side = 1, line = 4, adj = 1) # 有用な右下のノート

## OS X を検出する良い方法:
if(grepl("^darwin", R.version$os)) message("running on OS X")
}
\keyword{environment}
\keyword{sysdata}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%% File src/library/base/man/Version.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{R.Version}
%\title{Version Information}
%\alias{R.Version}
%\alias{R.version}
%\alias{version}
%\alias{R.version.string}
%\usage{
%R.Version()
%R.version
%R.version.string
%version
%}
%\description{
%  \code{R.Version()} provides detailed information about the version of
%  \R running.
%
%  \code{R.version} is a variable (a \code{\link{list}}) holding this
%  information (and \code{version} is a copy of it for S compatibility).
%}
%\value{
% \code{R.Version} returns a list with character-string components
% \item{platform}{the platform for which \R was built.  A triplet of the
%   form CPU-VENDOR-OS, as determined by the configure script.  E.g,
%   \code{"i686-unknown-linux-gnu"} or \code{"i386-pc-mingw32"}.
% }
%  \item{arch}{the architecture (CPU) \R was built on/for.}
%  \item{os}{the underlying operating system.}
%  \item{system}{CPU and OS, separated by a comma.}
%  \item{status}{the status of the version (e.g., \code{"alpha"})}
%  \item{major}{the major version number}
%  \item{minor}{the minor version number, including the patchlevel}
%  \item{year}{the year the version was released}
%  \item{month}{the month the version was released}
%  \item{day}{the day the version was released}
%  \item{svn rev}{the Subversion revision number, which should be either
%    \code{"unknown"} or a single number. (A range of numbers or a number
%    with \samp{M} or \samp{S} appended indicates inconsistencies in the
%    sources used to build this version of \R.)
%  }
%  \item{language}{always \code{"R"}.}
%  \item{version.string}{a
%    \code{\link{character}} string concatenating some of the info above,
%    useful for plotting, etc.}
%
%  \code{R.version} and \code{version} are lists of class
%  \code{"simple.list"} which has a \code{print} method.
%}
%\note{
%  Do \emph{not} use \code{R.version$os} to test the platform the
%  code is running on: use \code{.Platform$OS.type} instead.  Slightly
%  different versions of the OS may report different values of
%  \code{R.version$os}, as may different versions of \R.
%
%  \code{R.version.string} is a copy of \code{R.version$version.string}
%  for simplicity and backwards compatibility.
%}
%\details{
%  This gives details of the OS under which \R was built, not the one
%  under which it is currently running (for which see
%  \code{\link{Sys.info}}).
%
%  Note that OS names might not be what you expect: for example OS X
%  Mavericks 10.9.4 identifies itself as \samp{darwin13.3.0}, Linux
%  usually as \samp{linux-gnu} and Solaris 10 as \samp{solaris2.10}.
%}
%\seealso{
%  \code{\link{sessionInfo}} which provides additional information;
%  \code{\link{getRversion}} typically used inside R code,
%  \code{\link{.Platform}}, \code{\link{Sys.info}}.
%}
%\examples{
%require(graphics)
%
%R.version$os # to check how lucky you are ...
%plot(0) # any plot
%mtext(R.version.string, side = 1, line = 4, adj = 1) # a useful bottom-right note
%
%## a good way to detect OS X:
%if(grepl("^darwin", R.version$os)) message("running on OS X")
%}
%\keyword{environment}
%\keyword{sysdata}
%\keyword{programming}
%
\encoding{UTF8}
