% File src/library/base/man/as.function.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{as.function}
\title{Convert Object to Function}
\usage{
as.function(x, \dots)

\method{as.function}{default}(x, envir = parent.frame(), \dots)
}
\alias{as.function}
\alias{as.function.default}
\arguments{
  \item{x}{変換されるオブジェクト，既定メソッドに対してはリスト．}
  \item{\dots}{追加引数，オブジェクトによる．}

  \item{envir}{関数が定義されるべき環境．}
}
\description{
  \code{as.function} は総称的関数でオブジェクトを関数に変換するために使われる．

  \code{as.function.default} はリスト \code{x} に作用し，形式的引数リスト
を連結したものと，表現式か関数本体になるモード \code{"\link{call}"} の
オブジェクトを含む．
関数は指定された環境中に定義され，既定では呼び出し環境である．
}
\note{
  歴史的理由から \code{envir = NULL} は基礎環境ではなく大局的環境を使う．
 \code{NULL} の特別な処理は将来変更される可能性があるので，もしこれが
希望するものなら代わりに \code{envir = \link{globalenv}()} をつかってほしい．
}
\value{
  希望する関数．
}
\author{Peter Dalgaard}
\seealso{
  \code{\link{function}};
  \code{\link{alist}} は引数リスト等を構成するのに便利である．
}
\examples{
as.function(alist(a = , b = 2, a+b))
as.function(alist(a = , b = 2, a+b))(3)
}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/as.function.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{as.function}
%\title{Convert Object to Function}
%\usage{
%as.function(x, \dots)
%
%\method{as.function}{default}(x, envir = parent.frame(), \dots)
%}
%\alias{as.function}
%\alias{as.function.default}
%\arguments{
%  \item{x}{object to convert, a list for the default method.}
%  \item{\dots}{additional arguments, depending on object}
%
%  \item{envir}{environment in which the function should be defined}
%}
%\description{
%  \code{as.function} is a generic function which is used to convert
%  objects to functions.
%
%  \code{as.function.default} works on a list \code{x}, which should contain the
%  concatenation of a formal argument list and an expression or an
%  object of mode \code{"\link{call}"} which will become the function body.
%  The function will be defined in a specified environment, by default
%  that of the caller.
%}
%\note{
%  For ancient historical reasons, \code{envir = NULL} uses the global
%  environment rather than the base environment.
%  Please use \code{envir = \link{globalenv}()} instead if this is what you want,
%  as the special handling of \code{NULL} may change in a future release.
%}
%\value{
%  The desired function.
%}
%\author{Peter Dalgaard}
%\seealso{
%  \code{\link{function}};
%  \code{\link{alist}} which is handy for the construction of
%  argument lists, etc.
%}
%\examples{
%as.function(alist(a = , b = 2, a+b))
%as.function(alist(a = , b = 2, a+b))(3)
%}
%\keyword{programming}
%
\encoding{UTF8}
