% File src/library/base/man/files.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{files}
\alias{files}
\alias{file.append}
\alias{file.copy}
\alias{file.create}
\alias{file.exists}
\alias{file.remove}
\alias{file.rename}
\alias{file.symlink}
\alias{file.link}
#ifdef windows
\alias{Sys.junction}
#endif

\title{File Manipulation}
\usage{
file.create(\dots, showWarnings = TRUE)
file.exists(\dots)
file.remove(\dots)
file.rename(from, to)
file.append(file1, file2)
file.copy(from, to, overwrite = recursive, recursive = FALSE,
          copy.mode = TRUE, copy.date = FALSE)
file.symlink(from, to)
file.link(from, to)
#ifdef windows
Sys.junction(from, to)
#endif
}
\arguments{
  \item{\dots, file1, file2}{文字列ベクトル．ファイル名やパスを含む．}
  \item{from, to}{文字列ベクトル．ファイル名やパスを含む．
    \code{file.copy} と \code{file.symlink} 
#ifdef windows
    そして \code{Sys.junction}
#endif
    用． \code{to} はまた単一の既存ディレクトリへのパスでも良い．}
  \item{overwrite}{論理値；既存の目標ファイルを上書きすべきか?}
  \item{showWarnings}{論理値．失敗時に警告を示すべきか?}
  \item{recursive}{論理値．もし \code{to} がディレクトリならば，
    \code{from} 中のディレクトリ(とその内容)をコピーすべきか?
    (POSIX OS の \command{cp -R} のように．)}
  \item{copy.mode}{論理値．可能ならばファイルのパーミッションビットをコピーすべきか?}
  \item{copy.date}{論理値．可能ならばファイルの時刻を保存すべきか?
    \code{\link{Sys.setFileTime}} を見よ．}
}
\description{
  これらの関数は計算機のファイルシステムへの低水準インタフェイスを提供する．
}
\details{
  \code{\dots} 引数は一つの文字列に連結される：
  ファイルを別々にまた一つのベクトルで指定できる．
  これらのすべての関数はパス名を展開する： \code{\link{path.expand}} を見よ．

  \code{file.create} はもしそれが存在しなければ与えられた名前からファイルを作り，
  そしてもし存在すればそれらを切り捨てる．
  それらは \sQuote{\link{umask}} の設定(関係すれば)が許す最大の読み取り/書き込み
  パーミッションで作成される．既定ではもし操作が失敗すれば(理由と共に)警告が出る．

  \code{file.exists} はその引数の名前を持つファイルが存在するかどうかを示す
  論理値を返す．(ここで\sQuote{存在}はシステムの \code{stat} 呼び出しの
  意味である：ファイルは \code{stat} が必要とするパーミッションをあなたが
  持つときに限り存在すると報告される．
  存在はまた \code{\link{file.access}} でもチェック出来る：これは
  異なったパーミッションを使うかもしれず，従って異なった結果を得るかもしれない．
  ファイルの存在はそれが読み取り可能であることを意味しない：
  そのためには \code{\link{file.access}} を使う．)  何がファイルを構成するかは
  システム依存であるが，ディレクトリを含むべきである．
  (しかしながら WIndows ではディレクトリ名は末尾のバックスラッシュやスラッシュを
  含むべきではない．)  Unix 風システムではもしファイルがシンボリックリンクならば，
  結果はリンク先が実際のファイルかどうかを示し，単にリンクが存在するかどうかではない．
  最後に，\R オブジェクの存在をチェックする別の関数 \code{\link{exists}} を注意しよう．

  \code{file.remove} はその引数中の名前を持つファイルを削除しようと試みる．
  殆どの Unix プラットフォームでは\sQuote{ファイル}は空のディレクトリ，
  シンボリックリンク，fifo そしてソケットを除外する．
  Windows では\sQuote{ファイル}は正規のファイルを意味し，例えば空のディレクトリを
  含まない．

  \code{file.rename} はファイルの名前を変更しようとする(そして \code{from} と
  \code{to} は同じ長さでなければならない)．ファイルのパーミッションが許せば，
  これは \code{to} の既存の要素を上書きする．これは OS の対応するシステムコール
  の制限，特に\sQuote{ファイル}の解釈，に依存する(Unix 風システムの
  \command{man 2 rename} のようなものを見よ)：殆どのプラットフォームはファイルシステム
  を跨がったファイルを改名しない．(Windows では \code{file.rename} は
  ファイルを移動するがボリュム間のディレクトリの移動はしない．)  ディレクトリの改名を
  許すプラットフォーム上では，典型的に \code{from} と \code{to} の双方が
  ディレクトリか，もしくはどちらもディレクトリであってはならず，そしてもし
  \code{to} が存在すればそれは空のディレクトリでなければならない．

  \code{file.append} はその第二引数の名前を持つファイルを第一引数の名前を持つ
  それらに付加する．異なった長さのベクトル中で与えられた名前の整列のため
  \R の添字リサイクル規則が使われる．

  \code{file.copy} は \code{file.append} と同じように動作するが，
  引数はコピーに対する自然な順序を持つ．
  既存の目標ファイルは \code{overwrite = TRUE} で無い限りスキップされる．
  \code{to} 引数は単一の既存ディレクトリを指定できる．もし
  \code{copy.mode = TRUE} ならばファイルの読み取り/書き込みパーミッションは可能ならば
  コピーされるが \sQuote{\link{umask}} で制限される．(Windows ではこれは
  ファイルにだけ適用される． ALC 等の他のセキュリティ属性はコピーされない．
  POSIX ファイルシステムではリンク自体ではなくシンボリックリンクの目標が
  コピーされ，ハードリンクは別個にコピーされる．

  \code{file.symlink} と \code{file.link} はそれらをサポートするファイルシステム
  上でシンボリックリンクとハードリンクを作る．
  \code{file.symlink} に対しては \code{to} 引数は単一の既存ディレクトリを
  指定できる．Windows は NTFS ファイルシステム上でハードリンクを持ち，
  最近のバージョンではシンボリックリンクに関連した概念がある：
  下のこのヘルプ頁の Windows バージョンの節を見よ．
  FAT や SMB でマウントされたファイルシステムでどうなるかは OS 固有である．)
}

\value{
  これらの関数は試みられた各ファイル毎にどの操作が成功したかを示す論理値ベクトルを返す．
  ファイルやパス名に欠損値を使うことは常に失敗と見做される．

  もし \code{showWarnings = TRUE} ならば \code{file.create} は予期せぬ失敗に対して警告を出す．
}

\section{大・小文字を区別しないファイルシステム}{
  大・小文字を区別しないファイルシステムは Windows と OS X では規範であるが，
  すべての OS で見受けられる(例えば FAT でフォーマットされた USB ドライブは
  恐らく大・小文字を区別しない)．

  これらの関数はそうしたファイルシステム上で存在するファイルを大・小文字を区別せずにマッチする
  ことがもっとありそうである：しかしながらこれは OS の機能であり，
  ファイル名を大・小文字にマップすることは可能である．
}

#ifdef windows
\note{
  これらの関数が Windows の \file{d:path} の形の相対パスを処理する保証はない:
  代わりに \file{d:./path} を使おう．
  特に \file{d:} はディレクトリとして認識されない．
  同じく \samp{\\\\?\\} 接頭語(そして類似物)はサポートされない．

  これらの関数の多くは現在のロケールで不正な UTF-8 ファイルパスを受け入れる．

  不正なファイル名を与える(そして \file{foo/} と
  \file{foo\\} は Windows では不正であることを注意)ことは未定義の結果をもたらす．
}

\section{Windows でのシンボリックリンク}{
  POSIX ファイルシステムの意味でのシンボリックリンクは Windows では存在しない：
  しかしながら NTFS ファイルシステムは二種類の類似した概念をサポートしている．

  Windows 2000 とその後継は\sQuote{ジャンクション} (又は \sQuote{ジャンクションポイント})
  を持つが，不幸にも公開された API を持たない．これらは Unix の一つのディレクトリを
  他のディレクトリにマウントするという概念の Windows バージョンである．
  ジャンクションを作り，リストし，そして削除する一つの方法は
  \url{https://download.sysinternals.com/files/Junction.zip}
  (\url{https://technet.microsoft.com/en-us/sysinternals/bb896768} を見よ)
  \file{junction.exe} を経由することである．
  ごく最近の Windows の \command{mklink /J} のバージョンがまた使える．
  関数 \code{Sys.junction} は一つもしくはそれ以上のジャンクションを作る：
  \code{to} は単一の既存ディレクトリか，または
  \code{to} と同じ長さの非存在ファイルパスの集合を指定すべきである．

  ファイル/ディレクトリへのシンボリックリンクのバージョンが Vista 以来実装され，
  \code{file.symlink} はこのインタフェイスを利用する．しかしながらこれは
  本来の機能を失わせるほどの制限を持つ(OS バージョンの制限を別としても)．
  最初にユーザはシンボリックリンクを作るためにパーミッションを必要とし，
  パーミッションは普通管理者アカウントを除いて与えられない
  (注意：管理者権をもつユーザではない)：更に多くのユーザは Policy Editor が
  そうした権利を認めているように見える場合にも API は依然として不十分な
  パーミッションを報告する．ふたつ目にインタフェイスは 
  \code{from} がファイルかディレクトリかを知る必要がある(そしてそれは未だ
  存在しない必要がある)：我々はこれをディレクトリからのリンクがそれが既に
  存在する時にだけ許すように実装した．
  \R 3.0.3 以前ではパスはバックスラッシュを使う必要があった
  (Windows システムコールの文章化されていない制限)．

  ジャンクション(そしてほとんど確実にシンボリックリンク)を除去する際には
  注意がいる；多くのツールは目標とその中身を削除する
  (XP 中の Windows Explorer，そして 2.15.0 以前の \R 中の \code{unlink}
  を含む)．
}
#endif

\author{
  Ross Ihaka, Brian Ripley
}
\seealso{
  \code{\link{file.info}}, \code{\link{file.access}}, \code{\link{file.path}},
  \code{\link{file.show}}, \code{\link{list.files}},
  \code{\link{unlink}}, \code{\link{basename}},\cr
  \code{\link{path.expand}}.

  \code{\link{dir.create}}.

  ファイル指定中のワイルドカードの展開には \code{\link{Sys.glob}}．

  \code{\link{file_test}}, \code{\link{Sys.readlink}}.

  リンクとそれらの制限については \url{https://en.wikipedia.org/wiki/Hard_link} と
  \url{https://en.wikipedia.org/wiki/Symbolic_link}．
}

\examples{
cat("file A\n", file = "A")
cat("file B\n", file = "B")
file.append("A", "B")
file.create("A")
file.append("A", rep("B", 10))
if(interactive()) file.show("A")
file.copy("A", "C")
dir.create("tmp")
file.copy(c("A", "B"), "tmp")
list.files("tmp")
#ifdef unix
setwd("tmp")
file.remove("B")
file.symlink(file.path("..", c("A", "B")), ".")
setwd("..")
#endif
unlink("tmp", recursive = TRUE)
file.remove("A", "B", "C")
}
\keyword{file}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/files.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{files}
%\alias{files}
%\alias{file.append}
%\alias{file.copy}
%\alias{file.create}
%\alias{file.exists}
%\alias{file.remove}
%\alias{file.rename}
%\alias{file.symlink}
%\alias{file.link}
%#ifdef windows
%\alias{Sys.junction}
%#endif
%
%\title{File Manipulation}
%\usage{
%file.create(\dots, showWarnings = TRUE)
%file.exists(\dots)
%file.remove(\dots)
%file.rename(from, to)
%file.append(file1, file2)
%file.copy(from, to, overwrite = recursive, recursive = FALSE,
%          copy.mode = TRUE, copy.date = FALSE)
%file.symlink(from, to)
%file.link(from, to)
%#ifdef windows
%Sys.junction(from, to)
%#endif
%}
%\arguments{
%  \item{\dots, file1, file2}{character vectors, containing file names or paths.}
%  \item{from, to}{character vectors, containing file names or paths.
%    For \code{file.copy} and \code{file.symlink}
%#ifdef windows
%    and \code{Sys.junction}
%#endif
%    \code{to} can alternatively be the path to a single existing directory.}
%  \item{overwrite}{logical; should existing destination files be overwritten?}
%  \item{showWarnings}{logical; should the warnings on failure be shown?}
%  \item{recursive}{logical.  If \code{to} is a directory, should
%    directories in \code{from} be copied (and their contents)?  (Like
%    \command{cp -R} on POSIX OSes.)}
%  \item{copy.mode}{logical:  should file permission bits be copied where
%    possible?}
%  \item{copy.date}{logical:  should file dates be preserved where
%    possible? See \code{\link{Sys.setFileTime}}.}
%}
%\description{
%  These functions provide a low-level interface to the computer's
%  file system.
%}
%\details{
%  The \code{\dots} arguments are concatenated to form one character
%  string: you can specify the files separately or as one vector.
%  All of these functions expand path names: see \code{\link{path.expand}}.
%
%  \code{file.create} creates files with the given names if they do not
%  already exist and truncates them if they do.  They are created with
%  the maximal read/write permissions allowed by the
%  \sQuote{\link{umask}} setting (where relevant).  By default a warning
%  is given (with the reason) if the operation fails.
%
%  \code{file.exists} returns a logical vector indicating whether the
%  files named by its argument exist.  (Here \sQuote{exists} is in the
%  sense of the system's \code{stat} call: a file will be reported as
%  existing only if you have the permissions needed by \code{stat}.
%  Existence can also be checked by \code{\link{file.access}}, which
%  might use different permissions and so obtain a different result.
%  Note that the existence of a file does not imply that it is readable:
%  for that use \code{\link{file.access}}.)  What constitutes a
%  \sQuote{file} is system-dependent, but should include directories.
%  (However, directory names must not include a trailing backslash or
%  slash on Windows.)  Note that if the file is a symbolic link on a
%  Unix-alike, the result indicates if the link points to an actual file,
%  not just if the link exists.
%  Lastly, note the \emph{different} function \code{\link{exists}} which
%  checks for existence of \R objects.
%
%  \code{file.remove} attempts to remove the files named in its argument.
%  On most Unix platforms \sQuote{file} includes \emph{empty}
%  directories, symbolic links, fifos and sockets.  On Windows,
%  \sQuote{file} means a regular file and not, say, an empty directory.
%
%  \code{file.rename} attempts to rename files (and \code{from} and
%  \code{to} must be of the same length).  Where file permissions allow
%  this will overwrite an existing element of \code{to}.  This is subject
%  to the limitations of the OS's corresponding system call (see
%  something like \command{man 2 rename} on a Unix-alike): in particular
%  in the interpretation of \sQuote{file}: most platforms will not rename
%  files across file systems.  (On Windows, \code{file.rename} can move
%  files but not directories between volumes.)  On platforms which allow
%  directories to be renamed, typically neither or both of \code{from}
%  and \code{to} must a directory, and if \code{to} exists it must be an
%  empty directory.
%
%  \code{file.append} attempts to append the files named by its
%  second argument to those named by its first.  The \R subscript
%  recycling rule is used to align names given in vectors
%  of different lengths.
%
%  \code{file.copy} works in a similar way to \code{file.append} but with
%  the arguments in the natural order for copying.  Copying to existing
%  destination files is skipped unless \code{overwrite = TRUE}.  The
%  \code{to} argument can specify a single existing directory.  If
%  \code{copy.mode = TRUE} file read/write/execute permissions are copied
%  where possible, restricted by \sQuote{\link{umask}}.  (On Windows this
%  applies only to files.) Other security attributes such as ACLs are not
%  copied.  On a POSIX filesystem the targets of symbolic links will be
%  copied rather than the links themselves, and hard links are copied
%  separately.
%
%  \code{file.symlink} and \code{file.link} make symbolic and hard links
%  on those file systems which support them.  For \code{file.symlink} the
%  \code{to} argument can specify a single existing directory.  (Unix and
%  OS X native filesystems support both.  Windows has hard links to
%  files on NTFS file systems and concepts related to symbolic links on
%  recent versions: see the section below on the Windows version of this
%  help page.  What happens on a FAT or SMB-mounted file system is OS-specific.)
%}
%
%\value{
%  These functions return a logical vector indicating which
%  operation succeeded for each of the files attempted.  Using a missing
%  value for a file or path name will always be regarded as a failure.
%
%  If \code{showWarnings = TRUE}, \code{file.create} will give a warning
%  for an unexpected failure.
%}
%
%\section{Case-insensitive file systems}{
%  Case-insensitive file systems are the norm on Windows and OS X,
%  but can be found on all OSes (for example a FAT-formatted USB drive is
%  probably case-insensitive).
%
%  These functions will most likely match existing files regardless of case
%  on such file systems: however this is an OS function and it is
%  possible that file names might be mapped to upper or lower case.
%}
%
%#ifdef windows
%\note{
%  There is no guarantee that these functions will handle Windows
%  relative paths of the form \file{d:path}: try \file{d:./path}
%  instead.  In particular, \file{d:} is not recognized as a directory.
%  Nor are \samp{\\\\?\\} prefixes (and similar) supported.
%
%  Most of these functions accept UTF-8 filepaths not valid in the
%  current locale.
%
%  User error in supplying invalid file names (and note that \file{foo/}
%  and \file{foo\\} \emph{are} invalid on Windows) has undefined consequences.
%}
%
%\section{Symbolic links on Windows}{ Symbolic links in the sense of
%  POSIX file systems do not exist on Windows: however, NTFS file systems
%  support two similar concepts.
%
%  Windows 2000 and later have \sQuote{junctions} (or \sQuote{junction
%  points}), unfortunately without a public API.  They are a Windows
%  version of the Unix concept of mounting one directory on another.  One
%  way to create, list and delete junctions is \emph{via}
%  \file{junction.exe} from
%  \url{https://download.sysinternals.com/files/Junction.zip} (see
%  \url{https://technet.microsoft.com/en-us/sysinternals/bb896768}).  On
%  recent enough versions of Windows \command{mklink /J} can also be
%  used.  Function \code{Sys.junction} creates one or more junctions:
%  \code{to} should either specify a single existing directory or a set
%  of non-existent file paths of the same length as \code{from}.
%
%  A version of symbolic linking to files/directories was implemented
%  starting with Vista, and \code{file.symlink} makes use of that
%  interface.  However, it has restrictions (apart from the OS version
%  restriction) which are crippling.  First, the user needs permission to
%  make symbolic links, and that permission is not normally granted
%  except to Administrator accounts (note: not users with Administrator
%  rights): further many users report that whereas the Policy Editor
%  appears to be able to grant such rights, the API still reports
%  insufficient permissions.  Second, the interface needs to know if
%  \code{from} is a file or a directory (and it need not yet exist): we
%  have implemented this to allow linking from a directory only if it
%  currently exists.  Prior to \R 3.0.3 the paths had to use backslashes
%  (an undocumented restriction of the Windows system call).
%
%  Care is needed with removing a junction (and most likely also a
%  symbolic link): many tools will remove the target and its contents
%  (including Windows Explorer in XP, and \code{unlink} in \R prior to
%  2.15.0).
%}
%#endif
%
%\author{
%  Ross Ihaka, Brian Ripley
%}
%\seealso{
%  \code{\link{file.info}}, \code{\link{file.access}}, \code{\link{file.path}},
%  \code{\link{file.show}}, \code{\link{list.files}},
%  \code{\link{unlink}}, \code{\link{basename}},
%  \code{\link{path.expand}}.
%
%  \code{\link{dir.create}}.
%
%  \code{\link{Sys.glob}} to expand wildcards in file specifications.
%
%  \code{\link{file_test}}, \code{\link{Sys.readlink}}.
%
%  \url{https://en.wikipedia.org/wiki/Hard_link} and
%  \url{https://en.wikipedia.org/wiki/Symbolic_link} for the concepts of
%  links and their limitations.
%}
%
%\examples{
%cat("file A\n", file = "A")
%cat("file B\n", file = "B")
%file.append("A", "B")
%file.create("A")
%file.append("A", rep("B", 10))
%if(interactive()) file.show("A")
%file.copy("A", "C")
%dir.create("tmp")
%file.copy(c("A", "B"), "tmp")
%list.files("tmp")
%#ifdef unix
%setwd("tmp")
%file.remove("B")
%file.symlink(file.path("..", c("A", "B")), ".")
%setwd("..")
%#endif
%unlink("tmp", recursive = TRUE)
%file.remove("A", "B", "C")
%}
%\keyword{file}
%
\encoding{UTF8}
