% File src/library/base/man/get.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{get}
\title{Return the Value of a Named Object}
\alias{get}
\alias{mget}
\alias{dynGet}
\description{
  オブジェクトを名前で探す(\code{get})，又はゼロもしくはそれ以上のオブジェクトを
  探す (\code{mget})．
}
\usage{
get(x, pos = -1, envir = as.environment(pos), mode = "any",
    inherits = TRUE)

mget(x, envir = as.environment(-1), mode = "any", ifnotfound,
     inherits = FALSE)

dynGet(x, ifnotfound = , minframe = 1L, inherits = FALSE)
}
\arguments{
  \item{x}{\code{get} に対してはオブジェクト名(文字列として与えられる)．\cr
    \code{mget} に対してはオブジェクト名の文字列ベクトル．
  }
  \item{pos, envir}{オブジェクトをどこで探すか(\sQuote{詳細}を見よ)；もし
    省略されるとオブジェクト名が引用化されずに表現式中に登場されたかのように探索する．}
  \item{mode}{探されるオブジェクトのモードと型：\sQuote{詳細}節を見よ．}
  \item{inherits}{環境の囲みフレームが探されるべきか?}
  \item{ifnotfound}{\code{mget} に対しては項目が見つからなかったら
    \code{\link{list}} の値として使われる値：必要ならリストに変換される．\cr
    \code{dynGet} に対しては任意の \R オブジェクト，つまり
    \code{\link{stop}()} への呼び出し．}
  \item{minframe}{探される最小のフレーム番号を指定する整数．}
}
\details{
  \code{pos} 引数はオブジェクトを探す環境を何通りもの仕方で指定できる：
  正の整数(\code{\link{search}} リストの位置)；検索リスト中の要素名の文字列として；
  又は現在アクティブな関数呼び出しにアクセスする環境(\code{\link{sys.frame}} の使用を含む)．
  既定値は \code{-1} で \code{get} への呼び出しの現在の環境．
  \code{envir} 引数は環境を指定する別の方法である．

  これらの関数は名前 \code{x} の各々が指定環境でそれに結びついた値を持つかどうかを
  検索する．もし \code{inherits} が \code{TRUE} で \code{x} に対する値が見つからないと，
  環境の囲みフレームが名前 \code{x} が見つかるまで探索される．
  環境とそれらの囲み環境に関する詳細は \code{\link{environment}} と
  マニュアル \sQuote{R Language Definition} を見よ．

  もし \code{mode} が指定されるとその型のオブジェクトだけが探される．
  ここで \code{mode} とは意味 \code{\link{typeof}} と \code{\link{mode}} を
  合わせたものである：\code{"function"} はプリミティブ関数と演算子，
  \code{"numeric"}, \code{"integer"} そして \code{"double"}
  全ては任意の数値型をカバーする．\code{"symbol"} と \code{"name"} は
  同値であるが，しかし \code{"language"} が使われなければならない(そして
  \code{"call"} や \code{"("} ではない)．

  \code{mget} に対しては \code{mode} と \code{ifnotfound} の値は
  \code{x} と同じ長さか，長さ1でも良い．引数
  \code{ifnotfound} は要求された項目が見つからなかった時に使う値か，
  項目が見つからなかった時に呼び出される引数が一つの関数(要求されている項目
  の名前を引数に持つ)のどちらかのリストである．

  \code{dynGet()} は少々実験的で他の関数中で使われる．
  これはオブジェクトを呼び出し環境，つまり関数の
  \code{\link{sys.frame}()}，中で探す．注意して使おう．
}
\value{
  \code{get} に対しては見つかったオブジェクト．もしオブジェクトが
  見つからなければエラーになる．

  \code{mget} に対してはオブジェクトの名前付きリスト
  (見つかったものか \code{ifnotfound} で指定されたもの)．
}
\note{
  \code{a <- get(nam)} の逆操作は
  \code{\link{assign}(nam, a)} で \code{a} に名前 \code{nam} を与える．

  \code{inherits = TRUE} は \R では既定値であるが，S では異なった意味を持ち
  既定値ではない．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  オブジェクトが存在するかどうかのチェックには \code{\link{exists}}；
  オブジェクトの存在をチェックし同時にオブジェクトを得る効率的な方法は \code{\link{get0}}．

  \code{get()} の逆である \code{\link{assign}}，上を見よ．

  オブジェクトを他の名前空間を含むどこにあるかにかかわらず探すには \code{\link[utils]{getAnywhere}}，
  そしてオブジェクトを特定の名前空間で探すには \code{\link[utils]{getFromNamespace}}．
}
\examples{
get("\%o\%")

## mget のテスト
e1 <- new.env()
mget(letters, e1, ifnotfound = as.list(LETTERS))
}
\keyword{data}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/get.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{get}
%\title{Return the Value of a Named Object}
%\alias{get}
%\alias{mget}
%\alias{dynGet}
%\description{
%  Search by name for an object (\code{get}) or zero or more objects
%  (\code{mget}).
%}
%\usage{
%get(x, pos = -1, envir = as.environment(pos), mode = "any",
%    inherits = TRUE)
%
%mget(x, envir = as.environment(-1), mode = "any", ifnotfound,
%     inherits = FALSE)
%
%dynGet(x, ifnotfound = , minframe = 1L, inherits = FALSE)
%}
%\arguments{
%  \item{x}{For \code{get}, an object name (given as a character
%    string).\cr
%    For \code{mget}, a character vector of object names.
%  }
%  \item{pos, envir}{where to look for the object (see \sQuote{Details}); if
%    omitted search as if the name of the object appeared unquoted in an
%    expression.}
%  \item{mode}{the mode or type of object sought: see the
%    \sQuote{Details} section.}
%  \item{inherits}{should the enclosing frames of the environment be
%    searched?}
%  \item{ifnotfound}{For \code{mget}, a \code{\link{list}} of values to
%    be used if the item is not found: it will be coerced to a list if
%    necessary.\cr
%    For \code{dynGet} any \R object, e.g., a call to
%    \code{\link{stop}()}.}
%  \item{minframe}{integer specifying the minimal frame number to look
%    into.}
%}
%\details{
%  The \code{pos} argument can specify the environment in which to look
%  for the object in any of several ways: as a positive integer (the
%  position in the \code{\link{search}} list); as the character string
%  name of an element in the search list; or as an
%  \code{\link{environment}} (including using \code{\link{sys.frame}}
%  to access the currently active function calls).  The default of
%  \code{-1} indicates the current environment of the call to
%  \code{get}. The \code{envir} argument is an alternative way to
%  specify an environment.
%
%  These functions look to see if each of the name(s) \code{x} have a
%  value bound to it in the specified environment.  If \code{inherits} is
%  \code{TRUE} and a value is not found for \code{x} in the specified
%  environment, the enclosing frames of the environment are searched
%  until the name \code{x} is encountered.  See \code{\link{environment}}
%  and the \sQuote{R Language Definition} manual for details about the
%  structure of environments and their enclosures.
%
%  If \code{mode} is specified then only objects of that type are sought.
%  \code{mode} here is a mixture of the meanings of \code{\link{typeof}}
%  and \code{\link{mode}}: \code{"function"} covers primitive functions
%  and operators, \code{"numeric"}, \code{"integer"} and \code{"double"}
%  all refer to any numeric type, \code{"symbol"} and \code{"name"} are
%  equivalent \emph{but} \code{"language"} must be used (and not
%  \code{"call"} or \code{"("}).
%
%  For \code{mget}, the values of \code{mode} and \code{ifnotfound} can
%  be either the same length as \code{x} or of length 1.  The argument
%  \code{ifnotfound} must be a list containing either the value to use if
%  the requested item is not found or a function of one argument which
%  will be called if the item is not found, with argument the name of the
%  item being requested.
%
%  \code{dynGet()} is somewhat experimental and to be used \emph{inside}
%  another function.  It looks for an object in the callers, i.e.,
%  the \code{\link{sys.frame}()}s of the function.  Use with caution.
%}
%\value{
%  For \code{get}, the object found.  If no object is found an error results.
%
%  For \code{mget}, a named list of objects (found or specified \emph{via}
%  \code{ifnotfound}).
%}
%\note{
%  The reverse (or \dQuote{inverse}) of \code{a <- get(nam)} is
%  \code{\link{assign}(nam, a)}, assigning \code{a} to name \code{nam}.
%
%  \code{inherits = TRUE} is the default for \code{get} in \R
%  but not for S where it had a different meaning.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{exists}} for checking whether an object exists;
%  \code{\link{get0}} for an efficient way of both checking existence and
%  getting an object.
%
%  \code{\link{assign}}, the inverse of \code{get()}, see above.
%
%  Use \code{\link[utils]{getAnywhere}} for searching for an object
%  anywhere, including in other namespaces, and
%  \code{\link[utils]{getFromNamespace}} to find an object in a specific
%  namespace.
%}
%\examples{
%get("\%o\%")
%
%## test mget
%e1 <- new.env()
%mget(letters, e1, ifnotfound = as.list(LETTERS))
%}
%\keyword{data}
%
\encoding{UTF8}
