% File src/library/base/man/match.call.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{match.call}
\title{Argument Matching}
\usage{
match.call(definition = sys.function(sys.parent()),
           call = sys.call(sys.parent()),
           expand.dots = TRUE,
           envir = parent.frame(2L))
}
\alias{match.call}
\arguments{
  \item{definition}{関数，既定では \code{match.call} がその中から呼び出された
    関数．詳細を見よ．}
  \item{call}{\code{\link{call}} で生成されたもののような，
    \code{definition} で指定された関数への未評価呼び出し．}
  \item{expand.dots}{論理値．呼び出し中の \code{\dots} にマッチする
    引数を含めるか，それとも \code{\dots} 引数のまま残しておくか?}
  \item{envir}{もしあれば，そこから \code{call} 中の \code{\dots}
    が回収された環境．}
}
\description{
  \code{match.call} は全ての指定された引数がそれらの完全な名前で
  指定された呼び出しを返す．
}
\details{
  このヘルプページに於ける \sQuote{関数} とはインタープリタ関数
  (\sQuote{closure} としても知られている) を意味する：
  \code{match.call} はプリミティブな関数をサポートしない
  (そこでは引数のマッチングは普通位置による)．

  \code{match.call} は最も普通には次の二つの状況で使われる：
  \itemize{
    \item 後で再利用するために記録する：例えば殆どのモデル当てはめ関数は
    呼び出しをそれらが返すリストの \code{call} 要素として記録する．
    この場合既定の \code{expand.dots = TRUE} がふさわしい．

    \item 呼び出しの殆どを別の関数，しばしば \code{model.frame}，に渡す．
    ここでは共通のイディオムは \code{expand.dots = FALSE} が使われることで，
    そして マッチした呼び出しの \code{\dots} 要素は取り除かれる．
    別の方法は，\code{lm} が行うように，渡される引数を明示的に選択することである．
  }

  \code{definition} の指定なしに関数の外部から \code{match.call} を
  呼び出すことはエラーである．
}
\value{
  クラス \code{call} のオブジェクト．
}
\references{
  Chambers, J. M. (1998)
  \emph{Programming with Data. A Guide to the S Language}.
  Springer.
}
\seealso{
  \code{\link{sys.call}()} は似通っているが，引数の名前を展開しない；
  
  \code{\link{call}}, \code{\link{pmatch}}, \code{\link{match.arg}},
  \code{\link{match.fun}}.
}
\examples{
match.call(get, call("get", "abc", i = FALSE, p = 3))
## -> get(x = "abc", pos = 3, inherits = FALSE)
fun <- function(x, lower = 0, upper = 1) {
  structure((x - lower) / (upper - lower), CALL = match.call())
}
fun(4 * atan(1), u = pi)
}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/match.call.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{match.call}
%\title{Argument Matching}
%\usage{
%match.call(definition = sys.function(sys.parent()),
%           call = sys.call(sys.parent()),
%           expand.dots = TRUE,
%           envir = parent.frame(2L))
%}
%\alias{match.call}
%\arguments{
%  \item{definition}{a function, by default the function from which
%    \code{match.call} is called.  See details.}
%  \item{call}{an unevaluated call to the function specified by
%    \code{definition}, as generated by \code{\link{call}}.}
%  \item{expand.dots}{logical.  Should arguments matching \code{\dots}
%    in the call be included or left as a \code{\dots} argument?}
%  \item{envir}{an environment, from which the \code{\dots} in \code{call}
%    are retrieved, if any.}
%}
%\description{
%  \code{match.call} returns a call in which all of the specified arguments are
%  specified by their full names.
%}
%\details{
%  \sQuote{function} on this help page means an interpreted function
%  (also known as a \sQuote{closure}):  \code{match.call} does not support
%  primitive functions (where argument matching is normally
%  positional).
%
%  \code{match.call} is most commonly used in two circumstances:
%  \itemize{
%    \item To record the call for later re-use: for example most
%    model-fitting functions record the call as element \code{call} of
%    the list they return.  Here the default \code{expand.dots = TRUE}
%    is appropriate.
%
%    \item To pass most of the call to another function, often
%    \code{model.frame}.  Here the common idiom is that
%    \code{expand.dots = FALSE} is used, and the \code{\dots} element
%    of the matched call is removed.  An alternative is to
%    explicitly select the arguments to be passed on, as is done in
%    \code{lm}.
%  }
%
%  Calling \code{match.call} outside a function without specifying
%  \code{definition} is an error.
%}
%\value{
%  An object of class \code{call}.
%}
%\references{
%  Chambers, J. M. (1998)
%  \emph{Programming with Data. A Guide to the S Language}.
%  Springer.
%}
%\seealso{
%  \code{\link{sys.call}()} is similar, but does \emph{not} expand the
%  argument names;
%  \code{\link{call}}, \code{\link{pmatch}}, \code{\link{match.arg}},
%  \code{\link{match.fun}}.
%}
%\examples{
%match.call(get, call("get", "abc", i = FALSE, p = 3))
%## -> get(x = "abc", pos = 3, inherits = FALSE)
%fun <- function(x, lower = 0, upper = 1) {
%  structure((x - lower) / (upper - lower), CALL = match.call())
%}
%fun(4 * atan(1), u = pi)
%}
%\keyword{programming}
%
\encoding{UTF8}
