% File src/library/base/man/match.fun.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{match.fun}
\alias{match.fun}
\title{Extract a Function Specified by Name}
\description{
  関数を引数として取る関数内部で使われると，要求される関数オブジェクトを返すが，
  他のタイプのオブジェクトへの期待されないマッチングを避ける．
}
\usage{
match.fun(FUN, descend = TRUE)
}
\arguments{
 \item{FUN}{関数としてマッチする項目：関数，シンボル，または文字列．
    \sQuote{詳細}を見よ．}
 \item{descend}{論理値；過去の非関数オブジェクトを検索するか．}
}
\value{
  \code{FUN} にマッチする関数，もしくはエラーが生成される．
}
\details{
  \code{match.fun} は呼び出し側の\emph{親}の中でマッチングを行うため，
  トップレベルで使われることを意図していない．

  もし \code{FUN} が関数ならばそれが返される．もしそれがシンボル
  (例えばバックコートで囲まれた)か長さ1の文字列ならば，呼び出し側の
  親環境中で \code{get} を用いて検索される．もしそれが任意の他のモードならば，
  先ずシンボルとして呼び出し側の引数を得ることを試み
  (\code{substitute} を二度使い)，そしてそれが失敗するとエラーが宣言される．

  もし \code{descend = TRUE} ならば，\code{match.fun} は与えられた名前を持つ過去の
  非関数オブジェクトを探す；さもなければ，もし \code{FUN} が非関数オブジェクトを
  指し示していればエラーが生成される．

  これは \code{\link{apply}},
  \code{\link{lapply}}, \code{\link{outer}}，そして \code{\link{sweep}}
  のような基本関数中で使われている．
}
\author{
  Peter Dalgaard と Robert Gentleman，Jonathan Rougier による初期バージョンに
  基づく．
}
\section{バグ}{
  \code{descend} 引数は些か誤った名称であり，恐らく実際にはどれからも必要とされない．
  将来は取り除かれるかもしれない．

  これを完全に誤りなしにすることは不可能である．
  もし関数と同名の長さ1の文字列を含むリストやデータフレームを付加すると，
  それが使われるかもしれない(名前空間が助けになるかもしれないが)．
}
\seealso{
  \code{\link{match.arg}}, \code{\link{get}}
}
\examples{
# get("*") と同じ：
match.fun("*")
# outer をベクトルで上書き
outer <- 1:5
try(match.fun(outer, descend = FALSE)) #-> エラー： 関数ではない
match.fun(outer) # それをとにかく見つける
is.function(match.fun("outer")) # 同じ
}
\keyword{programming}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/match.fun.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{match.fun}
%\alias{match.fun}
%\title{Extract a Function Specified by Name}
%\description{
%  When called inside functions that take a function as argument, extract
%  the desired function object while avoiding undesired matching to
%  objects of other types.
%}
%\usage{
%match.fun(FUN, descend = TRUE)
%}
%\arguments{
% \item{FUN}{item to match as function: a function, symbol or
%    character string.  See \sQuote{Details}.}
% \item{descend}{logical; control whether to search past non-function
%     objects.}
%}
%\value{
%  A function matching \code{FUN} or an error is generated.
%}
%\details{
%  \code{match.fun} is not intended to be used at the top level since it
%  will perform matching in the \emph{parent} of the caller.
%
%  If \code{FUN} is a function, it is returned.  If it is a symbol (for
%  example, enclosed in backquotes) or a
%  character vector of length one, it will be looked up using \code{get}
%  in the environment of the parent of the caller.  If it is of any other
%  mode, it is attempted first to get the argument to the caller as a
%  symbol (using \code{substitute} twice), and if that fails, an error is
%  declared.
%
%  If \code{descend = TRUE}, \code{match.fun} will look past non-function
%  objects with the given name; otherwise if \code{FUN} points to a
%  non-function object then an error is generated.
%
%  This is used in base functions such as \code{\link{apply}},
%  \code{\link{lapply}}, \code{\link{outer}}, and \code{\link{sweep}}.
%}
%\author{
%  Peter Dalgaard and Robert Gentleman, based on an earlier version
%  by Jonathan Rougier.
%}
%\section{Bugs}{
%  The \code{descend} argument is a bit of misnomer and probably not
%  actually needed by anything.  It may go away in the future.
%
%  It is impossible to fully foolproof this.  If one \code{attach}es a
%  list or data frame containing a length-one character vector with the
%  same name as a function, it may be used (although namespaces
%  will help).
%}
%\seealso{
%  \code{\link{match.arg}}, \code{\link{get}}
%}
%\examples{
%# Same as get("*"):
%match.fun("*")
%# Overwrite outer with a vector
%outer <- 1:5
%try(match.fun(outer, descend = FALSE)) #-> Error:  not a function
%match.fun(outer) # finds it anyway
%is.function(match.fun("outer")) # as well
%}
%\keyword{programming}
%
\encoding{UTF8}
