% File src/library/base/man/merge.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Copyright 2002-2011 The R Foundation
% Distributed under GPL 2 or later

\name{merge}
\alias{merge}
\alias{merge.default}
\alias{merge.data.frame}
\concept{join}
\title{Merge Two Data Frames}
\description{
  二つのデータフレームを共通の列や行で併合する．
  又はデータベースの \emph{join} 演算の他のバージョンを行う．
}
\usage{
merge(x, y, \dots)

\method{merge}{default}(x, y, \dots)

\method{merge}{data.frame}(x, y, by = intersect(names(x), names(y)),
      by.x = by, by.y = by, all = FALSE, all.x = all, all.y = all,
      sort = TRUE, suffixes = c(".x",".y"),
      incomparables = NULL, \dots)
}
\arguments{
  \item{x, y}{データフレーム，もしくはそれに強制変換されるもの．}
  \item{by, by.x, by.y}{併合に使われる列の指定，
    \sQuote{詳細}を見よ．}
  \item{all}{論理値；\code{all = L} は \code{all.x = L} と
    \code{all.y = L} の短縮形である．ここで
    \code{L} は \code{\link{TRUE}} か \code{FALSE}．}
  \item{all.x}{論理値；もし \code{TRUE} なら
  \code{y} 中にマッチする行がない \code{x} 中の各列毎に一つ
    余分の行が出力に付け加えられる，
    これらの行は普通 \code{y} からの値で埋められる列中に \code{NA} を持つ．
    既定値は \code{FALSE} で，従って \code{x} と \code{y} の
    双方からのデータだけが出力中に含められる．}
  \item{all.y}{論理値；\code{all.x} と同様．}
  \item{sort}{論理値．結果は \code{by} 列に関してソートすべきか?}
  \item{suffixes}{長さ2の文字列ベクトル．
    併合に使われなかった(\code{by} 中に登場した等)結果中の列名を
    ユニークにするために使われる添字を指定する．}
  \item{incomparables}{マッチできない値．
    \code{\link{match}} を見よ．これは一つの列に関して併合するために
    使われることを意図しているので，これらはその列の比較不能な値である．}
  \item{\dots}{メソッドに/から渡される引数．}
}
\details{
  \code{merge} は総称的関数で，その主要なメソッドはデータフレーム用である：
  既定メソッドはその引数をデータフレームに強制変換し，そして
  \code{"data.frame"} メソッドを呼び出す．

  既定ではデータフレームは双方が共有する列に関して併合されるが，
  列に関する個別の指定も 
  \code{by.x} と \code{by.y} により与えられる．指定した二つのデータフレーム
  にマッチする行が抜き出され一緒に併合される．もしひとつ以上のマッチがあれば，
  全ての可能なマッチが一つの行毎に寄与する．
  \sQuote{マッチ}の正確な意味は \code{\link{match}} を見よ．

  それに関して併合を行う列は名前，数又は論理値ベクトルで指定できる：
  名前 \code{"row.names"} か数 \code{0} は行名を指定する．
  もし名前で指定されると，それは入力中の名前付き列とユニークに
  一致しなければならない．

  もし \code{by} か \code{by.x} と \code{by.y} の双方が長さ 0
  (長さゼロのベクトルか \code{NULL})ならば，結果，\code{r}，は
  \code{x} と \code{y} の\emph{カルテジアン積}になる，つまり
  \code{dim(r) = c(nrow(x)*nrow(y), ncol(x) + ncol(y))}．

  もし \code{all.x} が真ならば，\code{x} の全てのマッチしないケースも
  同様に結果に付け加えられる．\code{y} の対応する列は \code{NA} で
  埋められる；\code{all.y} に対しても同様である．

  もしデータフレーム中の併合に使われなかった列は
  任意の共通名を持つ．これらは結果の名前ををユニークにするため
  添字(既定で \code{".x"} と \code{".y"})を加えられる．
  もしこれが不可能ならばエラーが起きる．

  アルゴリズムの計算量は回答の長さに比例する．

  % Terminology follows https://en.wikipedia.org/wiki/Join_(SQL)
  SQL データベースの語法では，\code{all = FALSE} に対する既定値は
  \emph{natural join} を与え \emph{inner join} の特殊例である．
  \code{all.x = TRUE} の指定は \emph{left (outer) join}，
  \code{all.y = TRUE} は \emph{right (outer) join}，そして両方を併せた
  \code{all = TRUE} は \emph{(full) outer join} と呼ばれる．
  DBMS は \code{NULL} レコードとはマッチせず，\R の
  \code{incomparables = NA} と同値である．
}

\note{
  これはベクトル風の列を持つデータフレームに使われることを意図している：
  幾つかの機能は行列を含むデータフレームでも動作するが，全てではない．
  
  現在ロングベクトルは入力として受け入れられないので，
  従って 2^31 個未満の列に制限されている．
  \R 3.2.0 以前ではこの制限はまた結果にも適用された
  (そして 32 ビットプラットフォームでは依然そうである)．
}

\value{
  データフレーム．行は既定で共通の列に関して辞書式にソートされているが，
  \code{sort = FALSE} に対しては未指定の順序になる．
  列は共通の列に \code{x} 中の残りの列，そして \code{y} 中の残りの列が続く．
  もしマッチングが行名を伴えば \code{Row.names} と呼ばれる余分の列が左端に
  加えられ，全ての場合で結果は\sQuote{自動的な}行名を持つ．
}
\seealso{
  \code{\link{data.frame}},
  \code{\link{by}},
  \code{\link{cbind}}.

  \code{merge} メソッドを持つクラスに対しては \code{\link{dendrogram}}．
}

\examples{
## 意味のあるソート順序を得るために名前の文字列を使う
authors <- data.frame(
    surname = I(c("Tukey", "Venables", "Tierney", "Ripley", "McNeil")),
    nationality = c("US", "Australia", "US", "UK", "Australia"),
    deceased = c("yes", rep("no", 4)))
books <- data.frame(
    name = I(c("Tukey", "Venables", "Tierney",
             "Ripley", "Ripley", "McNeil", "R Core")),
    title = c("Exploratory Data Analysis",
              "Modern Applied Statistics ...",
              "LISP-STAT",
              "Spatial Statistics", "Stochastic Simulation",
              "Interactive Data Analysis",
              "An Introduction to R"),
    other.author = c(NA, "Ripley", NA, NA, NA, NA,
                     "Venables & Smith"))

(m1 <- merge(authors, books, by.x = "surname", by.y = "name"))
(m2 <- merge(books, authors, by.x = "name", by.y = "surname"))
stopifnot(as.character(m1[, 1]) == as.character(m2[, 1]),
          all.equal(m1[, -1], m2[, -1][ names(m1)[-1] ]),
          dim(merge(m1, m2, by = integer(0))) == c(36, 10))

## "R core" は作者から抜けておりここだけでみられる：
merge(authors, books, by.x = "surname", by.y = "name", all = TRUE)

## 'incomparables' の使用例
x <- data.frame(k1 = c(NA,NA,3,4,5), k2 = c(1,NA,NA,4,5), data = 1:5)
y <- data.frame(k1 = c(NA,2,NA,4,5), k2 = c(NA,NA,3,4,5), data = 1:5)
merge(x, y, by = c("k1","k2")) # NA のマッチ
merge(x, y, by = "k1") # NA のマッチ，従って 6 行
merge(x, y, by = "k2", incomparables = NA) # 2 行
}
\keyword{array}
\keyword{manip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/merge.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Copyright 2002-2011 The R Foundation
%% Distributed under GPL 2 or later
%
%\name{merge}
%\alias{merge}
%\alias{merge.default}
%\alias{merge.data.frame}
%\concept{join}
%\title{Merge Two Data Frames}
%\description{
%  Merge two data frames by common columns or row names, or do other
%  versions of database \emph{join} operations.
%}
%\usage{
%merge(x, y, \dots)
%
%\method{merge}{default}(x, y, \dots)
%
%\method{merge}{data.frame}(x, y, by = intersect(names(x), names(y)),
%      by.x = by, by.y = by, all = FALSE, all.x = all, all.y = all,
%      sort = TRUE, suffixes = c(".x",".y"),
%      incomparables = NULL, \dots)
%}
%\arguments{
%  \item{x, y}{data frames, or objects to be coerced to one.}
%  \item{by, by.x, by.y}{specifications of the columns used for merging.
%    See \sQuote{Details}.}
%  \item{all}{logical; \code{all = L} is shorthand for \code{all.x = L} and
%    \code{all.y = L}, where \code{L} is either \code{\link{TRUE}} or
%    \code{FALSE}.}
%  \item{all.x}{logical; if \code{TRUE}, then extra rows will be added to
%    the output, one for each row in \code{x} that has no matching row in
%    \code{y}.  These rows will have \code{NA}s in those columns that are
%    usually filled with values from \code{y}.  The default is
%    \code{FALSE}, so that only rows with data from both \code{x} and
%    \code{y} are included in the output.}
%  \item{all.y}{logical; analogous to \code{all.x}.}
%  \item{sort}{logical.  Should the result be sorted on the \code{by}
%    columns?}
%  \item{suffixes}{a character vector of length 2 specifying the suffixes
%    to be used for making unique the names of columns in the result
%    which not used for merging (appearing in \code{by} etc).}
%  \item{incomparables}{values which cannot be matched.  See
%    \code{\link{match}}.  This is intended to be used for merging on one
%    column, so these are incomparable values of that column.}
%  \item{\dots}{arguments to be passed to or from methods.}
%}
%\details{
%  \code{merge} is a generic function whose principal method is for data
%  frames: the default method coerces its arguments to data frames and
%  calls the \code{"data.frame"} method.
%
%  By default the data frames are merged on the columns with names they
%  both have, but separate specifications of the columns can be given by
%  \code{by.x} and \code{by.y}.  The rows in the two data frames that
%  match on the specified columns are extracted, and joined together.  If
%  there is more than one match, all possible matches contribute one row
%  each.  For the precise meaning of \sQuote{match}, see
%  \code{\link{match}}.
%
%  Columns to merge on can be specified by name, number or by a logical
%  vector: the name \code{"row.names"} or the number \code{0} specifies
%  the row names.  If specified by name it must correspond uniquely to a
%  named column in the input.
%
%  If \code{by} or both \code{by.x} and \code{by.y} are of length 0 (a
%  length zero vector or \code{NULL}), the result, \code{r}, is the
%  \emph{Cartesian product} of \code{x} and \code{y}, i.e.,
%  \code{dim(r) = c(nrow(x)*nrow(y), ncol(x) + ncol(y))}.
%
%  If \code{all.x} is true, all the non matching cases of \code{x} are
%  appended to the result as well, with \code{NA} filled in the
%  corresponding columns of \code{y};  analogously for \code{all.y}.
%
%  If the columns in the data frames not used in merging have any common
%  names, these have \code{suffixes} (\code{".x"} and \code{".y"} by
%  default) appended to try to make the names of the result unique.  If
%  this is not possible, an error is thrown.
%
%  The complexity of the algorithm used is proportional to the length of
%  the answer.
%
%  % Terminology follows https://en.wikipedia.org/wiki/Join_(SQL)
%  In SQL database terminology, the default value of \code{all = FALSE}
%  gives a \emph{natural join}, a special case of an \emph{inner
%  join}. Specifying \code{all.x = TRUE} gives a \emph{left (outer)
%  join}, \code{all.y = TRUE} a \emph{right (outer) join}, and both
%  (\code{all = TRUE} a \emph{(full) outer join}.  DBMSes do not match
%  \code{NULL} records, equivalent to \code{incomparables = NA} in \R.
%}
%
%\note{
%  This is intended to work with data frames with vector-like columns:
%  some aspects work with data frames containing matrices, but not all.
%  
%  Currently long vectors are not accepted for inputs, which are thus
%  restricted to less than 2^31 rows.  Prior to \R 3.2.0 that restriction
%  also applied to the result (and still does for 32-bit platforms).
%}
%
%\value{
%  A data frame.  The rows are by default lexicographically sorted on the
%  common columns, but for \code{sort = FALSE} are in an unspecified order.
%  The columns are the common columns followed by the
%  remaining columns in \code{x} and then those in \code{y}.  If the
%  matching involved row names, an extra character column called
%  \code{Row.names} is added at the left, and in all cases the result has
%  \sQuote{automatic} row names.
%}
%\seealso{
%  \code{\link{data.frame}},
%  \code{\link{by}},
%  \code{\link{cbind}}.
%
%  \code{\link{dendrogram}} for a class which has a \code{merge} method.
%}
%
%\examples{
%## use character columns of names to get sensible sort order
%authors <- data.frame(
%    surname = I(c("Tukey", "Venables", "Tierney", "Ripley", "McNeil")),
%    nationality = c("US", "Australia", "US", "UK", "Australia"),
%    deceased = c("yes", rep("no", 4)))
%books <- data.frame(
%    name = I(c("Tukey", "Venables", "Tierney",
%             "Ripley", "Ripley", "McNeil", "R Core")),
%    title = c("Exploratory Data Analysis",
%              "Modern Applied Statistics ...",
%              "LISP-STAT",
%              "Spatial Statistics", "Stochastic Simulation",
%              "Interactive Data Analysis",
%              "An Introduction to R"),
%    other.author = c(NA, "Ripley", NA, NA, NA, NA,
%                     "Venables & Smith"))
%
%(m1 <- merge(authors, books, by.x = "surname", by.y = "name"))
%(m2 <- merge(books, authors, by.x = "name", by.y = "surname"))
%stopifnot(as.character(m1[, 1]) == as.character(m2[, 1]),
%          all.equal(m1[, -1], m2[, -1][ names(m1)[-1] ]),
%          dim(merge(m1, m2, by = integer(0))) == c(36, 10))
%
%## "R core" is missing from authors and appears only here :
%merge(authors, books, by.x = "surname", by.y = "name", all = TRUE)
%
%## example of using 'incomparables'
%x <- data.frame(k1 = c(NA,NA,3,4,5), k2 = c(1,NA,NA,4,5), data = 1:5)
%y <- data.frame(k1 = c(NA,2,NA,4,5), k2 = c(NA,NA,3,4,5), data = 1:5)
%merge(x, y, by = c("k1","k2")) # NA's match
%merge(x, y, by = "k1") # NA's match, so 6 rows
%merge(x, y, by = "k2", incomparables = NA) # 2 rows
%}
%\keyword{array}
%\keyword{manip}
%
\encoding{UTF8}
