% File src/library/base/man/message.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{message}
\alias{message}
\alias{suppressMessages}
\alias{packageStartupMessage}
\alias{.packageStartupMessage}
\alias{suppressPackageStartupMessages}
\alias{.makeMessage}
\title{Diagnostic Messages}
\description{
  その引数から診断メッセージを生成する．
}
\usage{
message(\dots, domain = NULL, appendLF = TRUE)
suppressMessages(expr)

packageStartupMessage(\dots, domain = NULL, appendLF = TRUE)
suppressPackageStartupMessages(expr)

.makeMessage(\dots, domain = NULL, appendLF = FALSE)
}
\arguments{
  \item{\dots}{ゼロかそれ以上の文字列に変換できるオブジェクト
    (そしてそれらは分離記号なしに繋げられる)か(\code{message} 用だけ)
    一つの条件オブジェクト．}
  \item{domain}{\code{\link{gettext}} を見よ．もし \code{NA} なら，メッセージは
    翻訳されない，\code{\link{stop}} 中のノートも見よ．}
  \item{appendLF}{論理値：文字列として与えられたメッセージに新行を
    加えるか?}
  \item{expr}{評価される表現式．}
}
\details{
  \code{message} は警告やエラーではない\sQuote{単純な}診断メッセージを
  生成するのに使われるが，しかしながら条件として表現される．
  警告やエラーとは異なり最後の新行はメッセージの一部分と見做され，オプションである．
  既定のハンドラーはメッセージを
  \code{\link{stderr}()} コネクションに送る．

  もじ条件オブジェクトが \code{message} に提供されると，
  それは唯一の引数で無ければならず，それ以上の引数は警告と共に無視される．

  メッセージが処理されている間に \code{muffleMessage} 再開が利用できる．

  \code{suppressMessages} はその表現式を
  全ての\sQuote{単純な}診断メッセージ全てを無視した文脈の中で評価する．

  \code{packageStartupMessage} はそのメッセージが
  \code{suppressPackageStartupMessages} により別個に抑制できる変種である．
  (これらは依然としてメッセージであり，\code{suppressMessages} に
  より抑制できる．)

  \code{.makeMessage} は \code{message}, \code{warning}
  そして \code{stop} により使われるユーティリティで，
  \code{\dots} 引数から可能な翻訳(\code{\link{gettext}} を見よ)
  と結合(分離記号なしで)によりテキストメッセージを生成する．
}
\seealso{
  警告とエラーの生成については \code{\link{warning}} と \code{\link{stop}}；
  条件の処理と回復については \code{\link{conditions}}．
  recovery.

  テキストの自動翻訳については \code{\link{gettext}}．
}
\examples{
message("ABC", "DEF")
suppressMessages(message("ABC"))

testit <- function() {
  message("testing package startup messages")
  packageStartupMessage("initializing ...", appendLF = FALSE)
  Sys.sleep(1)
  packageStartupMessage(" done")
}

testit()
suppressPackageStartupMessages(testit())
suppressMessages(testit())
}
\keyword{programming}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/message.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{message}
%\alias{message}
%\alias{suppressMessages}
%\alias{packageStartupMessage}
%\alias{.packageStartupMessage}
%\alias{suppressPackageStartupMessages}
%\alias{.makeMessage}
%\title{Diagnostic Messages}
%\description{
%  Generate a diagnostic message from its arguments.
%}
%\usage{
%message(\dots, domain = NULL, appendLF = TRUE)
%suppressMessages(expr)
%
%packageStartupMessage(\dots, domain = NULL, appendLF = TRUE)
%suppressPackageStartupMessages(expr)
%
%.makeMessage(\dots, domain = NULL, appendLF = FALSE)
%}
%\arguments{
%  \item{\dots}{zero or more objects which can be coerced to character
%    (and which are pasted together with no separator) or (for
%    \code{message} only) a single condition object.}
%  \item{domain}{see \code{\link{gettext}}.  If \code{NA}, messages will
%    not be translated, see also the note in \code{\link{stop}}.}
%  \item{appendLF}{logical: should messages given as a character string
%    have a newline appended?}
%  \item{expr}{expression to evaluate.}
%}
%\details{
%  \code{message} is used for generating \sQuote{simple} diagnostic
%  messages which are neither warnings nor errors, but nevertheless
%  represented as conditions.  Unlike warnings and errors, a final
%  newline is regarded as part of the message, and is optional.
%  The default handler sends the message to the
%  \code{\link{stderr}()} \link{connection}.
%
%  If a condition object is supplied  to \code{message} it should be
%  the only argument, and further arguments will be ignored, with a warning.
%
%  While the message is being processed, a \code{muffleMessage} restart
%  is available.
%
%  \code{suppressMessages} evaluates its expression in a context that
%  ignores all \sQuote{simple} diagnostic messages.
%
%  \code{packageStartupMessage} is a variant whose messages can be
%  suppressed separately by \code{suppressPackageStartupMessages}.  (They
%  are still messages, so can be suppressed by \code{suppressMessages}.)
%
%  \code{.makeMessage} is a utility used by \code{message}, \code{warning}
%  and \code{stop} to generate a text message from the \code{\dots}
%  arguments by possible translation (see \code{\link{gettext}}) and
%  concatenation (with no separator).
%}
%\seealso{
%  \code{\link{warning}} and \code{\link{stop}} for generating warnings
%  and errors; \code{\link{conditions}} for condition handling and
%  recovery.
%
%  \code{\link{gettext}} for the mechanisms for the automated translation
%  of text.
%}
%\examples{
%message("ABC", "DEF")
%suppressMessages(message("ABC"))
%
%testit <- function() {
%  message("testing package startup messages")
%  packageStartupMessage("initializing ...", appendLF = FALSE)
%  Sys.sleep(1)
%  packageStartupMessage(" done")
%}
%
%testit()
%suppressPackageStartupMessages(testit())
%suppressMessages(testit())
%}
%\keyword{programming}
%
\encoding{UTF8}
