% File src/library/base/man/pmatch.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{pmatch}
\title{Partial String Matching}
\usage{
pmatch(x, table, nomatch = NA_integer_, duplicates.ok = FALSE)
}
\alias{pmatch}
\arguments{
  \item{x}{マッチされる値：\code{\link{as.character}} で文字列に変換
    される．ロングベクトルがサポートされている．}
  \item{table}{マッチされる対象の値：文字列ベクトルに変換される．
    ロングベクトルはサポートされていない．}
  \item{nomatch}{マッチしない場合と複数の部分マッチ位置の場合に
    返される値．これは整数に変換されることを注意する．}
  \item{duplicates.ok}{\code{table} 中の要素は二度以上使われるべきか?}
}
\description{
  \code{pmatch} はその最初の引数の要素に対して，その二番目の要素
  の間からマッチを探す．
}
\details{
  挙動は \code{duplicates.ok} の値によって異なる．最初にこれが真の場合を考える．
  最初の正確なマッチは考慮され，その位置が記録される．
  ユニークな部分マッチは考慮され，もしあれば記録される．
  (部分マッチは \code{x} の要素の全体が \code{table} の要素の先頭とマッチ
  した時に起こる．) 最後に \code{x} の全ての残りの要素はマッチしないと
  見做される．更に，空の文字列はどれともマッチせず，空の文字列に正確な
  マッチをするものはない．これは例えば文字列添字の部分マッチングに
  対する適切な挙動である．

  もし \code{duplicates.ok} が \code{FALSE} ならば，一度マッチした
  \code{table} の値は以降のマッチ探しからは除外される．
  この挙動は \R の引数マッチングのアルゴリズムと同値であるが，
  空の文字列の扱いだけが違う(引数マッチングではこれは正確なマッチと
  部分的なマッチの後任意の残りの引数とマッチする)．

  \code{\link{charmatch}} は \code{duplicates.ok} が真の
  \code{pmatch} に似るが，違いはそれがマッチなしと曖昧な部分マッチ
  を区別する点にある．それは空の文字列にマッチし，多重の正確なマッチ
  を認めない．

  \code{NA} 値はそれらが文字列定数 \code{"NA"} であるかのように扱われる．
}
\value{
  \code{x} と同じ長さの整数ベクトル(もし \code{nomatch = NA}
  ならば \code{NA} を含むかもしれない)で，
  マッチした \code{table} 中の要素の添字を与える．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Chambers, J. M. (1998)
  \emph{Programming with Data. A Guide to the S Language}.
  Springer.
}
\seealso{
  \code{\link{match}}, \code{\link{charmatch}} そして
  \code{\link{match.arg}}，
  関数の引数のマッチング等には \code{\link{match.fun}}，
  より一般的(正規表現)な文字列のマッチングには
  \code{\link{match.call}}，\code{\link{grep}} 等．
}
\examples{
pmatch("", "")                             # NA 
pmatch("m",   c("mean", "median", "mode")) # NA を返す
pmatch("med", c("mean", "median", "mode")) # 2 を返す

pmatch(c("", "ab", "ab"), c("abc", "ab"), dup = FALSE)
pmatch(c("", "ab", "ab"), c("abc", "ab"), dup = TRUE)
## compare
charmatch(c("", "ab", "ab"), c("abc", "ab"))
}
\keyword{character}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/pmatch.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{pmatch}
%\title{Partial String Matching}
%\usage{
%pmatch(x, table, nomatch = NA_integer_, duplicates.ok = FALSE)
%}
%\alias{pmatch}
%\arguments{
%  \item{x}{the values to be matched: converted to a character vector by
%    \code{\link{as.character}}.  \link{Long vectors} are supported.}
%  \item{table}{the values to be matched against: converted to a character
%    vector.  \link{Long vectors} are not supported.}
%  \item{nomatch}{the value to be returned at non-matching or multiply
%    partially matching positions.  Note that it is coerced to \code{integer}.}
%  \item{duplicates.ok}{should elements be in \code{table} be used more
%    than once?}
%}
%\description{
%  \code{pmatch} seeks matches for the elements of its first argument
%  among those of its second.
%}
%\details{
%  The behaviour differs by the value of \code{duplicates.ok}. Consider
%  first the case if this is true.  First exact matches are considered,
%  and the positions of the first exact matches are recorded. Then unique
%  partial matches are considered, and if found recorded.  (A partial
%  match occurs if the whole of the element of \code{x} matches the
%  beginning of the element of \code{table}.)  Finally,
%  all remaining elements of \code{x} are regarded as unmatched.
%  In addition, an empty string can match nothing, not even an exact
%  match to an empty string.  This is the appropriate behaviour for
%  partial matching of character indices, for example.
%
%  If \code{duplicates.ok} is \code{FALSE}, values of \code{table} once
%  matched are excluded from the search for subsequent matches.  This
%  behaviour is equivalent to the \R algorithm for argument
%  matching, except for the consideration of empty strings (which in
%  argument matching are matched after exact and partial matching to any
%  remaining arguments).
%
%  \code{\link{charmatch}} is similar to \code{pmatch} with
%  \code{duplicates.ok} true, the differences being that it
%  differentiates between no match and an ambiguous partial match,  it
%  does match empty strings, and it does not allow multiple exact matches.
%
%  \code{NA} values are treated as if they were the string constant
%  \code{"NA"}.
%}
%\value{
%  An integer vector (possibly including \code{NA} if \code{nomatch =
%    NA}) of the same length as \code{x}, giving the indices of the
%  elements in \code{table} which matched, or \code{nomatch}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Chambers, J. M. (1998)
%  \emph{Programming with Data. A Guide to the S Language}.
%  Springer.
%}
%\seealso{
%  \code{\link{match}}, \code{\link{charmatch}} and
%  \code{\link{match.arg}}, \code{\link{match.fun}},
%  \code{\link{match.call}}, for function argument matching etc.,
%  \code{\link{grep}} etc for more general (regexp) matching of strings.
%}
%\examples{
%pmatch("", "")                             # returns NA
%pmatch("m",   c("mean", "median", "mode")) # returns NA
%pmatch("med", c("mean", "median", "mode")) # returns 2
%
%pmatch(c("", "ab", "ab"), c("abc", "ab"), dup = FALSE)
%pmatch(c("", "ab", "ab"), c("abc", "ab"), dup = TRUE)
%## compare
%charmatch(c("", "ab", "ab"), c("abc", "ab"))
%}
%\keyword{character}
%
\encoding{UTF8}
