% File src/library/base/man/readChar.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{readChar}
\alias{readChar}
\alias{writeChar}
\title{Transfer Character Strings To and From Connections}
\description{
  文字列を，それらがコネクション上 null で終了していることを仮定せずに，
  コネクションへ・から移動する．
}
\usage{
readChar(con, nchars, useBytes = FALSE)

writeChar(object, con, nchars = nchar(object, type = "chars"),
          eos = "", useBytes = FALSE)
}
\arguments{
  \item{con}{コネクションオブジェクト，又はファイルやバイト型ベクトルの名前を
    与える文字列．}

  \item{nchars}{整数ベクトルで，読み書きされる(未終了の)文字列の文字数単位の長さを
    与える．要素は非負で \code{NA} であってはならない．}

  \item{useBytes}{論理値：\code{readChar} に対しては，
    多バイトロケールで \code{nchars} は文字数ではなくバイト数と
    見做すべきか?  \code{writeChar} に対しては \code{\link{writeLines}} を見よ．}

  \item{object}{コネクションに書き込まれる文字列ベクトルで，
    少なくとも \code{nchars} の長さ．}

  \item{eos}{\sQuote{文字列の終端}: 文字列．各文字列の最後に
    書き込まれる終端子で，ASCII \code{nul} が続く；
    終端子が無ければ \code{NULL} を使う．}
}
\details{
  これらの関数は C 風のゼロで終了する文字列を読み書きする \code{\link{readBin}} と
  \code{\link{writeBin}} を補足する．
  これらは既知の長さの文字列用で，オプションで文字列の終端マークを書くことが出来る．
  これらは現在のロケールで適正な文字列だけを意図している．
  
  これらの関数はバイナリモードのコネクションと共に使われることを
  意図している．
  もし \code{con} が文字列ならば，関数は関数呼び出しの間中開かれているバイナリ
  モードのファイルコネクションを得るために \code{\link{file}} を呼び出す．

  もしコネクションが開かれると，それはその現在の位置から読み書きされる．
  もしそれが開かれていないと，それは呼び出しの間中適当なモード
  (バイナリの読み書き)で開かれ，それから閉じられる．
  開かれたコネクションはバイナリモードで無ければならない．

  もし \code{readChar} がバイト型ベクトルの \code{con} とともに開かれると，
  ベクトル中のデータが入力として使われる．
  もし \code{writeChar} がバイト型ベクトルの \code{con} とともに開かれると，
  それは単にバイト型ベクトルが返されなければならないという指示である．

  ASCII の \code{nul} を含む文字列は
  \code{readChar} で正しく読み取られるが，最初の \code{nul} で
  刈り詰められ警告が出る．

  もし \code{readChar} に対して要求された長さがコネクション上で
  利用可能なデータよりも長ければ，利用できるものが返される．
  \code{writeChar} に対しては，もし多すぎる文字が要求されると
  出力はゼロで埋められ警告が出る．

  欠損した文字列は \code{NA} として書かれる．
}

\value{
  \code{readChar} に対しては長さが読み込まれた項目数の文字列ベクトル
  (\code{length(nchars)} より少ないかもしれない)．

  \code{writeChar} に対してはバイト型ベクトル(もし \code{con} がバイト型
  ベクトルなら)もしくは不可視の \code{NULL}．
}

\note{
  以前のバージョンの \R では文字列中に埋め込まれた nul バイトが許されたが，
  \R >= 2.8.0 では許されない．\code{readChar} はそれに対して \code{readBin} が
  ふさわしくない固定長のゼロで埋められたバイト欄を読むためによく使われた．
  \code{readChar} はもし埋め込みの nul が無ければ，依然としてそうした欄に
  使うことが出来る：さもなければ \code{readBin(what = "raw")} で
  代用できる．

  \code{nchars} は UTF-8 でない多バイトロケール中ではバイト単位ではなく
  文字単位と警告と共に解釈される．

  UTF-8 読み込みでは適正チェックはほとんどされない．

  これらの関数はテキストモードのコネクション上で使えるかもしれないが，
  コネクションへのテキストモードの書き込みと混用すべきではない．
  特にコネクションが \code{encoding} 引数と共に開かれている場合が該当する．
}

\seealso{
  マニュアル \sQuote{R Data Import/Export}．

  \code{\link{connections}}, \code{\link{readLines}},
  \code{\link{writeLines}}, \code{\link{readBin}}
}
\examples{
## 固定長文字列のテスト
zz <- file("testchar", "wb")
x <- c("a", "this will be truncated", "abc")
nc <- c(3, 10, 3)
writeChar(x, zz, nc, eos = NULL)
writeChar(x, zz, eos = "\r\n")
close(zz)

zz <- file("testchar", "rb")
readChar(zz, nc)
readChar(zz, nchar(x)+3) # 終端子を正確に読む必要
close(zz)
unlink("testchar")
}
\keyword{file}
\keyword{connection}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/readChar.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{readChar}
%\alias{readChar}
%\alias{writeChar}
%\title{Transfer Character Strings To and From Connections}
%\description{
%  Transfer character strings to and from connections, without assuming
%  they are null-terminated on the connection.
%}
%\usage{
%readChar(con, nchars, useBytes = FALSE)
%
%writeChar(object, con, nchars = nchar(object, type = "chars"),
%          eos = "", useBytes = FALSE)
%}
%\arguments{
%  \item{con}{A \link{connection} object, or a character string naming a file,
%    or a raw vector.}
%
%  \item{nchars}{integer vector, giving the lengths in characters of
%    (unterminated) character strings to be read or written.  Elements
%    must be >= 0 and not \code{NA}.}
%
%  \item{useBytes}{logical: For \code{readChar}, should \code{nchars} be
%    regarded as a number of bytes not characters in a multi-byte
%    locale?  For \code{writeChar}, see \code{\link{writeLines}}.}
%
%  \item{object}{A character vector to be written to the connection, at
%    least as long as \code{nchars}.}
%
%  \item{eos}{\sQuote{end of string}: character string .  The terminator
%    to be written after each string, followed by an ASCII \code{nul};
%    use \code{NULL} for no terminator at all.}
%}
%\details{
%  These functions complement \code{\link{readBin}} and
%  \code{\link{writeBin}} which read and write C-style zero-terminated
%  character strings.  They are for strings of known length, and
%  can optionally write an end-of-string mark.  They are intended only
%  for character strings valid in the current locale.
%
%  These functions are intended to be used with binary-mode connections.
%  If \code{con} is a character string, the functions call
%  \code{\link{file}} to obtain a binary-mode file connection which is
%  opened for the duration of the function call.
%
%  If the connection is open it is read/written from its current
%  position.  If it is not open, it is opened for the duration of the
%  call in an appropriate mode (binary read or write) and then closed
%  again.  An open connection must be in binary mode.
%
%  If \code{readChar} is called with \code{con} a raw vector, the data in
%  the vector is used as input.  If \code{writeChar} is called with
%  \code{con} a raw vector, it is just an indication that a raw vector
%  should be returned.
%
%  Character strings containing ASCII \code{nul}(s) will be read
%  correctly by \code{readChar} but truncated at the first
%  \code{nul} with a warning.
%
%  If the character length requested for \code{readChar} is longer than
%  the data available on the connection, what is available is
%  returned.  For \code{writeChar} if too many characters are requested
%  the output is zero-padded, with a warning.
%
%  Missing strings are written as \code{NA}.
%}
%
%\value{
%  For \code{readChar}, a character vector of length the number of
%  items read (which might be less than \code{length(nchars)}).
%
%  For \code{writeChar}, a raw vector (if \code{con} is a raw vector) or
%  invisibly \code{NULL}.
%}
%
%\note{
%  Earlier versions of \R allowed embedded nul bytes within character
%  strings, but not \R >= 2.8.0.  \code{readChar} was commonly used to
%  read fixed-size zero-padded byte fields for which \code{readBin} was
%  unsuitable.  \code{readChar} can still be used for such fields if
%  there are no embedded nuls: otherwise \code{readBin(what = "raw")}
%  provides an alternative.
%
%  \code{nchars} will be interpreted in bytes not characters in a
%  non-UTF-8 multi-byte locale, with a warning.
%
%  There is little validity checking of UTF-8 reads.
%
%  Using these functions on a text-mode connection may work but should
%  not be mixed with text-mode access to the connection, especially if
%  the connection was opened with an \code{encoding} argument.
%}
%
%\seealso{
%  The \sQuote{R Data Import/Export} manual.
%
%  \code{\link{connections}}, \code{\link{readLines}},
%  \code{\link{writeLines}}, \code{\link{readBin}}
%}
%\examples{
%## test fixed-length strings
%zz <- file("testchar", "wb")
%x <- c("a", "this will be truncated", "abc")
%nc <- c(3, 10, 3)
%writeChar(x, zz, nc, eos = NULL)
%writeChar(x, zz, eos = "\r\n")
%close(zz)
%
%zz <- file("testchar", "rb")
%readChar(zz, nc)
%readChar(zz, nchar(x)+3) # need to read the terminator explicitly
%close(zz)
%unlink("testchar")
%}
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
