% File src/library/base/man/serialize.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{readRDS}
\alias{readRDS}
\alias{saveRDS}
\title{Serialization Interface for Single Objects}
\description{
  一つの \R オブジェクトをファイルに書き出し，そしてそれを回復する．
}
\usage{
saveRDS(object, file = "", ascii = FALSE, version = NULL,
        compress = TRUE, refhook = NULL)

readRDS(file, refhook = NULL)
}
\arguments{
  \item{object}{シリアル化される \R オブジェクト．}
  \item{file}{\R オブジェクトが保存される，又は読み取られるコネクション又
    ファイルの名前．}
  \item{ascii}{論理値．もし \code{TRUE} か \code{NA} なら，ASCII
    表現が書き込まれる；さもなければ(既定)バイナリなものが使われる．
    \code{\link{save}} のヘルプのコメントを見よ．}
  \item{version}{使用する作業空間の書式バージョン．
    \code{NULL} は現在の既定バージョン(2)を指定する．バージョン 2 以前は
    サポートされないので，これはそれ以降のバージョンがある時だけ関係する．}
  \item{compress}{名前付きファイルへの保存が
    \code{"gzip"} 圧縮を使うかどうかを指示する論理値．又は
    \code{"gzip"}, \code{"bzip2"} 又は \code{"xz"} の一つで使用する圧縮の
    種類を指示する．\code{file} がコネクションなら無視される．}
  \item{refhook}{参照オブジェクトを処理するフック関数．}
}
\details{
  これらの関数は一つの \R オブジェクトをコネクション(普通ファイル)に
  保存し，そしてオブジェクトを，よくある例では別の名前で，回復する．
  これは \code{\link{save}} と \code{\link{load}} とは異なる，
  これらは一つ又はそれ以上の名前付きオブジェクトを保存し，
  環境の中に復元する．これらは \R 自体で広く使われる．
  例えばパッケージのメタデータや \code{\link{help.search}} データベースを
  保管する：ファイル拡張子 \code{".rds"} が最もしばしば使われる．

  関数 \code{\link{serialize}} と \code{\link{unserialize}} は
  シリアル化への少々低レベルのインタフェイスを提供する：
  \code{serialize} によるコネクションへのシリアル化は
  \code{readRDS} によって読み戻され，逆も行われる．

  これらのインタフェイスの全ては同じシリアル化書式を使い，
  それは \R 1.4.0 以来使われている(しかし新しいオブジェクトタイプが
  \R へ付け加えられるたびに時折拡張される)．しかしながら \code{save} は
  一つのオブジェクトのシリアル化の前に一つの行ヘッダ
  (保存される全てのオブジェクトの対リスト)を書き込む．

  \code{file} がファイル名の時圧縮は開かれたコネクションにより
  処理されるので，もしコネクションで処理されるのならば
  \code{file} がコネクションの時だけ可能である．
  従って，例えば\sspace{}\code{\link{url}} コネクションは
  \code{\link{gzcon}} の呼び出し中にラップされる必要がある．

  もしコネクションが与えられると，もし既に開かれていなければ関数の呼び出し
  の間中(バイナリモードで)開かれる：
  もし既に開かれていればそれは
  \code{saveRDS(ascii = FALSE)} に対するバイナリモードであるか，
  非アスキー保存されたものの読み込みでなければならない．
}

\value{
  \code{readRDS} に対しては \R オブジェクト．

  \code{saveRDS} に対しては不可視の \code{NULL}．
}

\seealso{
  \code{\link{serialize}}, \code{\link{save}} そして \code{\link{load}}．

  使われる書式の詳細はマニュアル \sQuote{R Internals}．
}

\examples{
## 一つのオブジェクトをファイルに保存
saveRDS(women, "women.rds")
## 別の名前でそれを快福
women2 <- readRDS("women.rds")
identical(women, women2)
## 又はコネクションを使ってオブジェクトを調べる，コネクションは必要に応じて開かれる
con <- gzfile("women.rds")
readRDS(con)
close(con)

## オブジェクトを回復するより面倒な方法
## これは unserialize() との互換性を示す
con <- gzfile("women.rds", "rb")
identical(unserialize(con), women)
close(con)
con <- gzfile("women.rds", "rb")
wm <- readBin(con, "raw", n = 1e4) # サイズは推測
close(con)
identical(unserialize(wm), women)

## serialize() との書式互換性：
con <- file("women2", "w")
serialize(women, con) # ASCII, 非圧縮
close(con)
identical(women, readRDS("women2"))
con <- bzfile("women3", "w")
serialize(women, con) # バイナリ，bzip2 で圧縮
close(con)
identical(women, readRDS("women2"))

\testonly{unlink(c("women.rds", "women2", "women3"))}
}

\keyword{file}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/serialize.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{readRDS}
%\alias{readRDS}
%\alias{saveRDS}
%\title{Serialization Interface for Single Objects}
%\description{
%  Functions to write a single \R object to a file, and to restore it.
%}
%\usage{
%saveRDS(object, file = "", ascii = FALSE, version = NULL,
%        compress = TRUE, refhook = NULL)
%
%readRDS(file, refhook = NULL)
%}
%\arguments{
%  \item{object}{\R object to serialize.}
%  \item{file}{a \link{connection} or the name of the file where the \R object
%    is saved to or read from.}
%  \item{ascii}{a logical.  If \code{TRUE} or \code{NA}, an ASCII
%    representation is written; otherwise (default), a binary one is used.
%    See the comments in the help for \code{\link{save}}.}
%  \item{version}{the workspace format version to use.  \code{NULL}
%    specifies the current default version (2).  Versions prior to 2 are not
%    supported, so this will only be relevant when there are later versions.}
%  \item{compress}{a logical specifying whether saving to a named file is
%    to use \code{"gzip"} compression, or one of \code{"gzip"},
%    \code{"bzip2"} or \code{"xz"} to indicate the type of compression to
%    be used.  Ignored if \code{file} is a connection.}
%  \item{refhook}{a hook function for handling reference objects.}
%}
%\details{
%  These functions provide the means to save a single \R object to a
%  connection (typically a file) and to restore the object, quite
%  possibly under a different name.  This differs from \code{\link{save}}
%  and \code{\link{load}}, which save and restore one or more named
%  objects into an environment.  They are widely used by \R itself, for
%  example to store metadata for a package and to store the
%  \code{\link{help.search}} databases: the \code{".rds"} file extension
%  is most often used.
%
%  Functions \code{\link{serialize}} and \code{\link{unserialize}}
%  provide a slightly lower-level interface to serialization: objects
%  serialized to a connection by \code{serialize} can be read back by
%  \code{readRDS} and conversely.
%
%  All of these interfaces use the same serialization format, which has
%  been used since \R 1.4.0 (but extended from time to time as new
%  object types have been added to \R).  However, \code{save} writes a
%  single line header (typically \code{"RDXs\n"}) before the
%  serialization of a single object (a pairlist of all the objects to be
%  saved).
%
%  Compression is handled by the connection opened when \code{file} is a
%  file name, so is only possible when \code{file} is a connection if
%  handled by the connection.  So e.g.\sspace{}\code{\link{url}}
%  connections will need to be wrapped in a call to \code{\link{gzcon}}.
%
%  If a connection is supplied it will be opened (in binary mode) for the
%  duration of the function if not already open: if it is already open it
%  must be in binary mode for \code{saveRDS(ascii = FALSE)} or to read
%  non-ASCII saves.
%}
%
%\value{
%  For \code{readRDS}, an \R object.
%
%  For \code{saveRDS}, \code{NULL} invisibly.
%}
%
%\seealso{
%  \code{\link{serialize}}, \code{\link{save}} and \code{\link{load}}.
%
%  The \sQuote{R Internals} manual for details of the format used.
%}
%
%\examples{
%## save a single object to file
%saveRDS(women, "women.rds")
%## restore it under a different name
%women2 <- readRDS("women.rds")
%identical(women, women2)
%## or examine the object via a connection, which will be opened as needed.
%con <- gzfile("women.rds")
%readRDS(con)
%close(con)
%
%## Less convenient ways to restore the object
%## which demonstrate compatibility with unserialize()
%con <- gzfile("women.rds", "rb")
%identical(unserialize(con), women)
%close(con)
%con <- gzfile("women.rds", "rb")
%wm <- readBin(con, "raw", n = 1e4) # size is a guess
%close(con)
%identical(unserialize(wm), women)
%
%## Format compatibility with serialize():
%con <- file("women2", "w")
%serialize(women, con) # ASCII, uncompressed
%close(con)
%identical(women, readRDS("women2"))
%con <- bzfile("women3", "w")
%serialize(women, con) # binary, bzip2-compressed
%close(con)
%identical(women, readRDS("women2"))
%
%\testonly{unlink(c("women.rds", "women2", "women3"))}
%}
%
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
