% File src/library/base/man/seek.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{seek}
\alias{seek}
\alias{seek.connection}
\alias{truncate}
\alias{truncate.connection}
\alias{isSeekable}
\title{Functions to Reposition Connections}
\description{
  Functions to re-position connections.
}
\usage{
seek(con, \dots)
\method{seek}{connection}(con, where = NA, origin = "start", rw = "", \dots)

isSeekable(con)

truncate(con, \dots)
}
\arguments{
  \item{con}{コネクション．}
  \item{where}{数値．ファイル位置(\code{origin} に関して相対的に指定される)，
    または \code{NA}．}
  \item{rw}{文字列．空または \code{"read"} また \code{"write"}，
    部分マッチが許される．}
  \item{origin}{文字列．\code{"start"}, \code{"current"},
    \code{"end"} の一つ：\sQuote{詳細}を見よ．}
  \item{\dots}{他のメソッドに・から引き渡す追加引数．}
}
\details{
  \code{where = NA} を使った \code{seek} は(最初からの)コネクションの
  現在のバイトオフセットを返す．そして \code{where} 引数が欠けていなければ
  コネクションは(もし可能ならば)指定位置に再位置決めされる．
  \code{isSeekable} はコネクションが原理的に \code{seek} をサポートするかどうかを
  返す：現在ファイルコネクション(可能性として gz 圧縮された)だけが
  サポートされている．

  \code{where} は実数として保管されるが整数を表現する：
  整数でない値は恐らく切り詰められる．可能な値は
  64 ビットそしてある 32 ビット構築では，位置は \R の整数で表現できる最大整数を
  超えることが出来ることを注意する．

  ファイルコネクションは書き込みと追加双方で開くことが出来る．
  その場合 \R は読み取りと書き込み用に別々の位置を維持する．
  \code{seek} が何を参照するかはその \code{rw} によって設定できる：
  既定値は使われた最後の(読み取りと書き込み)モードである．
  殆どのファイルは読み取り又は書き込み専用に開かれるために
  既定値はその状態にされる．もしファイルが読み書き双方で開かれたが
  使われていなければ，既定値は読み取り位置 (0) を与える．

  読み取りの初期位置は常に初めにある．
  書き込みに対する初期位置はモード \code{"r+"} と \code{"r+b"} では
  ファイルの始めであり，さもなければ追加モードではファイルの最後になる．
  ある種のプラットフォームは追加モードではファイルの最後だけで書き込みを
  許す．(追加モードで開かれたファイルに対する報告される書き込み位置は
  典型的にはファイルが書き込まれるまでは信頼できない．)

  \code{gzfile} コネクションは，非圧縮ファイルのファイル位置を使って，
  幾つかの制限下で \code{seek} をサポートする．
  それらは \code{origin = "end"} をサポートしない．書き込みの際は，
  シークは前方にだけ許される：
  読み込みの後方へのシークはファイルを巻き戻しそしてその最初から
  再読み込みすることでサポートされる．

  もし \code{seek} が \code{NA} で無い \code{where} の値で呼び出されると，
  任意のテキストモードでのプッシュバックは捨て去られる．

  \code{truncate} は書き込みに対して開かれたファイルをその現在の位置で
  切り詰める．これは \code{file} コネクションに対してだけ動作し，
  全てのプラットフォーム上でサポートされていない：
  他のプラットフォーム(Windows を含む)ではこれは大きな(> 2Gb)ファイルに対しては
  動作しない．

  これらのどれもが，再エンコーディングが選ばれたテキストコネクション
  上では動作するとは期待されていない．
}
\section{警告}{
  Windows 上で \code{seek} を使うことは勧められない．Windows のファイル
  の位置決めには相当多くのエラーが見つかっており，ユーザは自分自身のリスクで
  それを使うことがアドバイスされる．そして  Windows の不完全さに関する
  バグ報告で \R 開発者の時間を浪費しないようにして欲しい．
}
\value{
  \code{seek} は現在の位置を返す(任意の移動の前に)，
  もし関連があれば(数値)原点からのバイトのオフセット，さもなければ \code{0}．
  64 ビットそしてある 32 ビット構築では，位置は \R の整数で表現できる最大整数を
  超えることが出来る．

  \code{truncate} は \code{NULL} を返す：これはもしそれが失敗すれば
  (又は実装されていなければ)エラーと共に停止する．

  \code{isSeekable} はコネクションが \code{seek} をサポートするか
  どうかを示す論理値を返す．
}
\seealso{
  \code{\link{connections}}
}
\keyword{file}
\keyword{connection}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/seek.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{seek}
%\alias{seek}
%\alias{seek.connection}
%\alias{truncate}
%\alias{truncate.connection}
%\alias{isSeekable}
%\title{Functions to Reposition Connections}
%\description{
%  Functions to re-position connections.
%}
%\usage{
%seek(con, \dots)
%\method{seek}{connection}(con, where = NA, origin = "start", rw = "", \dots)
%
%isSeekable(con)
%
%truncate(con, \dots)
%}
%\arguments{
%  \item{con}{a \link{connection}.}
%  \item{where}{numeric.  A file position (relative to the origin
%    specified by \code{origin}), or \code{NA}.}
%  \item{rw}{character string.  Empty or \code{"read"} or \code{"write"},
%    partial matches allowed.}
%  \item{origin}{character string.  One of \code{"start"}, \code{"current"},
%    \code{"end"}: see \sQuote{Details}.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\details{
%  \code{seek} with \code{where = NA} returns the current byte offset
%  of a connection (from the beginning), and with a non-missing \code{where}
%  argument the connection is re-positioned (if possible) to the
%  specified position.  \code{isSeekable} returns whether the connection
%  in principle supports \code{seek}: currently only (possibly
%  gz-compressed) file connections do.
%
%  \code{where} is stored as a real but should represent an integer:
%  non-integer values are likely to be truncated.  Note that the possible
%  values can exceed the largest representable number in an \R
%  \code{integer} on 64-bit builds, and on some 32-bit builds.
%
%  File connections can be open for both writing/appending, in which case
%  \R keeps separate positions for reading and writing.  Which \code{seek}
%  refers to can be set by its \code{rw} argument: the default is the
%  last mode (reading or writing) which was used.  Most files are
%  only opened for reading or writing and so default to that state.  If a
%  file is open for both reading and writing but has not been used, the
%  default is to give the reading position (0).
%
%  The initial file position for reading is always at the beginning.
%  The initial position for writing is at the beginning of the file
%  for modes \code{"r+"} and \code{"r+b"}, otherwise at the end of the
%  file.  Some platforms only allow writing at the end of the file in
%  the append modes.  (The reported write position for a file opened in
%  an append mode will typically be unreliable until the file has been
%  written to.)
%
%  \code{gzfile} connections support \code{seek} with a number of
%  limitations, using the file position of the uncompressed file.
%  They do not support \code{origin = "end"}.  When writing, seeking is
%  only possible forwards: when reading seeking backwards is supported by
%  rewinding the file and re-reading from its start.
%
%  If \code{seek} is called with a non-\code{NA} value of \code{where},
%  any pushback on a text-mode connection is discarded.
%
%  \code{truncate} truncates a file opened for writing at its current
%  position.  It works only for \code{file} connections, and is not
%  implemented on all platforms: on others (including Windows) it will
%  not work for large (> 2Gb) files.
%
%  None of these should be expected to work on text-mode connections with
%  re-encoding selected.
%}
%\section{Warning}{
%  Use of \code{seek} on Windows is discouraged.  We have found so many
%  errors in the Windows implementation of file positioning that users
%  are advised to use it only at their own risk, and asked not to waste
%  the \R developers' time with bug reports on Windows' deficiencies.
%}
%\value{
%  \code{seek} returns the current position (before any move), as a
%  (numeric) byte offset from the origin, if relevant, or \code{0} if
%  not.  Note that the position can exceed the largest representable
%  number in an \R \code{integer} on 64-bit builds, and on some 32-bit
%  builds.
%
%  \code{truncate} returns \code{NULL}: it stops with an error if
%  it fails (or is not implemented).
%
%  \code{isSeekable} returns a logical value, whether the connection
%  supports \code{seek}.
%}
%\seealso{
%  \code{\link{connections}}
%}
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
