% File src/library/base/man/windows/shell.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{shell}
\Rdversion{1.1}
\alias{shell}
\title{Invoke a System Command, using a Shell}

\usage{
shell(cmd, shell, flag = "/c", intern = FALSE, wait = TRUE,
      translate = FALSE, mustWork = FALSE, ...)
}

\arguments{
  \item{cmd}{起動されるべき命令，文字列として与えられる．}
  \item{shell}{使用されるシェルの名前を与える文字列，又は
    \code{NULL} (シェル無し)．もし欠損していれば適当なシェルが選ばれる：
    \sQuote{詳細}を見よ．}
  \item{flag}{シェルのもとで命令を実行するスィッチ．もしシェルが
  \code{bash} か \code{tcsh} か \code{sh} ならば，既定値は \code{"-c"} に替えられる．}
  \item{intern}{論理値，命令の出力を \R オブジェクトにするかどうかを指示する．}
  \item{wait}{\R インタープリタは命令が終わるのを待つか?
    既定では待つ．そしてインタープリタは \code{intern = TRUE} ならば常に待つ．}
  \item{translate}{もし \code{TRUE} ならば \code{cmd} 中の \samp{"/"} は
    \samp{"\\"} に翻訳される．}
  \item{mustWork}{論理値；もし \code{TRUE} ならば命令の実行が失敗すると
    \R のエラーになる．もし \code{FALSE} ならば警告，\code{NA} ならば
    \R のメッセージは無い．}
  \item{\dots}{\code{\link{system}} への追加引数．}
}

\description{
  \code{shell} は \code{cmd} で指定される命令を普通シェルの下で実行する．
  これは POSIX 標準が要求するものである．
}

\value{
  もし \code{intern = TRUE} ならば命令の出力を与える文字列ベクトルで
  文字列ごとに一行になる．又は命令が実行できなければエラーメッセージ．

  もし \code{intern = FALSE} ならば返り値はエラーコードで
  不可視属性が与えられている(従って明示的にプリントする必要がある)．もし何らかの
  理由で命令が実行できなければ値は \code{-1} で \R の警告が出る．
  さもなければ，もし \code{wait = FALSE} ならば値は命令が返すエラーコードであり，
  そしてもし \code{wait = TRUE} ならばそれはゼロになる
  (便宜的な成功値)．

  もし \code{intern = FALSE} で \code{wait = TRUE} (既定値)ならば
  コンソールアプリケーションである命令が
  テキスト出力が \R のコンソールか \R を実行しているウィンドウ(\code{Rterm})
  に現れる．
}

\details{
  もしどのシェルも指定されないと環境変数
  \env{R_SHELL} と \env{COMSPEC} が順に試される：\env{COMSPEC}
  は常に成功すべきである．\code{shell = NULL} を使うと命令 
  \code{cmd} が直接起動されるが，拡張子 \file{.exe} が仮定される．
  もし拡張子が与えられれば直接バッチファイルを使うことが可能である：
  そうすると Windows (\R ではなく)がシェルを選択する．

  より完全な詳細は \code{\link{system}} を見よ：
  \code{shell} は \code{system} に対するよりわかりやすい
  ラッパである．Windows のファイルアソシエーションを使うには
  \code{\link{shell.exec}} を利用する．
}

\note{
  この関数は Windows でだけ存在する：全ての他のプラットフォームでは
  \code{\link{system}} はシェルを利用する．
}

\seealso{\code{\link{system}}, \code{\link{shell.exec}}}

\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/windows/shell.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{shell}
%\Rdversion{1.1}
%\alias{shell}
%\title{Invoke a System Command, using a Shell}
%
%\usage{
%shell(cmd, shell, flag = "/c", intern = FALSE, wait = TRUE,
%      translate = FALSE, mustWork = FALSE, ...)
%}
%
%\arguments{
%  \item{cmd}{the system command to be invoked, as a string.}
%  \item{shell}{a string giving the name of the shell to be used, or
%    \code{NULL} (no shell).  If missing, a suitable shell is chosen:
%    see \sQuote{Details}.}
%  \item{flag}{the switch to run a command under the shell.  If the shell
%  is \code{bash} or \code{tcsh} or \code{sh} the default is changed to
%  \code{"-c"}.}
%  \item{intern}{a logical, indicates whether to make the output of the
%    command an \R object.}
%  \item{wait}{should the \R interpreter wait for the command to finish?
%    The default is to wait, and the interpreter will always wait if
%    \code{intern = TRUE}.}
%  \item{translate}{If \code{TRUE}, \samp{"/"} in \code{cmd} is
%    translated to \samp{"\\"}.}
%  \item{mustWork}{a logical; if \code{TRUE} failure to run the command
%    will give an \R error, if \code{FALSE} a warning and if \code{NA},
%    no \R message.}
%  \item{\dots}{additional arguments to \code{\link{system}}.}
%}
%
%\description{
%  \code{shell} runs the command specified by \code{cmd}, usually under
%  a shell, because that is what the POSIX standards require.
%}
%
%\value{
%  If \code{intern = TRUE}, a character vector giving the output of the
%  command, one line per character string, or an error message if the
%  command could not be run.
%
%  If \code{intern = FALSE}, the return value is an error code, given the
%  invisible attribute (so needs to be printed explicitly).  If the
%  command could not be run for any reason, the value is \code{-1} and
%  an \R warning is generated.  Otherwise if \code{wait = FALSE} the value
%  is the error code returned by the command, and if \code{wait = TRUE}
%  it is the zero (the conventional success value),
%
%  If \code{intern = FALSE} and \code{wait = TRUE} (the defaults) the text
%  output from a command that is a console application will appear in
%  the \R console (\code{Rgui}) or the window running \R (\code{Rterm}).
%}
%
%\details{
%  If no \code{shell} is specified, the environment variables
%  \env{R_SHELL} and \env{COMSPEC} are tried in turn: \env{COMSPEC}
%  should always succeed.  Using \code{shell = NULL} invokes the command
%  \code{cmd} directly, in which case an extension of \file{.exe} is
%  assumed.  It is possible to use batch files directly if their
%  extension is given: Windows (rather than \R) then chooses a shell.
%
%  See \code{\link{system}} for fuller details: \code{shell} is a more
%  user-friendly wrapper for \code{system}.  To make use of Windows
%  file associations, use \code{\link{shell.exec}}.
%}
%
%\note{
%  This function exists only on Windows: on all other platform
%  \code{\link{system}} uses a shell.
%}
%
%\seealso{\code{\link{system}}, \code{\link{shell.exec}}}
%
%\keyword{utilities}
%
\encoding{UTF8}
