% File src/library/base/man/table.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{table}
\title{Cross Tabulation and Table Creation}
\alias{table}
\alias{summary.table}
\alias{print.summary.table}%% {print.table} is in ./print.Rd
\alias{as.data.frame.table}
\alias{as.table}
\alias{as.table.default}
\alias{is.table}

\concept{counts}
\concept{frequencies}
\concept{occurrences}
\concept{contingency table}

\description{
  \code{table} は因子水準の各組み合わせ毎の集計の分割表を作るために
  クロス集計因子を作る．
}
\usage{
table(\dots, exclude = if (useNA == "no") c(NA, NaN), useNA = c("no",
    "ifany", "always"), dnn = list.names(\dots), deparse.level = 1)

as.table(x, \dots)
is.table(x)

\method{as.data.frame}{table}(x, row.names = NULL, \dots,
              responseName = "Freq", stringsAsFactors = TRUE,
              sep = "", base = list(LETTERS))
}
\arguments{
  \item{\dots}{因子(文字列を含む)として解釈できる一つ又はそれ以上のオブジェクト，
    又はその成分がそのように解釈できるリスト(データフレーム)．
    (\code{as.table} に対して引数は指定されたメソッドに渡される；
    \code{as.data.frame} に対しては使用されない．)}
  \item{exclude}{\code{\dots} 中の全ての因子に対して除かれる水準．
    もし \code{NULL} に設定するとそれは \code{useNA = "always"} を意味する．
    非因子引数に対するその解釈については\sQuote{詳細}を参照．}
  \item{useNA}{テーブルに \code{NA} 値を含むか．
    \sQuote{詳細}を見よ．短縮出来る．}
  \item{dnn}{結果中の次元に与えられる名前
    (\emph{次元名の名前})．}
  \item{deparse.level}{既定の \code{dnn} をどのように構成するかを制御する．
    \sQuote{詳細}を見よ．}
  \item{x}{任意の \R オブジェクト，又は \code{as.data.frame} メソッドに対しては
    クラス \code{"table"} を継承するオブジェクト．
    \code{as.data.frame.table(x, *)} はテーブルでない \code{x} に対しては
    配列を再整形するためには明示的に呼びだされるかもしれない．}
  \item{row.names}{データフレームに対して行名を与える文字列．}
  \item{responseName}{テーブル項目に対して使われる名前で，普通計数．}
  \item{stringsAsFactors}{論理値：分類因子は因子として返される(既定)べきか
    文字列にすべきか?}
  \item{sep, base}{\code{\link{provideDimnames}} に渡される．}
}
\details{
  もし引数 \code{dnn} が提供されないと，内部関数
  \code{list.names} が\sQuote{次元名の名前}を計算するために呼び出される．
  もし \code{\dots} 中の引数が名前を持てば，これらの名前が使われる．
  残りの引数に対しては \code{deparse.level = 0} は空の名前を与え，
  \code{deparse.level = 1} はもしそれがシンボルならば与えられた引数を使い，
  そして \code{deparse.level = 2} は引数を逆構文解析する．

  \code{exclude} が指定され NULL でない時だけ(つまり既定ではない)，
  \code{table} は因子引数の水準を捨てる可能性がある．

  \code{useNA} はテーブルが \code{NA} 値のカウントを含むかどうかを制御する：
  カウントが正の時だけ，そしてゼロカウントに対してすら
  許された値は決して対応しない．
  これは \code{exclude = NULL} を指定することで上書きされる．
  \code{exclude} で指定された水準は
  \code{NA} にマップされ，従って \code{NA} カウントに含められる
  ことを注意する．

  \code{exclude} と \code{useNA} の双方は "全てか皆無か" 原則の上で動作する．
  もし多元テーブルの次元を個別に制御したければ，
  各引数を \code{\link{factor}} か \code{\link{addNA}} を使って修正する．

  変換に頼るよりは因子を提供するのが最良である．特に，
  \code{exclude} は因子への変換に使われ，そして
  変換前に \code{exclude} 中に現れる値(水準では無く)は
  捨て去られる代わりに \code{NA} にマップされる．

  クラス \code{"table"} に対する \code{summary} メソッド(
  \code{table} や \code{\link{xtabs}} で作られたオブジェクトに対して
  使われる) は基本的情報を与え，因子の独立性に対するカイ二乗検定を
  実行する(関数 \code{\link{chisq.test}} は現在二元テーブル
  だけを扱える)．
}
\value{
  \code{table()} は\emph{分割表}を返す．これはクラス \code{"table"} のオブジェクト
  で整数値の配列である．
  S とは異なり結果は常に配列で，因子が一つなら一次元配列である．

  \code{as.table} と \code{is.table} はそれぞれ分割表に変換しテストする．

  クラス \code{"table"} を継承するオブジェクトに対する \code{as.data.frame}
  メソッドは分割表の配列を基礎とする表現を分類因子と対応項目を含む
  データフレームに変換される(後者は \code{responseName} という名前の
  成分になる)．これは \code{\link{xtabs}} の逆操作である．
}
\seealso{
  \code{\link{tabulate}} は基礎にある関数でより細かな制御を許す．

  多次元テーブルのプリント(そしてそれ以上)に対しては \code{\link{ftable}} を使う．
  \code{\link{margin.table}}, \code{\link{prop.table}}, \code{\link{addmargins}}.

  公式インタフェイスを使ったデータフレームのクロス集計に対しては \code{\link{xtabs}}．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
require(stats) # rpois と xtabs に対して
## 簡単な頻度分布
table(rpois(100, 5))
## デザインのチェック：
with(warpbreaks, table(wool, tension))
table(state.division, state.region)

# 簡単な二元分類表
with(airquality, table(cut(Temp, quantile(Temp)), Month))

a <- letters[1:3]
table(a, sample(a))                    # dnn は c("a", "")
table(a, sample(a), deparse.level = 0) # dnn は c("", "")
table(a, sample(a), deparse.level = 2) # dnn は c("a", "sample(a)")

## xtabs() <-> as.data.frame.table() :
UCBAdmissions ## 既に分割表
DF <- as.data.frame(UCBAdmissions)
class(tab <- xtabs(Freq ~ ., DF)) # xtabs & table
## tab は元のテーブルと同じ
all(tab == UCBAdmissions)
all.equal(dimnames(tab), dimnames(UCBAdmissions))

a <- rep(c(NA, 1/0:3), 10)
table(a)
table(a, exclude = NULL)
b <- factor(rep(c("A","B","C"), 10))
table(b)
table(b, exclude = "B")
d <- factor(rep(c("A","B","C"), 10), levels = c("A","B","C","D","E"))
table(d, exclude = "B")
print(table(b, d), zero.print = ".")

## NA のカウント：
is.na(d) <- 3:4
d. <- addNA(d)
d.[1:7]
table(d.) # ", exclude = NULL" は不要
## つまり 'd' の NA をカウントしたければ
table(d, useNA = "ifany")

## NA のカウントを持つ二元テーブル．三番目の変種は馬鹿げているが，しかし
## exclude や useNA 使って出来ない事柄を示している.
with(airquality,
   table(OzHi = Ozone > 80, Month, useNA = "ifany"))
with(airquality,
   table(OzHi = Ozone > 80, Month, useNA = "always"))
with(airquality,
   table(OzHi = Ozone > 80, addNA(Month)))
}
\keyword{category}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/table.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{table}
%\title{Cross Tabulation and Table Creation}
%\alias{table}
%\alias{summary.table}
%\alias{print.summary.table}%% {print.table} is in ./print.Rd
%\alias{as.data.frame.table}
%\alias{as.table}
%\alias{as.table.default}
%\alias{is.table}
%
%\concept{counts}
%\concept{frequencies}
%\concept{occurrences}
%\concept{contingency table}
%
%\description{
%  \code{table} uses the cross-classifying factors to build a contingency
%  table of the counts at each combination of factor levels.
%}
%\usage{
%table(\dots, exclude = if (useNA == "no") c(NA, NaN), useNA = c("no",
%    "ifany", "always"), dnn = list.names(\dots), deparse.level = 1)
%
%as.table(x, \dots)
%is.table(x)
%
%\method{as.data.frame}{table}(x, row.names = NULL, \dots,
%              responseName = "Freq", stringsAsFactors = TRUE,
%              sep = "", base = list(LETTERS))
%}
%\arguments{
%  \item{\dots}{one or more objects which can be interpreted as factors
%    (including character strings), or a list (or data frame) whose
%    components can be so interpreted.  (For \code{as.table}, arguments
%    passed to specific methods; for \code{as.data.frame}, unused.)}
%  \item{exclude}{levels to remove for all factors in \code{\dots}.
%    If set to \code{NULL}, it implies \code{useNA = "always"}.  See
%    \sQuote{Details} for its interpretation for non-factor arguments.}
%  \item{useNA}{whether to include \code{NA} values in the table.
%    See \sQuote{Details}.  Can be abbreviated.}
%  \item{dnn}{the names to be given to the dimensions in the result (the
%    \emph{dimnames names}).}
%  \item{deparse.level}{controls how the default \code{dnn} is
%    constructed.  See \sQuote{Details}.}
%  \item{x}{an arbitrary \R object, or an object inheriting from class
%    \code{"table"} for the \code{as.data.frame} method. Note that
%    \code{as.data.frame.table(x, *)} may be called explicitly for
%    non-table \code{x} for \dQuote{reshaping} \code{\link{array}}s.}
%  \item{row.names}{a character vector giving the row names for the data
%    frame.}
%  \item{responseName}{The name to be used for the column of table
%    entries, usually counts.}
%  \item{stringsAsFactors}{logical: should the classifying factors be
%    returned as factors (the default) or character vectors?}
%  \item{sep, base}{passed to \code{\link{provideDimnames}}.}
%}
%\details{
%  If the argument \code{dnn} is not supplied, the internal function
%  \code{list.names} is called to compute the \sQuote{dimname names}.  If the
%  arguments in \code{\dots} are named, those names are used.  For the
%  remaining arguments, \code{deparse.level = 0} gives an empty name,
%  \code{deparse.level = 1} uses the supplied argument if it is a symbol,
%  and \code{deparse.level = 2} will deparse the argument.
%
%  Only when \code{exclude} is specified and non-NULL (i.e., not by
%  default), will \code{table} potentially drop levels of factor
%  arguments.
%
%  \code{useNA} controls if the table includes counts of \code{NA}
%  values: the allowed values correspond to never, only if the count is
%  positive and even for zero counts.  This is overridden by specifying
%  \code{exclude = NULL}.  Note that levels specified in \code{exclude}
%  are mapped to \code{NA} and so included in \code{NA} counts.
%
%  Both \code{exclude} and \code{useNA} operate on an "all or none"
%  basis.  If you want to control the dimensions of a multiway table
%  separately, modify each argument using \code{\link{factor}} or
%  \code{\link{addNA}}.
%
%  It is best to supply factors rather than rely on coercion.  In
%  particular, \code{exclude} will be used in coercion to a factor, and
%  so values (not levels) which appear in \code{exclude} before coercion
%  will be mapped to \code{NA} rather than be discarded.
%
%  The \code{summary} method for class \code{"table"} (used for objects
%  created by \code{table} or \code{\link{xtabs}}) which gives basic
%  information and performs a chi-squared test for independence of
%  factors (note that the function \code{\link{chisq.test}} currently
%  only handles 2-d tables).
%}
%\value{
%  \code{table()} returns a \emph{contingency table}, an object of
%  class \code{"table"}, an array of integer values.
%  Note that unlike S the result is always an array, a 1D array if one
%  factor is given.
%
%  \code{as.table} and \code{is.table} coerce to and test for contingency
%  table, respectively.
%
%  The \code{as.data.frame} method for objects inheriting from class
%  \code{"table"} can be used to convert the array-based representation
%  of a contingency table to a data frame containing the classifying
%  factors and the corresponding entries (the latter as component
%  named by \code{responseName}).  This is the inverse of \code{\link{xtabs}}.
%}
%\seealso{
%  \code{\link{tabulate}} is the underlying function and allows finer
%  control.
%
%  Use \code{\link{ftable}} for printing (and more) of
%  multidimensional tables.  \code{\link{margin.table}},
%  \code{\link{prop.table}}, \code{\link{addmargins}}.
%
%  \code{\link{xtabs}} for cross tabulation of data frames with a
%  formula interface.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%require(stats) # for rpois and xtabs
%## Simple frequency distribution
%table(rpois(100, 5))
%## Check the design:
%with(warpbreaks, table(wool, tension))
%table(state.division, state.region)
%
%# simple two-way contingency table
%with(airquality, table(cut(Temp, quantile(Temp)), Month))
%
%a <- letters[1:3]
%table(a, sample(a))                    # dnn is c("a", "")
%table(a, sample(a), deparse.level = 0) # dnn is c("", "")
%table(a, sample(a), deparse.level = 2) # dnn is c("a", "sample(a)")
%
%## xtabs() <-> as.data.frame.table() :
%UCBAdmissions ## already a contingency table
%DF <- as.data.frame(UCBAdmissions)
%class(tab <- xtabs(Freq ~ ., DF)) # xtabs & table
%## tab *is* "the same" as the original table:
%all(tab == UCBAdmissions)
%all.equal(dimnames(tab), dimnames(UCBAdmissions))
%
%a <- rep(c(NA, 1/0:3), 10)
%table(a)
%table(a, exclude = NULL)
%b <- factor(rep(c("A","B","C"), 10))
%table(b)
%table(b, exclude = "B")
%d <- factor(rep(c("A","B","C"), 10), levels = c("A","B","C","D","E"))
%table(d, exclude = "B")
%print(table(b, d), zero.print = ".")
%
%## NA counting:
%is.na(d) <- 3:4
%d. <- addNA(d)
%d.[1:7]
%table(d.) # ", exclude = NULL" is not needed
%## i.e., if you want to count the NA's of 'd', use
%table(d, useNA = "ifany")
%
%## Two-way tables with NA counts. The 3rd variant is absurd, but shows
%## something that cannot be done using exclude or useNA.
%with(airquality,
%   table(OzHi = Ozone > 80, Month, useNA = "ifany"))
%with(airquality,
%   table(OzHi = Ozone > 80, Month, useNA = "always"))
%with(airquality,
%   table(OzHi = Ozone > 80, addNA(Month)))
%}
%\keyword{category}
%\encoding{UTF8}

\encoding{UTF8}

