% File src/library/graphics/man/plot.table.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{plot.table}
\alias{plot.table}
\alias{lines.table}
\alias{points.table}
\title{Plot Methods for \code{table} Objects}
\description{
  これは総称的関数 \code{plot} の
  (分割表) \code{\link{table}} オブジェクトに対する
  メソッドである．一方2次元もしくはそれ以上のテーブルに対しては
  \code{\link{mosaicplot}} が描かれる．
  1次元ならば棒として描かれる．
}
\usage{
\method{plot}{table}(x, type = "h", ylim = c(0, max(x)), lwd = 2,
     xlab = NULL, ylab = NULL, frame.plot = is.num, \dots)
\method{points}{table}(x, y = NULL, type = "h", lwd = 2, \dots)
\method{lines}{table}(x, y = NULL, type = "h", lwd = 2, \dots)
}
\arguments{
  \item{x}{\code{\link{table}} (風)オブジェクト．}
  \item{y}{\code{NULL} で無ければならない：不正な呼び出しの防止のためにある．}
  \item{type}{プロットタイプ．}
  \item{ylim}{y 軸の範囲．}
  \item{lwd}{1次元ケースで \code{type = "h"} が使われた時の棒の線幅．}
  \item{xlab, ylab}{x と y 軸ラベル．}
  \item{frame.plot}{1次元ケースで枠(\code{\link{box}})を描くべきかどうかを指示する論理値．
    \code{x} が数値に変換可能な次元名を持てば既定値は真．}
  \item{\dots}{追加のグラフィカルパラメータ，\code{\link{plot.default}} を見よ．
    \code{axes = FALSE} が受け入れられる．}
}
\seealso{
  因子に対する \code{\link{plot.factor}}, the \code{\link{plot}} メソッド．
}

\examples{
## 1次元テーブル
(Poiss.tab <- table(N = stats::rpois(200, lambda = 5)))
plot(Poiss.tab, main = "plot(table(rpois(200, lambda = 5)))")

plot(table(state.division))

## 4次元：
plot(Titanic, main ="plot(Titanic, main= *)")

}
\keyword{hplot}
\keyword{category}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/plot.table.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{plot.table}
%\alias{plot.table}
%\alias{lines.table}
%\alias{points.table}
%\title{Plot Methods for \code{table} Objects}
%\description{
%  This is a method of the generic \code{plot} function for
%  (contingency) \code{\link{table}} objects.  Whereas for two- and more
%  dimensional tables, a \code{\link{mosaicplot}} is drawn,
%  one-dimensional ones are plotted as bars.
%}
%\usage{
%\method{plot}{table}(x, type = "h", ylim = c(0, max(x)), lwd = 2,
%     xlab = NULL, ylab = NULL, frame.plot = is.num, \dots)
%\method{points}{table}(x, y = NULL, type = "h", lwd = 2, \dots)
%\method{lines}{table}(x, y = NULL, type = "h", lwd = 2, \dots)
%}
%\arguments{
%  \item{x}{a \code{\link{table}} (like) object.}
%  \item{y}{Must be \code{NULL}: there to protect against incorrect calls.}
%  \item{type}{plotting type.}
%  \item{ylim}{range of y-axis.}
%  \item{lwd}{line width for bars when \code{type = "h"} is used in the 1D case.}
%  \item{xlab, ylab}{x- and y-axis labels.}
%  \item{frame.plot}{logical indicating if a frame (\code{\link{box}})
%    should be drawn in the 1D case.  Defaults to true when \code{x} has
%    \code{\link{dimnames}} coerce-able to numbers.}
%  \item{\dots}{further graphical arguments, see \code{\link{plot.default}}.
%    \code{axes = FALSE} is accepted.}
%}
%\seealso{
%  \code{\link{plot.factor}}, the \code{\link{plot}} method for factors.
%}
%
%\examples{
%## 1-d tables
%(Poiss.tab <- table(N = stats::rpois(200, lambda = 5)))
%plot(Poiss.tab, main = "plot(table(rpois(200, lambda = 5)))")
%
%plot(table(state.division))
%
%## 4-D :
%plot(Titanic, main ="plot(Titanic, main= *)")
%
%}
%\keyword{hplot}
%\keyword{category}
%
%\encoding{UTF8}
%