% File src/library/stats/man/Cauchy.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Cauchy}
\alias{Cauchy}%@%\alias{コーシー分布}
\alias{dcauchy}
\alias{pcauchy}
\alias{qcauchy}
\alias{rcauchy}
\title{The Cauchy Distribution}
\description{
  位置パラメータ \code{location} とスケールパラメーター \code{scale}
  を持つコーシー分布に対する密度，分布関数と乱数生成．
}
\usage{
dcauchy(x, location = 0, scale = 1, log = FALSE)
pcauchy(q, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
qcauchy(p, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
rcauchy(n, location = 0, scale = 1)
}
\arguments{
  \item{x, q}{クォンタイルのベクトル．}
  \item{p}{確率のベクトル．}
  \item{n}{観測値数．もし \code{length(n) > 1} なら長さが
    必要な個数とされる．}
  \item{location, scale}{位置とスケールパラメータ．}
  \item{log, log.p}{論理値；もし TRUE なら確率 p は log(p) とされる．}
  \item{lower.tail}{論理値；もし TRUE (既定値)なら
    確率は \eqn{P[X \le x]} で，さもなければ \eqn{P[X > x]}．}
}
\value{
  \code{dcauchy} は密度，\code{pcauchy} は分布関数，
  \code{qcauchy} はクォンタイル関数，そして
  \code{rcauchy} は乱数を生成する．
  
  \code{rcauchy} に対しては結果の長さは \code{n} で決まり，．
  そして他の関数に対しては数値引数の最大長である．

  \code{n} 以外の数値引数は結果の長さまでリサイクルされる．
  論理値引数は最初の要素だけが使われる．
}
\details{
  もし \code{location} 又は \code{scale} が指定されないと，
  それらはそれぞれ既定値 \code{0} と \code{1} とされる．

  位置 \eqn{l} でスケール \eqn{s} を持つコーシー分布は
  全ての \eqn{x} に対して密度
  \deqn{f(x) = \frac{1}{\pi s}
    \left( 1 + \left(\frac{x - l}{s}\right)^2 \right)^{-1}%
  }{f(x) = 1 / (\pi s (1 + ((x-l)/s)^2))}
  を持つ．
}
\source{
  \code{dcauchy}，\code{pcauchy} そして \code{qcauchy} は全て
  定義の数値的に安定したバージョンから計算される．

  \code{rcauchy} は逆関数を使う．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Johnson, N. L., Kotz, S. and Balakrishnan, N. (1995)
  \emph{Continuous Univariate Distributions}, volume 1, chapter 16.
  Wiley, New York.
}
\seealso{
  \code{dcauchy(*, l = 0, s = 1)} を拡張する
   t 分布 \code{\link{dt}} を含む他の分布は
   \link{Distributions}．
}
\examples{
dcauchy(-1:4)
}
\keyword{distribution}

\encoding{UTF-8}
