% File src/library/stats/man/Logistic.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Logistic}
\alias{Logistic}%@%\alias{ロジスティック分布}
\alias{dlogis}
\alias{plogis}
\alias{qlogis}
\alias{rlogis}
\title{The Logistic Distribution}
\concept{logit}
\concept{sigmoid}
\description{
  パラメータ \code{location} と \code{scale}
  のロジスティック分布に対する密度，分布関数，クォンタイル関数と乱数生成．
}
\usage{
dlogis(x, location = 0, scale = 1, log = FALSE)
plogis(q, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
qlogis(p, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
rlogis(n, location = 0, scale = 1)
}
\arguments{
  \item{log, log.p}{logical; if TRUE, probabilities p are given as log(p).}
  \item{lower.tail}{logical; if TRUE (default), probabilities are
    \eqn{P[X \le x]}, otherwise, \eqn{P[X > x]}.}
  \item{x, q}{クォンタイルのベクトル．}
  \item{p}{確率のベクトル．}
  \item{n}{観測値数．もし \code{length(n) > 1} なら長さが
    必要な個数とされる．}
  \item{location, scale}{位置とスケールパラメータ．}
  \item{log, log.p}{論理値；もし TRUE なら確率 p は log(p) とされる．}
  \item{lower.tail}{論理値；もし TRUE (既定値)なら
    確率は \eqn{P[X \le x]} で，さもなければ \eqn{P[X > x]}．}
}
\value{
  \code{dlogis} は密度，\code{plogis} は分布関数，
  \code{qlogis} はクォンタイル関数，そして
  \code{rlogis} は乱数を生成する．

  不正な引数は値 \code{NaN} を返し，警告が出る．

  \code{rlogis} に対しては結果の長さは \code{n} で決まり，
  そして他の関数に対しては数値引数の最大長である．

  \code{n} 以外の数値引数は結果の長さまでリサイクルされる．
  論理値引数は最初の要素だけが使われる．
}
\details{
  もし \code{location} や \code{scale} が省略されると，
  それらはそれぞれ既定値の \code{0} と \code{1} とされる．

  \code{location} \eqn{= \mu}{= m} で
  \code{scale} \eqn{= \sigma}{= s} のロジスティック関数は
  分布関数
  \deqn{
    F(x) = \frac{1}{1 + e^{-(x-\mu)/\sigma}}%
  }{F(x) = 1 / (1 + exp(-(x-m)/s))}  そして密度
  \deqn{
    f(x)= \frac{1}{\sigma}\frac{e^{(x-\mu)/\sigma}}{(1 + e^{(x-\mu)/\sigma})^2}%
  }{f(x) = 1/s exp((x-m)/s) (1 + exp((x-m)/s))^-2}
  を持つ．
  
  これは平均 \eqn{\mu}{m} で分散
  \eqn{\pi^2/3 \sigma^2}{\pi^2 /3 s^2} の裾の長い分布である．
}
\note{
  \code{qlogis(p)} は有名な\sQuote{\emph{ロジット}}関数，
  \eqn{logit(p) = \log p/(1-p)}{logit(p) = log(p/(1-p))}，と
  同じで \code{plogis(x)} は従って
  \sQuote{逆ロジット}と呼ばれる．

  分布関数はスケールされ直したハイパボリックタンジェント，
  \code{plogis(x) == (1+ \link{tanh}(x/2))/2}，であり
  これはニューラルネットワーク等では
  \emph{シグモイド関数}と呼ばれる．
}
\source{
  \code{[dpq]logis} はその定義から直接計算される．

  \code{rlogis} は逆関数を使う．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Johnson, N. L., Kotz, S. and Balakrishnan, N. (1995)
  \emph{Continuous Univariate Distributions}, volume 2, chapter 23.
  Wiley, New York.
}
\seealso{
  標準的分布については \link{Distributions}．
}
\examples{
var(rlogis(4000, 0, scale = 5))  # 約 (+/- 3)
pi^2/3 * 5^2
}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/Logistic.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Logistic}
%\alias{Logistic}
%\alias{dlogis}
%\alias{plogis}
%\alias{qlogis}
%\alias{rlogis}
%\title{The Logistic Distribution}
%\concept{logit}
%\concept{sigmoid}
%\description{
%  Density, distribution function, quantile function and random
%  generation for the logistic distribution with parameters
%  \code{location} and \code{scale}.
%}
%\usage{
%dlogis(x, location = 0, scale = 1, log = FALSE)
%plogis(q, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
%qlogis(p, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
%rlogis(n, location = 0, scale = 1)
%}
%\arguments{
%  \item{x, q}{vector of quantiles.}
%  \item{p}{vector of probabilities.}
%  \item{n}{number of observations. If \code{length(n) > 1}, the length
%    is taken to be the number required.}
%  \item{location, scale}{location and scale parameters.}
%  \item{log, log.p}{logical; if TRUE, probabilities p are given as log(p).}
%  \item{lower.tail}{logical; if TRUE (default), probabilities are
%    \eqn{P[X \le x]}, otherwise, \eqn{P[X > x]}.}
%}
%
%\value{
%  \code{dlogis} gives the density,
%  \code{plogis} gives the distribution function,
%  \code{qlogis} gives the quantile function, and
%  \code{rlogis} generates random deviates.
%  
%  The length of the result is determined by \code{n} for
%  \code{rlogis}, and is the maximum of the lengths of the
%  numerical arguments for the other functions.  
%  
%  The numerical arguments other than \code{n} are recycled to the
%  length of the result.  Only the first elements of the logical
%  arguments are used.
%}
%\details{
%  If \code{location} or \code{scale} are omitted, they assume the
%  default values of \code{0} and \code{1} respectively.
%
%  The Logistic distribution with \code{location} \eqn{= \mu}{= m} and
%  \code{scale} \eqn{= \sigma}{= s} has distribution function
%  \deqn{
%    F(x) = \frac{1}{1 + e^{-(x-\mu)/\sigma}}%
%  }{F(x) = 1 / (1 + exp(-(x-m)/s))}  and density
%  \deqn{
%    f(x)= \frac{1}{\sigma}\frac{e^{(x-\mu)/\sigma}}{(1 + e^{(x-\mu)/\sigma})^2}%
%  }{f(x) = 1/s exp((x-m)/s) (1 + exp((x-m)/s))^-2.}
%
%  It is a long-tailed distribution with mean \eqn{\mu}{m} and variance
%  \eqn{\pi^2/3 \sigma^2}{\pi^2 /3 s^2}.
%}
%\note{
%  \code{qlogis(p)} is the same as the well known \sQuote{\emph{logit}}
%  function, \eqn{logit(p) = \log p/(1-p)}{logit(p) = log(p/(1-p))},
%  and \code{plogis(x)} has consequently been called the \sQuote{inverse logit}.
%
%  The distribution function is a rescaled hyperbolic tangent,
%  \code{plogis(x) == (1+ \link{tanh}(x/2))/2}, and it is called a
%  \emph{sigmoid function} in contexts such as neural networks.
%}
%\source{
%  \code{[dpq]logis} are calculated directly from the definitions.
%
%  \code{rlogis} uses inversion.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Johnson, N. L., Kotz, S. and Balakrishnan, N. (1995)
%  \emph{Continuous Univariate Distributions}, volume 2, chapter 23.
%  Wiley, New York.
%}
%\seealso{
%  \link{Distributions} for other standard distributions.
%}
%\examples{
%var(rlogis(4000, 0, scale = 5))  # approximately (+/- 3)
%pi^2/3 * 5^2
%}
%\keyword{distribution}
%
%\encoding{UTF-8}
%
