% File src/library/stats/man/SSfol.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{SSfol}
%@%\alias{漸近回帰モデル}%@%\alias{自己開始モデル}%@%\alias{コンパートメントモデル}
\encoding{UTF-8}
\title{Self-Starting Nls First-order Compartment Model}
\usage{
SSfol(Dose, input, lKe, lKa, lCl)
}
\alias{SSfol}
\arguments{
  \item{Dose}{初期投与量を表現する数値．}
 \item{input}{モデルがそこで評価される数値ベクトル．}
  \item{lKe}{消滅レート定数の自然対数を表現する数値パラメータ．}
  \item{lKa}{吸収レート定数の自然対数を表現する数値パラメータ．}
  \item{lCl}{クリアランス(浄化値)の自然対数を表現する数値パラメータ．}
}
\description{
  この\code{自己開始}モデルは1次のコンパートメント関数とそのグラディエントを
  評価する．
  それは与えられたデータセットに対してパラメータ \code{lKe}, \code{lKa}
  そして \code{lCl} の初期推定値を評価する \code{initial} 属性を持つ．
}
\value{
  \code{input} と同じ長さの数値ベクトル．これは表現式
\preformatted{Dose * exp(lKe+lKa-lCl) * (exp(-exp(lKe)*input) - exp(-exp(lKa)*input))
    / (exp(lKa) - exp(lKe))
}
  の値である．
  もし引数 \code{lKe}, \code{lKa} そして \code{lCl} の
  全てが名前付きオブジェクトなら，これらの名前に関した
  グラディエント行列が \code{gradient} という名前の属性として付いている．
}
\author{\enc{José}{Jose} Pinheiro と Douglas Bates}
\seealso{\code{\link{nls}}, \code{\link{selfStart}}
}
\examples{
Theoph.1 <- Theoph[ Theoph$Subject == 1, ]
SSfol(Theoph.1$Dose, Theoph.1$Time, -2.5, 0.5, -3) # 応答のみ
lKe <- -2.5; lKa <- 0.5; lCl <- -3
SSfol(Theoph.1$Dose, Theoph.1$Time, lKe, lKa, lCl) # 応答とグラディエント
getInitial(conc ~ SSfol(Dose, Time, lKe, lKa, lCl), data = Theoph.1)
## Initial values are in fact the converged values
fm1 <- nls(conc ~ SSfol(Dose, Time, lKe, lKa, lCl), data = Theoph.1)
summary(fm1)
}
\keyword{models}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/SSfol.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{SSfol}
%\encoding{UTF-8}
%\title{Self-Starting Nls First-order Compartment Model}
%\usage{
%SSfol(Dose, input, lKe, lKa, lCl)
%}
%\alias{SSfol}
%\arguments{
%  \item{Dose}{a numeric value representing the initial dose.}
%  \item{input}{a numeric vector at which to evaluate the model.}
%  \item{lKe}{a numeric parameter representing the natural logarithm of
%    the elimination rate constant.}
%  \item{lKa}{a numeric parameter representing the natural logarithm of
%    the absorption rate constant.}
%  \item{lCl}{a numeric parameter representing the natural logarithm of
%    the clearance.}
%}
%\description{
%  This \code{selfStart} model evaluates the first-order compartment
%  function and its gradient.  It has an \code{initial} attribute that
%  creates initial estimates of the parameters \code{lKe}, \code{lKa},
%  and \code{lCl}.
%}
%\value{
%  a numeric vector of the same length as \code{input}, which is the
%  value of the expression
%\preformatted{Dose * exp(lKe+lKa-lCl) * (exp(-exp(lKe)*input) - exp(-exp(lKa)*input))
%    / (exp(lKa) - exp(lKe))
%}
%
%  If all of the arguments \code{lKe}, \code{lKa}, and \code{lCl} are
%  names of objects, the gradient matrix with respect to these names is
%  attached as an attribute named \code{gradient}.
%}
%\author{\enc{José}{Jose} Pinheiro and Douglas Bates}
%\seealso{\code{\link{nls}}, \code{\link{selfStart}}
%}
%\examples{
%Theoph.1 <- Theoph[ Theoph$Subject == 1, ]
%SSfol(Theoph.1$Dose, Theoph.1$Time, -2.5, 0.5, -3) # response only
%lKe <- -2.5; lKa <- 0.5; lCl <- -3
%SSfol(Theoph.1$Dose, Theoph.1$Time, lKe, lKa, lCl) # response and gradient
%getInitial(conc ~ SSfol(Dose, Time, lKe, lKa, lCl), data = Theoph.1)
%## Initial values are in fact the converged values
%fm1 <- nls(conc ~ SSfol(Dose, Time, lKe, lKa, lCl), data = Theoph.1)
%summary(fm1)
%}
%\keyword{models}
%
%
