% File src/library/stats/man/SSweibull.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{SSweibull}

\title{Self-Starting Nls Weibull Growth Curve Model}
%@%\alias{漸近回帰モデル}%@%\alias{自己開始モデル}%@%\alias{ワイブル成長曲線}
\usage{
SSweibull(x, Asym, Drop, lrc, pwr)
}
\alias{SSweibull}
\arguments{
 \item{input}{モデルがそこで評価される数値ベクトル．}
 \item{Asym}{右側(非常に大きな \code{input} の値)の水平漸近値を
   表す数値パラメータ．}
 \item{Drop}{
   \code{Asym} から the \code{y} 切片への変化を表す数値パラメータ．}
 \item{lrc}{レート定数の自然対数を表す数値パラメータ．}
 \item{pwr}{
   \code{x} を巾乗すべき値を表す数値パラメータ．}
}
\description{
  この\code{自己開始}モデルは成長曲線に対するワイブルモデル
  とそのグラディエントを評価する．
  それは与えられたデータセットに対してパラメータ
  \code{Asym}, \code{Drop},
  \code{lrc} そして \code{pwr} の初期推定値を評価する \code{initial} 属性を持つ．
}
\value{
  \code{input} と同じ長さの数値ベクトル．これは表現式
  \code{Asym-Drop*exp(-exp(lrc)*x^pwr)} の値である．
  もし引数 \code{Asym}, \code{Drop}, \code{lrc} そして \code{pwr} の
  全てが名前付きオブジェクトなら，これらの名前に関した
  グラディエント行列が \code{gradient} という名前の属性として付いている．
}
\details{
  このモデルは \code{pwr} が 1 の時 \code{SSasymp} に
  帰着するという点で \code{\link{SSasymp}} モデルの拡張である．
  }
\author{Douglas Bates}
\references{
  Ratkowsky, David A. (1983), \emph{Nonlinear Regression Modeling},
  Dekker. (section 4.4.5)
}
\seealso{\code{\link{nls}}, \code{\link{selfStart}}, \code{\link{SSasymp}}
}
\examples{
Chick.6 <- subset(ChickWeight, (Chick == 6) & (Time > 0))
SSweibull(Chick.6$Time, 160, 115, -5.5, 2.5)   # 応答のみ
Asym <- 160; Drop <- 115; lrc <- -5.5; pwr <- 2.5
SSweibull(Chick.6$Time, Asym, Drop, lrc, pwr)  # 応答とグラディエント
getInitial(weight ~ SSweibull(Time, Asym, Drop, lrc, pwr), data = Chick.6)
## Initial values are in fact the converged values
fm1 <- nls(weight ~ SSweibull(Time, Asym, Drop, lrc, pwr), data = Chick.6)
summary(fm1)
}
\keyword{models}

\encoding{UTF-8}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/SSweibull.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{SSweibull}
%\title{Self-Starting Nls Weibull Growth Curve Model}
%\usage{
%SSweibull(x, Asym, Drop, lrc, pwr)
%}
%\alias{SSweibull}
%\arguments{
% \item{x}{a numeric vector of values at which to evaluate the model.}
% \item{Asym}{a numeric parameter representing the horizontal asymptote on
%   the right side (very small values of \code{x}).}
% \item{Drop}{a numeric parameter representing the change from
%   \code{Asym} to the \code{y} intercept.}
% \item{lrc}{a numeric parameter representing the natural logarithm of
%   the rate constant.}
% \item{pwr}{a numeric parameter representing the power to which \code{x}
%   is raised.}
%}
%\description{
%  This \code{selfStart} model evaluates the Weibull model for growth
%  curve data and its gradient.  It has an \code{initial} attribute that
%  will evaluate initial estimates of the parameters \code{Asym}, \code{Drop},
%  \code{lrc}, and \code{pwr} for a given set of data.
%}
%\value{
%  a numeric vector of the same length as \code{x}.  It is the value of
%  the expression \code{Asym-Drop*exp(-exp(lrc)*x^pwr)}.  If all of
%  the arguments \code{Asym}, \code{Drop}, \code{lrc}, and \code{pwr} are
%  names of objects, the gradient matrix with respect to these names is
%  attached as an attribute named \code{gradient}.
%}
%\details{
%  This model is a generalization of the \code{\link{SSasymp}} model in
%  that it reduces to \code{SSasymp} when \code{pwr} is unity.
%  }
%\author{Douglas Bates}
%\references{
%  Ratkowsky, David A. (1983), \emph{Nonlinear Regression Modeling},
%  Dekker. (section 4.4.5)
%}
%\seealso{\code{\link{nls}}, \code{\link{selfStart}}, \code{\link{SSasymp}}
%}
%\examples{
%Chick.6 <- subset(ChickWeight, (Chick == 6) & (Time > 0))
%SSweibull(Chick.6$Time, 160, 115, -5.5, 2.5)   # response only
%Asym <- 160; Drop <- 115; lrc <- -5.5; pwr <- 2.5
%SSweibull(Chick.6$Time, Asym, Drop, lrc, pwr)  # response and gradient
%getInitial(weight ~ SSweibull(Time, Asym, Drop, lrc, pwr), data = Chick.6)
%## Initial values are in fact the converged values
%fm1 <- nls(weight ~ SSweibull(Time, Asym, Drop, lrc, pwr), data = Chick.6)
%summary(fm1)
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
