% File src/library/stats/man/TDist.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{TDist}

\alias{TDist}%@%\alias{t 分布}
\alias{dt}
\alias{pt}
\alias{qt}
\alias{rt}
\title{The Student t Distribution}
\description{
  自由度 \code{df} (そしてオプションで非中心化パラメータ \code{ncp})
  の t 分布に対する密度，分布関数，クォンタイル関数と乱数生成．
}
\usage{
dt(x, df, ncp, log = FALSE)
pt(q, df, ncp, lower.tail = TRUE, log.p = FALSE)
qt(p, df, ncp, lower.tail = TRUE, log.p = FALSE)
rt(n, df, ncp)
}
\arguments{
  \item{x, q}{クォンタイルのベクトル．}
  \item{p}{確率のベクトル．}
  \item{n}{観測値数．もし \code{length(n) > 1} なら長さが
    必要な個数とされる．}
  \item{df}{自由度(\eqn{> 0}，非整数かもしれない)．
    \code{df = Inf} が許される．}
  \item{ncp}{非中心化パラメータ \eqn{\delta}{delta}；
    現在 \code{rt()} を除いて \code{abs(ncp) <= 37.62} のみ．
    もし省略されると中心化 t 分布が与えられる．}
  \item{log, log.p}{論理値；もし TRUE なら確率 p は log(p) とされる．}
  \item{lower.tail}{論理値；もし TRUE (既定値)なら
    確率は \eqn{P[X \le x]} で，さもなければ \eqn{P[X > x]}．}
}
\value{
  \code{dt} は密度，\code{pt} は分布関数，
  \code{qt} はクォンタイル関数，そして
  \code{rt} は乱数を生成する．

  不正な引数は値 \code{NaN} を返し，警告が出る．

  \code{rt} に対しては結果の長さは \code{n} で決まり，
  そして他の関数に対しては数値引数の最大長である．

  \code{n} 以外の数値引数は結果の長さまでリサイクルされる．
  論理値引数は最初の要素だけが使われる．
}
\note{
  \code{ncp = 0} とすると非中心化分布に対するアルゴリズムを使い，
  これは \code{ncp} が省略された時のアルゴリズムとは同じでない．
  これは \code{ncp} が非常にゼロに近い極限的なケースとの一貫性を
  与えるためである．

  ゼロでない \code{ncp} に対するコードは主に
  適度な \code{ncp} の値に対して使われることを意図している：
  それは大きな値に対しては，特に裾で，それほど正確ではない．
}
\details{
  The 
  自由度 \code{df} \eqn{= \nu}{= n} の
  \eqn{t} 分布の密度は全ての実 \eqn{x} に対して.
  \deqn{
    f(x) = \frac{\Gamma ((\nu+1)/2)}{\sqrt{\pi \nu} \Gamma (\nu/2)}
    (1 + x^2/\nu)^{-(\nu+1)/2}%
  }{f(x) = \Gamma((n+1)/2) / (\sqrt(n \pi) \Gamma(n/2)) (1 + x^2/n)^-((n+1)/2)}
  である．平均は
  \eqn{0} (\eqn{\nu > 1}{n > 1} に対して)で分散は
  \eqn{\frac{\nu}{\nu-2}}{n/(n-2)} (\eqn{\nu > 2}{n > 2} に対して)．

  パラメータ \eqn{(\nu, \delta)}{(df, Del)} \code{= (df, ncp)} の
  一般の\emph{非中心化} \eqn{t} は 
  \eqn{T_{\nu}(\delta) := (U + \delta)/\sqrt{V/\nu}}{T(df, Del) := (U + Del) / \sqrt(V/df) }
  の分布として定義される，ここで
  \eqn{U} と \eqn{V} は独立な確率変数
  \eqn{U \sim {\cal N}(0,1)}{U ~ N(0,1)} と
  \eqn{V \sim \chi^2_\nu}{V ~ \chi^2(df)}
  である(\link{Chisquare} を見よ)．

  最も使われる応用は
  \eqn{t} 検定のパワーの計算である：\cr
  \eqn{T = \frac{\bar{X} - \mu_0}{S/\sqrt{n}}}{T= (mX - m0) / (S/sqrt(n))}
  とする，ここで
  \eqn{\bar{X}}{mX} は \code{\link{mean}} で
  \eqn{S} は独立同分布 \eqn{{\cal N}(\mu, \sigma^2)}{N(\mu, \sigma^2)} の
  標本 
  \eqn{X_1, X_2, \dots, X_n} の標本標準偏差(\code{\link{sd}})である．
  すると \eqn{T} は自由度
  \code{df}\eqn{{} = n-1}{= n - 1} で
  非中心化パラメータ
  \code{ncp}\eqn{{} = (\mu - \mu_0) \sqrt{n}/\sigma}{ = (\mu - m0) * sqrt(n)/\sigma} の非中心化 \eqn{t} 分布に従う．
}
\source{
  中心化 \code{dt} は
  Catherine Loader 提供の正確な公式を使い計算される
  (\code{\link{dbinom}} 中の参考文献を見よ)．

  \code{dt} の非中心化ケースに対しては
  累積分布との関係式(\eqn{x \neq 0}{x != 0} に対して)に基づく
  Claus \enc{Ekstrøm}{Ekstroem} の C コード．

  For the central case of
  \code{pt} の中心化ケースについては裾における正規近似，
  さもなければ \code{\link{pbeta}} を使う．

  \code{pt} の非中心化ケースに対しては次の C への翻訳

  Lenth, R. V. (1989). \emph{Algorithm AS 243} ---
  Cumulative distribution function of the non-central \eqn{t} distribution,
  \emph{Applied Statistics} \bold{38}, 185--189.

  これは下裾だけを計算するので，上裾はキャンセルの影響を受け，
  これが重大と思われる場合は警告が出る．

  中心化 \code{qt} に対しては次の C への翻訳

  Hill, G. W. (1970) Algorithm 396: Student's t-quantiles.
  \emph{Communications of the ACM}, \bold{13(10)}, 619--620.

  で次を考慮している

  Hill, G. W. (1981) Remark on Algorithm 396, \emph{ACM Transactions on
    Mathematical Software}, \bold{7}, 250--1.

  非中心化ケースは逆関数を使う．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole. (Except non-central versions.)

  Johnson, N. L., Kotz, S. and Balakrishnan, N. (1995)
  \emph{Continuous Univariate Distributions}, volume 2, chapters 28 and 31.
  Wiley, New York.
}
\seealso{
  F 分布 \code{\link{df}} を含む他の標準分布は \link{Distributions}．
}
\examples{
require(graphics)

1 - pt(1:5, df = 1)
qt(.975, df = c(1:10,20,50,100,1000))

tt <- seq(0, 10, len = 21)
ncp <- seq(0, 6, len = 31)
ptn <- outer(tt, ncp, function(t, d) pt(t, df = 3, ncp = d))
t.tit <- "Non-central t - Probabilities"
image(tt, ncp, ptn, zlim = c(0,1), main = t.tit)
persp(tt, ncp, ptn, zlim = 0:1, r = 2, phi = 20, theta = 200, main = t.tit,
      xlab = "t", ylab = "non-centrality parameter",
      zlab = "Pr(T <= t)")

plot(function(x) dt(x, df = 3, ncp = 2), -3, 11, ylim = c(0, 0.32),
     main = "Non-central t - Density", yaxs = "i")
}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/TDist.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{TDist}
%
%\alias{TDist}
%\alias{dt}
%\alias{pt}
%\alias{qt}
%\alias{rt}
%\title{The Student t Distribution}
%\description{
%  Density, distribution function, quantile function and random
%  generation for the t distribution with \code{df} degrees of freedom
%  (and optional non-centrality parameter \code{ncp}).
%}
%\usage{
%dt(x, df, ncp, log = FALSE)
%pt(q, df, ncp, lower.tail = TRUE, log.p = FALSE)
%qt(p, df, ncp, lower.tail = TRUE, log.p = FALSE)
%rt(n, df, ncp)
%}
%\arguments{
%  \item{x, q}{vector of quantiles.}
%  \item{p}{vector of probabilities.}
%  \item{n}{number of observations. If \code{length(n) > 1}, the length
%    is taken to be the number required.}
%  \item{df}{degrees of freedom (\eqn{> 0}, maybe non-integer).  \code{df
%      = Inf} is allowed.}
%  \item{ncp}{non-centrality parameter \eqn{\delta}{delta};
%    currently except for \code{rt()}, only for \code{abs(ncp) <= 37.62}.
%    If omitted, use the central t distribution.}
%  \item{log, log.p}{logical; if TRUE, probabilities p are given as log(p).}
%  \item{lower.tail}{logical; if TRUE (default), probabilities are
%    \eqn{P[X \le x]}, otherwise, \eqn{P[X > x]}.}
%}
%\value{
%  \code{dt} gives the density,
%  \code{pt} gives the distribution function,
%  \code{qt} gives the quantile function, and
%  \code{rt} generates random deviates.
%
%  Invalid arguments will result in return value \code{NaN}, with a warning.
%
%  The length of the result is determined by \code{n} for
%  \code{rt}, and is the maximum of the lengths of the
%  numerical arguments for the other functions.  
%  
%  The numerical arguments other than \code{n} are recycled to the
%  length of the result.  Only the first elements of the logical
%  arguments are used.
%}
%\note{
%  Supplying \code{ncp = 0} uses the algorithm for the non-central
%  distribution, which is not the same algorithm used if \code{ncp} is
%  omitted.  This is to give consistent behaviour in extreme cases with
%  values of \code{ncp} very near zero.
%
%  The code for non-zero \code{ncp} is principally intended to be used
%  for moderate values of \code{ncp}: it will not be highly accurate,
%  especially in the tails, for large values.
%}
%\details{
%  The \eqn{t} distribution with \code{df} \eqn{= \nu}{= n} degrees of
%  freedom has density
%  \deqn{
%    f(x) = \frac{\Gamma ((\nu+1)/2)}{\sqrt{\pi \nu} \Gamma (\nu/2)}
%    (1 + x^2/\nu)^{-(\nu+1)/2}%
%  }{f(x) = \Gamma((n+1)/2) / (\sqrt(n \pi) \Gamma(n/2)) (1 + x^2/n)^-((n+1)/2)}
%  for all real \eqn{x}.
%  It has mean \eqn{0} (for \eqn{\nu > 1}{n > 1}) and
%  variance \eqn{\frac{\nu}{\nu-2}}{n/(n-2)} (for \eqn{\nu > 2}{n > 2}).
%
%  The general \emph{non-central} \eqn{t}
%  with parameters \eqn{(\nu, \delta)}{(df, Del)} \code{= (df, ncp)}
%  is defined as the distribution of
%  \eqn{T_{\nu}(\delta) := (U + \delta)/\sqrt{V/\nu}}{T(df, Del) := (U + Del) / \sqrt(V/df) }
%  where \eqn{U} and \eqn{V}  are independent random
%  variables, \eqn{U \sim {\cal N}(0,1)}{U ~ N(0,1)} and
%  \eqn{V \sim \chi^2_\nu}{V ~ \chi^2(df)} (see \link{Chisquare}).
%
%  The most used applications are power calculations for \eqn{t}-tests:\cr
%  Let \eqn{T = \frac{\bar{X} - \mu_0}{S/\sqrt{n}}}{T= (mX - m0) / (S/sqrt(n))}
%  where
%  \eqn{\bar{X}}{mX} is the \code{\link{mean}} and \eqn{S} the sample standard
%  deviation (\code{\link{sd}}) of \eqn{X_1, X_2, \dots, X_n} which are
%  i.i.d. \eqn{{\cal N}(\mu, \sigma^2)}{N(\mu, \sigma^2)}
%  Then \eqn{T} is distributed as non-central \eqn{t} with
%  \code{df}\eqn{{} = n-1}{= n - 1}
%  degrees of freedom and \bold{n}on-\bold{c}entrality \bold{p}arameter
%  \code{ncp}\eqn{{} = (\mu - \mu_0) \sqrt{n}/\sigma}{ = (\mu - m0) * sqrt(n)/\sigma}.
%}
%\source{
%  The central \code{dt} is computed via an accurate formula
%  provided by Catherine Loader (see the reference in \code{\link{dbinom}}).
%
%  For the non-central case of \code{dt}, C code contributed by
%  Claus \enc{Ekstrøm}{Ekstroem} based on the relationship (for
%  \eqn{x \neq 0}{x != 0}) to the cumulative distribution.
%
%  For the central case of \code{pt}, a normal approximation in the
%  tails, otherwise via \code{\link{pbeta}}.
%
%  For the non-central case of \code{pt} based on a C translation of
%
%  Lenth, R. V. (1989). \emph{Algorithm AS 243} ---
%  Cumulative distribution function of the non-central \eqn{t} distribution,
%  \emph{Applied Statistics} \bold{38}, 185--189.
%
%  This computes the lower tail only, so the upper tail suffers from
%  cancellation and a warning will be given when this is likely to be
%  significant.
%
%  For central \code{qt}, a C translation of
%
%  Hill, G. W. (1970) Algorithm 396: Student's t-quantiles.
%  \emph{Communications of the ACM}, \bold{13(10)}, 619--620.
%
%  altered to take account of
%
%  Hill, G. W. (1981) Remark on Algorithm 396, \emph{ACM Transactions on
%    Mathematical Software}, \bold{7}, 250--1.
%
%  The non-central case is done by inversion.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole. (Except non-central versions.)
%
%  Johnson, N. L., Kotz, S. and Balakrishnan, N. (1995)
%  \emph{Continuous Univariate Distributions}, volume 2, chapters 28 and 31.
%  Wiley, New York.
%}
%\seealso{
%  \link{Distributions} for other standard distributions, including
%  \code{\link{df}} for the F distribution.
%}
%\examples{
%require(graphics)
%
%1 - pt(1:5, df = 1)
%qt(.975, df = c(1:10,20,50,100,1000))
%
%tt <- seq(0, 10, len = 21)
%ncp <- seq(0, 6, len = 31)
%ptn <- outer(tt, ncp, function(t, d) pt(t, df = 3, ncp = d))
%t.tit <- "Non-central t - Probabilities"
%image(tt, ncp, ptn, zlim = c(0,1), main = t.tit)
%persp(tt, ncp, ptn, zlim = 0:1, r = 2, phi = 20, theta = 200, main = t.tit,
%      xlab = "t", ylab = "non-centrality parameter",
%      zlab = "Pr(T <= t)")
%
%plot(function(x) dt(x, df = 3, ncp = 2), -3, 11, ylim = c(0, 0.32),
%     main = "Non-central t - Density", yaxs = "i")
%}
%\keyword{distribution}
%
%\encoding{UTF-8}
%
