% File src/library/stats/man/Tukey.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Tukey}
\alias{Tukey}%@%\alias{スチューデント化範囲の分布}
\title{The Studentized Range Distribution}
\description{
  スチューデント化範囲 \eqn{R/s} の分布の関数，ここで
  \eqn{R} は標準正規標本の範囲で
  \eqn{df \times s^2}{df*s^2} は独立に
  自由度 \eqn{df} のカイ二乗分布に従う，\code{\link{pchisq}} を見よ．
}
\usage{
ptukey(q, nmeans, df, nranges = 1, lower.tail = TRUE, log.p = FALSE)
qtukey(p, nmeans, df, nranges = 1, lower.tail = TRUE, log.p = FALSE)
}
\alias{ptukey}
\alias{qtukey}
\arguments{
  \item{x, q}{クォンタイルのベクトル．}
  \item{p}{確率のベクトル．}
  \item{nmeans}{範囲に対する標本サイズ(各グループで同じ)．}
  \item{n}{観測値数．もし \code{length(n) > 1} なら長さが
    必要な個数とされる．}
  \item{df}{\eqn{s} に対する自由度(下を見よ)．}
  \item{nranges}{その\bold{最大}範囲が考慮される\emph{グループ}の数．}
  \item{log, log.p}{論理値；もし TRUE なら確率 p は log(p) とされる．}
  \item{lower.tail}{論理値；もし TRUE (既定値)なら
    確率は \eqn{P[X \le x]} で，さもなければ \eqn{P[X > x]}．}
}
\details{
  もし \eqn{n_g =}{ng =}\code{nranges} が 1 より大きければ，
  \eqn{R} は各々 \code{nmeans} 観測値の \eqn{n_g}{ng} グループの
  \emph{最大値}．
}
\value{
  \code{ptukey} は分布関数を与え \code{qtukey} はその
  逆関数のクォンタイル関数．
  
  結果の長さは数値引数の最大長である．
  他の数値引数はその長さまでリサイクルされる．
  論理値引数はその最初の要素だけが使われる．
}
\note{
  \code{ptukey} の積分に対してはルジャンドルの16点公式が使われる．
  計算は特に \code{ptukey} の逆関数を見つける単純な割線法を
  使う \code{qtukey} に対して相対的に手間がかかる．
  \code{qtukey} は 4 桁の精度であろう．
}
\source{
  \code{qtukey} は部分的に Odeh and Evans (1974) から採用された．
}
\references{
  Copenhaver, Margaret Diponzio and Holland, Burt S. (1988)
  Multiple comparisons of simple effects in
  the two-way analysis of variance with fixed effects.
  \emph{Journal of Statistical Computation and Simulation}, \bold{30}, 1--15.

  Odeh, R. E.  and  Evans, J. O. (1974)
  Algorithm AS 70: Percentage Points of the Normal Distribution.
  \emph{Applied Statistics} \bold{23}, 96--97.
}
\seealso{
  対応する正規分布に対する関数 \code{\link{pnorm}} と
  \code{\link{qnorm}} を含む標準分布については
  \link{Distributions}．
}
\examples{
if(interactive())
  curve(ptukey(x, nm = 6, df = 5), from = -1, to = 8, n = 101)
(ptt <- ptukey(0:10, 2, df =  5))
(qtt <- qtukey(.95, 2, df =  2:11))
## 精度は8桁以上にはならないかもしれない：
\donttest{summary(abs(.95 - ptukey(qtt, 2, df = 2:11)))}
}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/Tukey.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Tukey}
%\alias{Tukey}
%\title{The Studentized Range Distribution}
%\description{
%  Functions of the distribution of the studentized range, \eqn{R/s},
%  where \eqn{R} is the range of a standard normal sample and
%  \eqn{df \times s^2}{df*s^2} is independently distributed as
%  chi-squared with \eqn{df} degrees of freedom, see \code{\link{pchisq}}.
%}
%\usage{
%ptukey(q, nmeans, df, nranges = 1, lower.tail = TRUE, log.p = FALSE)
%qtukey(p, nmeans, df, nranges = 1, lower.tail = TRUE, log.p = FALSE)
%}
%\alias{ptukey}
%\alias{qtukey}
%\arguments{
%  \item{q}{vector of quantiles.}
%  \item{p}{vector of probabilities.}
%  \item{nmeans}{sample size for range (same for each group).}
%  \item{df}{degrees of freedom for \eqn{s} (see below).}
%  \item{nranges}{number of \emph{groups} whose \bold{maximum} range is
%    considered.}
%  \item{log.p}{logical; if TRUE, probabilities p are given as log(p).}
%  \item{lower.tail}{logical; if TRUE (default), probabilities are
%    \eqn{P[X \le x]}, otherwise, \eqn{P[X > x]}.}
%}
%\details{
%  If \eqn{n_g =}{ng =}\code{nranges} is greater than one, \eqn{R} is
%  the \emph{maximum} of \eqn{n_g}{ng} groups of \code{nmeans}
%  observations each.
%}
%\value{
%  \code{ptukey} gives the distribution function and \code{qtukey} its
%  inverse, the quantile function.
%  
%  The length of the result is the maximum of the lengths of the
%  numerical arguments.  The other numerical arguments are recycled
%  to that length.  Only the first elements of the logical arguments
%  are used.  
%}
%\note{
%  A Legendre 16-point formula is used for the integral of \code{ptukey}.
%  The computations are relatively expensive, especially for
%  \code{qtukey} which uses a simple secant method for finding the
%  inverse of \code{ptukey}.
%  \code{qtukey} will be accurate to the 4th decimal place.
%}
%\source{
%  \code{qtukey} is in part adapted from Odeh and Evans (1974).
%}
%\references{
%  Copenhaver, Margaret Diponzio and Holland, Burt S. (1988)
%  Multiple comparisons of simple effects in
%  the two-way analysis of variance with fixed effects.
%  \emph{Journal of Statistical Computation and Simulation}, \bold{30}, 1--15.
%
%  Odeh, R. E.  and  Evans, J. O. (1974)
%  Algorithm AS 70: Percentage Points of the Normal Distribution.
%  \emph{Applied Statistics} \bold{23}, 96--97.
%}
%\seealso{
%  \link{Distributions} for standard distributions, including
%  \code{\link{pnorm}} and \code{\link{qnorm}} for the corresponding
%  functions for the normal distribution.
%}
%\examples{
%if(interactive())
%  curve(ptukey(x, nm = 6, df = 5), from = -1, to = 8, n = 101)
%(ptt <- ptukey(0:10, 2, df =  5))
%(qtt <- qtukey(.95, 2, df =  2:11))
%## The precision may be not much more than about 8 digits:
%\donttest{summary(abs(.95 - ptukey(qtt, 2, df = 2:11)))}
%}
%\keyword{distribution}
%
%\encoding{UTF-8}
%
