% File src/library/stats/man/TukeyHSD.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{TukeyHSD}
\alias{TukeyHSD}%@%\alias{Tukey のHSD法}
%\alias{TukeyHSD.aov}
%\alias{print.TukeyHSD}
%\alias{plot.TukeyHSD}
\title{Compute Tukey Honest Significant Differences}
\description{
  指定された族毎の被覆確率を持つ
  因子の水準の平均間の差に対する信頼集合を作る．
  この区間はスチューデント化された範囲統計量に基づく
  Tukey の \sQuote{Honest Significant Difference} 法である．
}
\usage{
TukeyHSD(x, which, ordered = FALSE, conf.level = 0.95, \dots)
}
\arguments{
 \item{x}{当てはめモデルオブジェクトで，普通
   \code{\link{aov}} による当てはめ結果．}
 \item{which}{それに対して区間が計算されるべき
   当てはめモデル中の項をリストする文字列．
   既定では全ての項．}
  \item{ordered}{因子の水準は差を取る前に標本平均の
   増加順に並べ替えるかどうかを指示する論理値．
   もし \code{ordered} が真なら平均の差は全て正になる．
   有意な差は端 \code{lwr} が正になるものである．}
 \item{conf.level}{ゼロと族毎の使われる信頼水準を与える
   ものとの間の数値．}
 \item{\dots}{オプションの追加引数．
   現在どれも使われない．}
}
\details{
  これは総称的関数である：
  ここでの説明はクラス \code{"aov"} の当てはめに対するものである．
  
  分散分析に於ける因子の水準の平均を比較する際，
  t 検定を使う単純な比較は実際には存在しない有意な差を
  宣言する確率をつり上げる．
  これは各区間毎に与えられた被覆確率で区間が計算されるためであるが，
  被覆の解釈は通常区間の全ての族に関して行われる．

  John Tukey は個別の差ではなく標本平均の範囲に基づく区間を
  提案した．この関数が返す区間は
  スチューデント化された範囲統計量に基づく．

  このように作られた区間は
  因子の各水準に於いて同じ数の観測値がある釣り合い型デザインにたいして
  正確に適用される．
  この関数は適度に非釣り合い型なデザインに対しても意味のある区間を
  与える標本数に対する補正を組み込んでいる．

  もし \code{which} が非因子の項を指定すればこれらは
  警告と共に捨てられる：もし項が一つも残らなければ
  エラーになる．
}
\value{
  クラス \code{c("multicomp", "TukeyHSD")} のりストで，
  \code{which} 中で要求された各項に対して一つの成分を持つ．
  各成分は行列で次の列を持つ，観測平均の差を与える
  \code{diff}，区間の下端を与える \code{lwr}，
  上端を与える \code{upr}，そして
  多重比較に対する修正済みの p 値を与える
  \code{p adj}．

  クラス \code{"TukeyHSD"} に対しては
  \code{print} と \code{plot} メソッドがある．
  \code{plot} メソッドは \code{xlab}, \code{ylab} 又は
  \code{main} 引数を受け入れず，各プロットに対して
  それ自体の値を作る．
}
\references{
  Miller, R. G. (1981)
  \emph{Simultaneous Statistical Inference}. Springer.

  Yandell, B. S. (1997)
  \emph{Practical Data Analysis for Designed Experiments}.
  Chapman & Hall.
}
\author{
  Douglas Bates
}
\seealso{
  \code{\link{aov}}, \code{\link{qtukey}}, \code{\link{model.tables}},
  パッケージ \CRANpkg{multcomp} 中の \code{\link[multcomp]{glht}}．
}
\examples{
require(graphics)

summary(fm1 <- aov(breaks ~ wool + tension, data = warpbreaks))
TukeyHSD(fm1, "tension", ordered = TRUE)
plot(TukeyHSD(fm1, "tension"))
}
\keyword{models}
\keyword{design}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/TukeyHSD.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{TukeyHSD}
%\alias{TukeyHSD}
%%\alias{TukeyHSD.aov}
%%\alias{print.TukeyHSD}
%%\alias{plot.TukeyHSD}
%\title{Compute Tukey Honest Significant Differences}
%\description{
%  Create a set of confidence intervals on the differences between the
%  means of the levels of a factor with the specified family-wise
%  probability of coverage.  The intervals are based on the Studentized
%  range statistic, Tukey's \sQuote{Honest Significant Difference}
%  method.
%}
%\usage{
%TukeyHSD(x, which, ordered = FALSE, conf.level = 0.95, \dots)
%}
%\arguments{
% \item{x}{A fitted model object, usually an \code{\link{aov}} fit.}
% \item{which}{A character vector listing terms in the fitted model for
%   which the intervals should be calculated.  Defaults to all the
%   terms.}
%  \item{ordered}{A logical value indicating if the levels of the factor
%   should be ordered according to increasing average in the sample
%   before taking differences.  If \code{ordered} is true then
%   the calculated differences in the means will all be positive.  The
%   significant differences will be those for which the \code{lwr} end
%   point is positive.}
% \item{conf.level}{A numeric value between zero and one giving the
%   family-wise confidence level to use.}
% \item{\dots}{Optional additional arguments.  None are used at present.}
%}
%\details{
%  This is a generic function: the description here applies to the method
%  for fits of class \code{"aov"}.
%  
%  When comparing the means for the levels of a factor in an analysis of
%  variance, a simple comparison using t-tests will inflate the
%  probability of declaring a significant difference when it is not in
%  fact present.  This because the intervals are calculated with a
%  given coverage probability for each interval but the interpretation of
%  the coverage is usually with respect to the entire family of
%  intervals.
%
%  John Tukey introduced intervals based on the range of the
%  sample means rather than the individual differences.  The intervals
%  returned by this function are based on this Studentized range
%  statistics.
%
%  The intervals constructed in this way would only apply exactly to
%  balanced designs where there are the same number of observations made
%  at each level of the factor.  This function incorporates an adjustment
%  for sample size that produces sensible intervals for mildly unbalanced
%  designs.
%
%  If \code{which} specifies non-factor terms these will be dropped with
%  a warning: if no terms are left this is an error.
%}
%\value{
%  A list of class \code{c("multicomp", "TukeyHSD")},
%  with one component for each term requested in \code{which}.
%  Each component is a matrix with columns \code{diff} giving the
%  difference in the observed means, \code{lwr} giving the lower
%  end point of the interval, \code{upr} giving the upper end point
%  and \code{p adj} giving the p-value after adjustment for the multiple
%  comparisons.
%
%  There are \code{print} and \code{plot} methods for class
%  \code{"TukeyHSD"}.  The \code{plot} method does not accept
%  \code{xlab}, \code{ylab} or \code{main} arguments and creates its own
%  values for each plot.
%}
%\references{
%  Miller, R. G. (1981)
%  \emph{Simultaneous Statistical Inference}. Springer.
%
%  Yandell, B. S. (1997)
%  \emph{Practical Data Analysis for Designed Experiments}.
%  Chapman & Hall.
%}
%\author{
%  Douglas Bates
%}
%\seealso{
%  \code{\link{aov}}, \code{\link{qtukey}}, \code{\link{model.tables}},
%  \code{\link[multcomp]{glht}} in package \CRANpkg{multcomp}.
%}
%\examples{
%require(graphics)
%
%summary(fm1 <- aov(breaks ~ wool + tension, data = warpbreaks))
%TukeyHSD(fm1, "tension", ordered = TRUE)
%plot(TukeyHSD(fm1, "tension"))
%}
%\keyword{models}
%\keyword{design}
%
%\encoding{UTF-8}
%
