% File src/library/stats/man/Uniform.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Uniform}
\alias{Uniform}%@%\alias{一様分布}
\title{The Uniform Distribution}
\usage{
dunif(x, min = 0, max = 1, log = FALSE)
punif(q, min = 0, max = 1, lower.tail = TRUE, log.p = FALSE)
qunif(p, min = 0, max = 1, lower.tail = TRUE, log.p = FALSE)
runif(n, min = 0, max = 1)
}
\alias{dunif}
\alias{punif}
\alias{qunif}
\alias{runif}
\arguments{
  \item{x, q}{クォンタイルのベクトル．}
  \item{p}{確率のベクトル．}
  \item{n}{観測値数．もし \code{length(n) > 1} なら長さが
    必要な個数とされる．}
  \item{min, max}{分布の下限と上限．
    有限でなければならない．}
  \item{log, log.p}{論理値；もし TRUE なら確率 p は log(p) とされる．}
  \item{lower.tail}{論理値；もし TRUE (既定値)なら
    確率は \eqn{P[X \le x]} で，さもなければ \eqn{P[X > x]}．}
}
\description{
  これらの関数は
  \code{min} から \code{max} までの区間上の一様乱数に関する情報を
  与える．\code{dunif} は密度，
  \code{punif} は分布関数，
  \code{qunif} はクォンタイル関数，そして
  \code{runif} は乱数を生成する．
}
\details{
  もし \code{min} や \code{max} が指定されないと，
  それらはそれぞれ既定値の
  \code{0} と \code{1} とされる．

  一様分布は \eqn{min \le x \le max} で密度
  \deqn{f(x) = \frac{1}{max-min}}{f(x) = 1/(max-min)}
  を持つ．

  \eqn{u := min == max} のケースでは極限ケース
  \eqn{X \equiv u}{X == u} とされるが，この場合密度は存在せず
  \code{dunif} は \code{NaN} (エラー条件)を返す．

  \code{max = min} か \code{max-min} が
  \code{min} と比較して小さくなければ
  \code{runif} は極値のどちらも生成しない．
  特に既定値ではそうである．
}
\value{
  \code{dunif} は密度，\code{punif} は分布関数，
  \code{qunif} はクォンタイル関数，そして
  \code{runif} は乱数を生成する．

  結果の長さは \code{runif} に対しては \code{n}
  で決まり，他の関数に対しては数値引数の長さの
  最大値である．

  \code{n} 以外の数値引数は結果の長さまでリサイクルされる．
  論理値引数は最初の要素だけが使われる．
}
\note{擬似乱数生成器からの出力の特性
  (精度や周期等)は大きく異なる．
  \R の生成アルゴリズムに関するより多くの情報は
  \code{\link{.Random.seed}} を見よ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \R に於ける乱数の生成については \code{\link{RNG}}．

  他の標準分布に対しては \link{Distributions}．
}
\examples{
u <- runif(20)

## 次の関係が常に成り立つ：
punif(u) == u
dunif(u) == 1

var(runif(10000))  #- ~ = 1/12 = .08333
}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/Uniform.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Uniform}
%\alias{Uniform}
%\title{The Uniform Distribution}
%\usage{
%dunif(x, min = 0, max = 1, log = FALSE)
%punif(q, min = 0, max = 1, lower.tail = TRUE, log.p = FALSE)
%qunif(p, min = 0, max = 1, lower.tail = TRUE, log.p = FALSE)
%runif(n, min = 0, max = 1)
%}
%\alias{dunif}
%\alias{punif}
%\alias{qunif}
%\alias{runif}
%\arguments{
%  \item{x, q}{vector of quantiles.}
%  \item{p}{vector of probabilities.}
%  \item{n}{number of observations. If \code{length(n) > 1}, the length
%    is taken to be the number required.}
%  \item{min, max}{lower and upper limits of the distribution.  Must be finite.}
%  \item{log, log.p}{logical; if TRUE, probabilities p are given as log(p).}
%  \item{lower.tail}{logical; if TRUE (default), probabilities are
%    \eqn{P[X \le x]}, otherwise, \eqn{P[X > x]}.}
%}
%\description{
%  These functions provide information about the uniform distribution
%  on the interval from \code{min} to \code{max}.  \code{dunif} gives the
%  density, \code{punif} gives the distribution function \code{qunif}
%  gives the quantile function and \code{runif} generates random
%  deviates.
%}
%\details{
%  If \code{min} or \code{max} are not specified they assume the default
%  values of \code{0} and \code{1} respectively.
%
%  The uniform distribution has density
%  \deqn{f(x) = \frac{1}{max-min}}{f(x) = 1/(max-min)}
%  for \eqn{min \le x \le max}.
%
%  For the case of \eqn{u := min == max}, the limit case of
%  \eqn{X \equiv u}{X == u} is assumed, although there is no density in
%  that case and \code{dunif} will return \code{NaN} (the error condition).
%
%  \code{runif} will not generate either of the extreme values unless
%  \code{max = min} or \code{max-min} is small compared to \code{min},
%  and in particular not for the default arguments.
%}
%\value{
%  \code{dunif} gives the density,
%  \code{punif} gives the distribution function,
%  \code{qunif} gives the quantile function, and
%  \code{runif} generates random deviates.
%  
%  The length of the result is determined by \code{n} for
%  \code{runif}, and is the maximum of the lengths of the
%  numerical arguments for the other functions.  
%  
%  The numerical arguments other than \code{n} are recycled to the
%  length of the result.  Only the first elements of the logical
%  arguments are used.
%}
%\note{The characteristics of output from pseudo-random number generators
%  (such as precision and periodicity) vary widely.  See
%  \code{\link{.Random.seed}} for more information on \R's random number
%  generation algorithms.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{RNG}} about random number generation in \R.
%
%  \link{Distributions} for other standard distributions.
%}
%\examples{
%u <- runif(20)
%
%## The following relations always hold :
%punif(u) == u
%dunif(u) == 1
%
%var(runif(10000))  #- ~ = 1/12 = .08333
%}
%\keyword{distribution}
%
%\encoding{UTF-8}
%
