% File src/library/stats/man/anova.glm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{anova.glm}
%@%\alias{デビアンス分析表}
\title{Analysis of Deviance for Generalized Linear Model Fits}
\usage{
\method{anova}{glm}(object, \dots, dispersion = NULL, test = NULL)
}
\alias{anova.glm}
\description{
  一つ又はそれ以上の一般化線形モデル当てはめに対するデビアンス分析表
  を計算する．
}
\arguments{
  \item{object, \dots}{
    クラス \code{glm} のオブジェクト，普通
    \code{\link{glm}} 呼び出しの結果か
    \code{"glmlist"} メソッドに対する
    \code{objects} のりスト．}
  \item{dispersion}{当てはめ族に対する散布度パラメータ．
    既定ではこれはオブジェクトから得られる．}
  \item{test}{文字列で(部分的に)
    \code{"Chisq"}, \code{"LRT"}, \code{"Rao"}, \code{"F"}
    又は \code{"Cp"} のどれかにマッチする．\code{\link{stat.anova}} を見よ．}
}
\details{
  単一のオブジェクトを指定すると
  その当てはめに対する逐次的デビアンス分析表を与える．
  つまり公式の各項が順に付け加えられた時残差デビアンスの減少と
  残差デビアンス自体がテーブルの行として与えられる．

  一つ以上のオブジェクトが指定されると，
  テーブルは各モデルに対する残差自由度とデビアンスを行に持つ．
  最初を除く全てのモデルに対して，
  自由度とデビアンスの変化がまた示される．
  (これはモデルが入れ子になっている場合だけ統計的に意味を持つ．)
  モデルを最少から最大に並べるのでが慣例であるが，
  これはユーザ次第である．

  テーブルはオプションで検定統計量を含むことが出来る．
  既知の散布度(例えば二項とポアッソン当てはめ)では
  カイ二乗検定が最も相応しく，そして
  散布度がモーメントで推定されるもの
  (例えば \code{gaussian}, \code{quasibinomial} そして
  \code{quasipoisson} 当てはめ)に対してはF検定が最も相応しい．
  Mallows の \eqn{C_p}{Cp} 統計量は残差デビアンスに
  \eqn{\sigma^2} の推定量の2倍に残差自由度を掛けたものである．
  これは AIC に非常に近い
  (そして散布度が既知なら定数倍である)．
  尤度比検定と Rao の有効スコア検定に対しては
  また \code{"LRT"} と \code{"Rao"} を使う．
  前者は \code{"Chisq"} の同義語である
  (両者は漸近的にカイ二乗分布に従うが)．

  散布度推定値は最大モデルから取られ，
  \code{\link{summary.glm}} が返す値を使う．
  これはほとんどの場合カイ自乗分布に基づく推定値を使うので，
  F検定は表示されるデビアンス分析表では
  残差デビアンスには基づかない．
}
\value{
  クラス \code{"anova"} のオブジェクトで
  クラス \code{"data.frame"} を継承する．
}
\section{警告}{
  二つもしくはそれ以上のモデルの比較はそれらが同じデータセットに当てはめられた
  時だけ適正である．これはもし欠損値があり \R  の既定の
  \code{na.action = na.omit} が使われた時は問題になるかもしれない．
}
\references{
  Hastie, T. J. and Pregibon, D. (1992)
  \emph{Generalized linear models.}
  Chapter 6 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{glm}}, \code{\link{anova}}.

  各項がそれらの階層を尊重して一時に一つ取り除かれる
  いわゆる\sQuote{タイプ II} anova に対しては
  \code{\link{drop1}}．
}
\examples{
## --- '?glm' の例に続く：
\dontshow{require(utils)
example("glm", echo = FALSE)}
anova(glm.D93)
anova(glm.D93, test = "Cp")
anova(glm.D93, test = "Chisq")
glm.D93a <-
   update(glm.D93, ~treatment*outcome) # ペアソンのカイ二乗に同値
anova(glm.D93, glm.D93a, test = "Rao")
}
\keyword{models}
\keyword{regression}


\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/anova.glm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{anova.glm}
%\title{Analysis of Deviance for Generalized Linear Model Fits}
%\usage{
%\method{anova}{glm}(object, \dots, dispersion = NULL, test = NULL)
%}
%\alias{anova.glm}
%\description{
%  Compute an analysis of deviance table for one or more generalized
%  linear model fits.
%}
%\arguments{
%  \item{object, \dots}{objects of class \code{glm}, typically
%    the result of a call to \code{\link{glm}}, or a list of
%    \code{objects} for the \code{"glmlist"} method.}
%  \item{dispersion}{the dispersion parameter for the fitting family.
%    By default it is obtained from the object(s).}
%  \item{test}{a character string, (partially) matching one of \code{"Chisq"},
%  \code{"LRT"}, \code{"Rao"},
%    \code{"F"} or \code{"Cp"}. See \code{\link{stat.anova}}.}
%}
%\details{
%  Specifying a single object gives a sequential analysis of deviance
%  table for that fit.  That is, the reductions in the residual deviance
%  as each term of the formula is added in turn are given in as
%  the rows of a table, plus the residual deviances themselves.
%
%  If more than one object is specified, the table has a row for the
%  residual degrees of freedom and deviance for each model.
%  For all but the first model, the change in degrees of freedom and
%  deviance is also given. (This only makes statistical sense if the
%  models are nested.)  It is conventional to list the models from
%  smallest to largest, but this is up to the user.
%
%  The table will optionally contain test statistics (and P values)
%  comparing the reduction in deviance for the row to the residuals.
%  For models with known dispersion (e.g., binomial and Poisson fits)
%  the chi-squared test is most appropriate, and for those with
%  dispersion estimated by moments (e.g., \code{gaussian},
%  \code{quasibinomial} and \code{quasipoisson} fits) the F test is
%  most appropriate.  Mallows' \eqn{C_p}{Cp} statistic is the residual
%  deviance plus twice the estimate of \eqn{\sigma^2} times
%  the residual degrees of freedom, which is closely related to AIC (and
%  a multiple of it if the dispersion is known).
%  You can also choose \code{"LRT"} and
%    \code{"Rao"} for likelihood ratio tests and Rao's efficient score test.
%    The former is synonymous with \code{"Chisq"} (although both have
%    an asymptotic chi-square distribution).
%
%  The dispersion estimate will be taken from the largest model, using
%  the value returned by \code{\link{summary.glm}}.  As this will in most
%  cases use a Chisquared-based estimate, the F tests are not based on
%  the residual deviance in the analysis of deviance table shown.
%}
%\value{
%  An object of class \code{"anova"} inheriting from class \code{"data.frame"}.
%}
%\section{Warning}{
%  The comparison between two or more models will only be valid if they
%  are fitted to the same dataset. This may be a problem if there are
%  missing values and \R's default of \code{na.action = na.omit} is used,
%  and \code{anova} will detect this with an error.
%}
%\references{
%  Hastie, T. J. and Pregibon, D. (1992)
%  \emph{Generalized linear models.}
%  Chapter 6 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{glm}}, \code{\link{anova}}.
%
%  \code{\link{drop1}} for
%  so-called \sQuote{type II} anova where each term is dropped one at a
%  time respecting their hierarchy.
%}
%\examples{
%## --- Continuing the Example from  '?glm':
%\dontshow{require(utils)
%example("glm", echo = FALSE)}
%anova(glm.D93)
%anova(glm.D93, test = "Cp")
%anova(glm.D93, test = "Chisq")
%glm.D93a <-
%   update(glm.D93, ~treatment*outcome) # equivalent to Pearson Chi-square
%anova(glm.D93, glm.D93a, test = "Rao")
%}
%\keyword{models}
%\keyword{regression}
%
%
%\encoding{UTF-8}
%
