% File src/library/stats/man/anova.lm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{anova.lm}
\alias{anova.lm}%@%\alias{分散分析表}
\alias{anova.lmlist}
\title{ANOVA for Linear Model Fits}
\usage{
\method{anova}{lm}(object, \dots)

\method{anova}{lmlist}(object, \dots, scale = 0, test = "F")
}
\description{
  一つ又はそれ以上の線形モデル当てはめに対する分散分析表を計算する．
}
\arguments{
  \item{object, \dots}{
    クラス \code{lm} のオブジェクトで，普通
    \code{\link{lm}} の呼び出しの結果．}
  \item{test}{使われる検定統計量を指定する文字列．
    \code{"F"}, \code{"Chisq"} または \code{"Cp"} のどれかで，
    部分マッチングが可能．又は検定無しなら \code{NULL}．}
  \item{scale}{数値．
    ノイズ分散 \eqn{\sigma^2} の推定量．もしゼロならこれは考慮される
    最大モデルから推定される．}
  
}
\details{
  単一のオブジェクトを指定すると
  その当てはめに対する逐次的分散分析表を与える．
  つまり公式の各項が順に付け加えられた時残差平方和の減少と
  残差平方和自体がテーブルの列として与えられる．

  テーブルは平均平方和と残差平方和を比較する
  F 統計量(と P 値)を含む．

  一つ以上のオブジェクトが指定されると，
  テーブルは各モデルに対する平方和を行に持つ．
  最初を除く全てのモデルに対して，
  自由度と平方和の変化がまた示される．
  (これはモデルが入れ子になっている場合だけ統計的に意味を持つ．)
  モデルを最少から最大に並べるのでが慣例であるが，
  これはユーザ次第である．

  テーブルはオプションで検定統計量を含むことが出来る．
  普通
  F 統計量が最も相応しく，これは行に対する平均平方和を
  最大モデルに対する残差平方和と比較する．
  もし \code{scale} を指定するとカイ二乗検定を使うことが出来る．
  Mallows の \eqn{C_p}{Cp} 統計量は残差平方和に
  \eqn{\sigma^2}{sigma^2} の推定値の2倍に残差自由度を掛けたものを
  加えたものである．
}
\value{
  An object of class
  クラス \code{"data.frame"} を継承するクラス \code{"anova"} のオブジェクト．
}
\section{警告}{
  二つもしくはそれ以上のモデルの比較はそれらが同じデータセットに当てはめられた
  時だけ適正である．これはもし欠損値があり \R の既定の
  \code{na.action = na.omit} が使われた時は問題になるかもしれず，
  \code{anova.lmlist} はこれを検出してエラーとする．
}
\references{
  Chambers, J. M. (1992)
  \emph{Linear models.}
  Chapter 4 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\seealso{
  モデル当てはめ関数 \code{\link{lm}}, \code{\link{anova}}．

  各項がそれらの階層を尊重して一時に一つ取り除かれる
  いわゆる\sQuote{タイプ II} anova に対しては
  \code{\link{drop1}}．
}
\examples{
## 逐次的テーブル
fit <- lm(sr ~ ., data = LifeCycleSavings)
anova(fit)

## 個別のモデルによる同じ効果
fit0 <- lm(sr ~ 1, data = LifeCycleSavings)
fit1 <- update(fit0, . ~ . + pop15)
fit2 <- update(fit1, . ~ . + pop75)
fit3 <- update(fit2, . ~ . + dpi)
fit4 <- update(fit3, . ~ . + ddpi)
anova(fit0, fit1, fit2, fit3, fit4, test = "F")

anova(fit4, fit2, fit0, test = "F") # 非慣例的な順序
}
\keyword{regression}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/anova.lm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{anova.lm}
%\alias{anova.lm}
%\alias{anova.lmlist}
%\title{ANOVA for Linear Model Fits}
%\usage{
%\method{anova}{lm}(object, \dots)
%
%\method{anova}{lmlist}(object, \dots, scale = 0, test = "F")
%}
%\description{
%  Compute an analysis of variance table for one or more linear model fits.
%}
%\arguments{
%  \item{object, \dots}{objects of class \code{lm}, usually, a result of a
%    call to \code{\link{lm}}.}
%  \item{test}{a character string specifying the test statistic to be
%    used. Can be one of \code{"F"}, \code{"Chisq"} or \code{"Cp"},
%    with partial matching allowed, or \code{NULL} for no test.}
%  \item{scale}{numeric. An estimate of the noise variance
%    \eqn{\sigma^2}. If zero this will be estimated from the
%    largest model considered.
%  }
%}
%\details{
%  Specifying a single object gives a sequential analysis of variance
%  table for that fit.  That is, the reductions in the residual sum of
%  squares as each term of the formula is added in turn are given in as
%  the rows of a table, plus the residual sum of squares.
%
%  The table will contain F statistics (and P values) comparing the
%  mean square for the row to the residual mean square.
%
%  If more than one object is specified, the table has a row for the
%  residual degrees of freedom and sum of squares for each model.
%  For all but the first model, the change in degrees of freedom and sum
%  of squares is also given. (This only make statistical sense if the
%  models are nested.)  It is conventional to list the models from
%  smallest to largest, but this is up to the user.
%
%  Optionally the table can include test statistics.  Normally the
%  F statistic is most appropriate, which compares the mean square for a
%  row to the residual sum of squares for the largest model considered.
%  If \code{scale} is specified chi-squared tests can be used. Mallows'
%  \eqn{C_p}{Cp} statistic is the residual sum of squares plus twice the
%  estimate of \eqn{\sigma^2}{sigma^2} times the residual degrees of freedom.
%}
%\value{
%  An object of class \code{"anova"} inheriting from class \code{"data.frame"}.
%}
%\section{Warning}{
%  The comparison between two or more models will only be valid if they
%  are fitted to the same dataset. This may be a problem if there are
%  missing values and \R's default of \code{na.action = na.omit} is used,
%  and \code{anova.lmlist} will detect this with an error.
%}
%\references{
%  Chambers, J. M. (1992)
%  \emph{Linear models.}
%  Chapter 4 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\seealso{
%  The model fitting function \code{\link{lm}}, \code{\link{anova}}.
%
%  \code{\link{drop1}} for
%  so-called \sQuote{type II} anova where each term is dropped one at a
%  time respecting their hierarchy.
%}
%\examples{
%## sequential table
%fit <- lm(sr ~ ., data = LifeCycleSavings)
%anova(fit)
%
%## same effect via separate models
%fit0 <- lm(sr ~ 1, data = LifeCycleSavings)
%fit1 <- update(fit0, . ~ . + pop15)
%fit2 <- update(fit1, . ~ . + pop75)
%fit3 <- update(fit2, . ~ . + dpi)
%fit4 <- update(fit3, . ~ . + ddpi)
%anova(fit0, fit1, fit2, fit3, fit4, test = "F")
%
%anova(fit4, fit2, fit0, test = "F") # unconventional order
%}
%\keyword{regression}
%\keyword{models}
%
%\encoding{UTF-8}
%
