% File src/library/stats/man/approxfun.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{approxfun}
\alias{approx}%@%\alias{線形補間}
\alias{approxfun}
\title{Interpolation Functions}
\description{
  与えられたデータ点を線形に補間する点のリストを返す．
  もしくは線形(又は定数)補間をする関数を返す．
}
\usage{
approx   (x, y = NULL, xout, method = "linear", n = 50,
          yleft, yright, rule = 1, f = 0, ties = mean)

approxfun(x, y = NULL,       method = "linear",
          yleft, yright, rule = 1, f = 0, ties = mean)
}
\arguments{
  \item{x, y}{補間される点の座標を与える数値ベクトル．
    又は単一のプロット構造を指定できる：
    \code{\link{xy.coords}} を見よ．}
  \item{xout}{どこで補間が行われるかを指定するオプションの数値ベクトル．}
  \item{method}{使われる補間メソッドを指定する．
    選択肢は \code{"linear"} か \code{"constant"}．}
  \item{n}{もし \code{xout} が指定されないと，補間は
    区間 [\code{min(x)}, \code{max(x)}] を覆う
    \code{n} 個の等間隔の点で行われる．}
  \item{yleft}{
    入力 \code{x} 値が
    \code{min(x)} より小さい時に返される値．既定値は
    以下に与えられる \code{rule} の値で定義される．}
  \item{yright}{
    入力 \code{x} 値が
    \code{max(x)} より大きい時に返される値．既定値は
    以下に与えられる \code{rule} の値で定義される．}
  \item{rule}{
    区間 [\code{min(x)}, \code{max(x)}] の外で補間をどのように行うかを
    記述する整数(長さ 1 か 2)．
    もし \code{rule} が \code{1} ならそうした点に対しては
    \code{NA} が返され，
    もしそれが \code{2} なら最も近いデータの極値が使われる．
    もし左と右の補外が異なるべきならば，例えば \code{rule = 2:1} を使う．}
  \item{f}{
    \code{method = "constant"} に対しては 0 と 1 の間(0, 1 を含む)
    で，左連続と右連続なステップ関数の間の妥協を指示する．
    もし \code{y0} と \code{y1} が点の左右での値とすると
    \code{f == 0} ならば値は \code{y0}，\code{f == 1} ならば \code{y1} で，
    if , and
    中間の値では \code{ y0*(1-f)+y1*f} となる．
    このようにして結果は
    有限でない \code{y} の値に対してさえ
    \code{f == 0} に対しては右連続で
    \code{f == 1} に対しては左連続である．}
  \item{ties}{
    タイの \code{x} 値の扱い．
    引数が一つで一つの値を返す関数か，
    文字列 \code{"ordered"}．}
}
\details{
  入力は削除される欠損値を含んでいても良いので，
  少なくと二つの完全な対
  \code{(x, y)} が必要とされる(\code{method = "linear"}
  に対してはさもなければ一つ)．
  もし重複(タイ)する \code{x} 値があり
  \code{ties} が関数ならばそれが
  異なった \code{x} の値の各々で \code{y} に適用される．
  この文脈で有用な関数は
  \code{\link{mean}}, \code{\link{min}} そして \code{\link{max}}
  を含む．もし \code{ties = "ordered"} ならば
  \code{x} の値は既に順序化されているとされる．
  最初の \code{y} 値が左への補間に使われ，
  最後のそれが右への補間に使われる．
}
\value{
  \code{approx} は
  成分 \code{x} と \code{y} のりストを返す，
  これは希望の \code{method} (そして \code{rule}) に従って与えられた
  データ点を補間する \code{n} 個の座標を含む．

  関数 \code{approxfun} は与えられたデータ点で
  (線形もしくは定数)補間をする関数を返す．
  与えられた \code{x} の値の集合に対してこの関数は
  対応する補間値を返す．
  これはそれが作られた時にその環境中に保管されたデータを使うが，
  詳細は変更の可能性がある．
}
\section{警告}{
  \code{approxfun} が返す値は
  現在の \R のバージョン中のコードへの参照を含む：
  これは保存し異なった \R セッションにロードされることを意図していない．
  これは \R >= 3.0.0 ではより安全である．
}
\seealso{
  スプライン補間に対しては \code{\link{spline}} と \code{\link{splinefun}}．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
require(graphics)

x <- 1:10
y <- rnorm(10)
par(mfrow = c(2,1))
plot(x, y, main = "approx(.) and approxfun(.)")
points(approx(x, y), col = 2, pch = "*")
points(approx(x, y, method = "constant"), col = 4, pch = "*")

f <- approxfun(x, y)
curve(f(x), 0, 11, col = "green2")
points(x, y)
is.function(fc <- approxfun(x, y, method = "const")) # TRUE
curve(fc(x), 0, 10, col = "darkblue", add = TRUE)
## 左右への異なった補外：
plot(approxfun(x, y, rule = 2:1), 0, 11,
     col = "tomato", add = TRUE, lty = 3, lwd = 2)

## 'タイ'の扱いを示す：

x <- c(2,2:4,4,4,5,5,7,7,7)
y <- c(1:6, 5:4, 3:1)
approx(x, y, xout = x)$y # 警告
(ay <- approx(x, y, xout = x, ties = "ordered")$y)
stopifnot(ay == c(2,2,3,6,6,6,4,4,1,1,1))
approx(x, y, xout = x, ties = min)$y
approx(x, y, xout = x, ties = max)$y

%%-- MM has nice utility plotting -- do in demo ?
}
\keyword{arith}
\keyword{dplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/approxfun.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{approxfun}
%\alias{approx}
%\alias{approxfun}
%\title{Interpolation Functions}
%\description{
%  Return a list of points which linearly interpolate given data points,
%  or a function performing the linear (or constant) interpolation.
%}
%\usage{
%approx   (x, y = NULL, xout, method = "linear", n = 50,
%          yleft, yright, rule = 1, f = 0, ties = mean)
%
%approxfun(x, y = NULL,       method = "linear",
%          yleft, yright, rule = 1, f = 0, ties = mean)
%}
%\arguments{
%  \item{x, y}{numeric vectors giving the coordinates of the points to be
%    interpolated.  Alternatively a single plotting structure can be
%    specified: see \code{\link{xy.coords}}.}
%  \item{xout}{an optional set of numeric values specifying where
%    interpolation is to take place.}
%  \item{method}{specifies the interpolation method to be used.  Choices
%    are \code{"linear"} or \code{"constant"}.}
%  \item{n}{If \code{xout} is not specified, interpolation takes place at
%    \code{n} equally spaced points spanning the interval [\code{min(x)},
%    \code{max(x)}].}
%  \item{yleft}{the value to be returned when input \code{x} values are
%    less than \code{min(x)}. The default is defined by the value
%    of \code{rule} given below.}
%  \item{yright}{the value to be returned when input \code{x} values are
%    greater than \code{max(x)}. The default is defined by the value
%    of \code{rule} given below.}
%  \item{rule}{an integer (of length 1 or 2) describing how interpolation
%    is to take place outside the interval [\code{min(x)}, \code{max(x)}].
%    If \code{rule} is \code{1} then \code{NA}s are returned for such
%    points and if it is \code{2}, the value at the closest data extreme
%    is used.  Use, e.g., \code{rule = 2:1}, if the left and right side
%    extrapolation should differ.}
%  \item{f}{for \code{method = "constant"} a number between 0 and 1
%    inclusive, indicating a compromise between left- and 
%    right-continuous step functions. If \code{y0} and \code{y1} are
%    the values to the left and right of the point then the value is
%    \code{y0} if \code{f == 0}, \code{y1} if \code{f == 1}, and
%    \code{ y0*(1-f)+y1*f} for intermediate values. In this way the result is
%    right-continuous for \code{f == 0} and left-continuous for \code{f
%    == 1}, even for non-finite \code{y} values.}
%  \item{ties}{Handling of tied \code{x} values.  Either a function
%    with a single vector argument returning a single number result or
%    the string \code{"ordered"}.}
%}
%\details{
%  The inputs can contain missing values which are deleted, so at least
%  two complete \code{(x, y)} pairs are required (for \code{method =
%  "linear"}, one otherwise).  If there are duplicated (tied) \code{x}
%  values and \code{ties} is a function it is applied to the \code{y}
%  values for each distinct \code{x} value.
%  Useful functions in this context include \code{\link{mean}},
%  \code{\link{min}}, and \code{\link{max}}.  If \code{ties = "ordered"}
%  the \code{x} values are assumed to be already ordered.  The first
%  \code{y} value will be used for interpolation to the left and the last
%  one for interpolation to the right.
%}
%\value{
%  \code{approx} returns a list with components \code{x} and \code{y},
%  containing \code{n} coordinates which interpolate the given data
%  points according to the \code{method} (and \code{rule}) desired.
%
%  The function \code{approxfun} returns a function performing (linear or
%  constant) interpolation of the given data points.  For a given set of
%  \code{x} values, this function will return the corresponding
%  interpolated values.  It uses data stored in its environment when it
%  was created, the details of which are subject to change.
%}
%\section{Warning}{
%  The value returned by \code{approxfun} contains references to the code
%  in the current version of \R: it is not intended to be saved and
%  loaded into a different \R session.  This is safer for \R >= 3.0.0.
%}
%\seealso{
%  \code{\link{spline}} and \code{\link{splinefun}} for spline
%  interpolation.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%require(graphics)
%
%x <- 1:10
%y <- rnorm(10)
%par(mfrow = c(2,1))
%plot(x, y, main = "approx(.) and approxfun(.)")
%points(approx(x, y), col = 2, pch = "*")
%points(approx(x, y, method = "constant"), col = 4, pch = "*")
%
%f <- approxfun(x, y)
%curve(f(x), 0, 11, col = "green2")
%points(x, y)
%is.function(fc <- approxfun(x, y, method = "const")) # TRUE
%curve(fc(x), 0, 10, col = "darkblue", add = TRUE)
%## different extrapolation on left and right side :
%plot(approxfun(x, y, rule = 2:1), 0, 11,
%     col = "tomato", add = TRUE, lty = 3, lwd = 2)
%
%## Show treatment of 'ties' :
%
%x <- c(2,2:4,4,4,5,5,7,7,7)
%y <- c(1:6, 5:4, 3:1)
%approx(x, y, xout = x)$y # warning
%(ay <- approx(x, y, xout = x, ties = "ordered")$y)
%stopifnot(ay == c(2,2,3,6,6,6,4,4,1,1,1))
%approx(x, y, xout = x, ties = min)$y
%approx(x, y, xout = x, ties = max)$y
%
%%%-- MM has nice utility plotting -- do in demo ?
%}
%\keyword{arith}
%\keyword{dplot}
%
%\encoding{UTF-8}
%
