% File src/library/stats/man/bartlett.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{bartlett.test}
\alias{bartlett.test}
\alias{bartlett.test.default}
\alias{bartlett.test.formula}
\title{Bartlett Test of Homogeneity of Variances}
\description{
  各(標本)グループの分散が等しいという帰無仮説に対する
  Bartlett の検定を実行する．
}
\usage{
bartlett.test(x, \dots)

\method{bartlett.test}{default}(x, g, \dots)

\method{bartlett.test}{formula}(formula, data, subset, na.action, \dots)
}
\arguments{
  \item{x}{データ値の数値ベクトル，もしくは
    それぞれの標本を表す数値データベクトルのリスト，
    または(クラス \code{"lm"} を継承する)当てはめモデルオブジェクト．}
  \item{g}{
    \code{x} の対応する要素のグループを与えるベクトル又は因子オブジェクト．
    もし \code{x} がリストなら無視される．}
  \item{formula}{
    型式 \code{lhs ~ rhs} の公式で，\code{lhs} は
    データ値で \code{rhs} は対応するグループを表す．}
  \item{data}{
    公式 \code{formula} 中の変数を含む
    オプションの行列かデータフレーム(もしくは類似物：\code{\link{model.frame}} を見よ)
    既定では半数は \code{environment(formula)} から取られる．}
  \item{subset}{使用される観測値の部分集合を指定するオプションのベクトル．}
  \item{na.action}{
    データが \code{NA} を含んでいたら何が起きるべきかを指示する関数．
    既定では \code{getOption("na.action")}．}
  \item{\dots}{メソッドから・へ渡される追加引数．}
}
\details{
  もし \code{x} がリストならば，その要素は分散の等質性を比較される
  標本又は当てはめ線形モデルとされる．
  この場合，要素は全て数値データベクトルであるか，
  当てはめ線形モデルである必要があり，
  \code{g} は無視され，
  この検定を実行するには単に \code{bartlett.test(x)} とすれば良い．
  もし標本がまだリストに入っていなければ
  \code{bartlett.test(list(x, ...))} を使う．

  さもなければ \code{x} は数値データベクトルで，
  \code{g} は \code{x} の対応要素に対するグループを
  与える \code{x} と同じ長さのベクトルか因子オブジェクトでなければならない．
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{Bartlett の K 平方検定統計量．}
  \item{parameter}{検定統計量の近似カイ二乗分布の自由度．}
  \item{p.value}{検定のp値．}
  \item{method}{文字列
    \code{"Bartlett test of homogeneity of variances"}．}
  \item{data.name}{データのな雨を与える文字列．}
}
\seealso{
  正規分布からの二標本の分散を比較する特殊例は \code{\link{var.test}}；
  分散の等質性に対するランクに基づいた(ノンパラメトリック)な
  \eqn{k} 標本テストは \code{\link{fligner.test}}；
  スケールの違いに対するランクに基づく二標本検定は \code{\link{ansari.test}}．
}
\references{
  Bartlett, M. S. (1937).
  Properties of sufficiency and statistical tests.
  \emph{Proceedings of the Royal Society of London Series A}
  \bold{160}, 268--282.
}

% FIXME: could use something more interesting here
\examples{
require(graphics)

plot(count ~ spray, data = InsectSprays)
bartlett.test(InsectSprays$count, InsectSprays$spray)
bartlett.test(count ~ spray, data = InsectSprays)
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/bartlett.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{bartlett.test}
%\alias{bartlett.test}
%\alias{bartlett.test.default}
%\alias{bartlett.test.formula}
%\title{Bartlett Test of Homogeneity of Variances}
%\description{
%  Performs Bartlett's test of the null that the variances in each of the
%  groups (samples) are the same.
%}
%\usage{
%bartlett.test(x, \dots)
%
%\method{bartlett.test}{default}(x, g, \dots)
%
%\method{bartlett.test}{formula}(formula, data, subset, na.action, \dots)
%}
%\arguments{
%  \item{x}{a numeric vector of data values, or a list of numeric data
%    vectors representing the respective samples, or fitted linear model
%    objects (inheriting from class \code{"lm"}).}
%  \item{g}{a vector or factor object giving the group for the
%    corresponding elements of \code{x}.
%    Ignored if \code{x} is a list.}
%  \item{formula}{a formula of the form \code{lhs ~ rhs} where \code{lhs}
%    gives the data values and \code{rhs} the corresponding groups.}
%  \item{data}{an optional matrix or data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.}
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.  Defaults to
%    \code{getOption("na.action")}.}
%  \item{\dots}{further arguments to be passed to or from methods.}
%}
%\details{
%  If \code{x} is a list, its elements are taken as the samples or fitted
%  linear models to be compared for homogeneity of variances.  In this
%  case, the elements must either all be numeric data vectors or fitted
%  linear model objects, \code{g} is ignored, and one can simply use
%  \code{bartlett.test(x)} to perform the test.  If the samples are not
%  yet contained in a list, use \code{bartlett.test(list(x, ...))}.
%
%  Otherwise, \code{x} must be a numeric data vector, and \code{g} must
%  be a vector or factor object of the same length as \code{x} giving the
%  group for the corresponding elements of \code{x}.
%}
%\value{
%  A list of class \code{"htest"} containing the following components:
%  \item{statistic}{Bartlett's K-squared test statistic.}
%  \item{parameter}{the degrees of freedom of the approximate chi-squared
%    distribution of the test statistic.}
%  \item{p.value}{the p-value of the test.}
%  \item{method}{the character string
%    \code{"Bartlett test of homogeneity of variances"}.}
%  \item{data.name}{a character string giving the names of the data.}
%}
%\seealso{
%  \code{\link{var.test}} for the special case of comparing variances in
%  two samples from normal distributions;
%  \code{\link{fligner.test}} for a rank-based (nonparametric)
%  \eqn{k}-sample test for homogeneity of variances;
%  \code{\link{ansari.test}} and \code{\link{mood.test}} for two rank
%  based two-sample tests for difference in scale.
%}
%\references{
%  Bartlett, M. S. (1937).
%  Properties of sufficiency and statistical tests.
%  \emph{Proceedings of the Royal Society of London Series A}
%  \bold{160}, 268--282.
%}
%
%% FIXME: could use something more interesting here
%\examples{
%require(graphics)
%
%plot(count ~ spray, data = InsectSprays)
%bartlett.test(InsectSprays$count, InsectSprays$spray)
%bartlett.test(count ~ spray, data = InsectSprays)
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%