% File src/library/stats/man/biplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{biplot}
\alias{biplot}
\alias{biplot.default}
\title{Biplot of Multivariate Data}
\usage{
biplot(x, \dots)

\method{biplot}{default}(x, y, var.axes = TRUE, col, cex = rep(par("cex"), 2),
       xlabs = NULL, ylabs = NULL, expand = 1,
       xlim  = NULL, ylim  = NULL, arrow.len = 0.1,
       main = NULL, sub = NULL, xlab = NULL, ylab = NULL, \dots)
}
\arguments{
  \item{x}{\code{biplot}，当てはめオブジェクト．
    \code{biplot.default} に対しては点の最初のセット
    (2列の行列)で，普通観測値に関係する．}
  \item{y}{点の二番目のセット(2列の行列)，普通観測値に関係する．}
  \item{var.axes}{もし \code{TRUE} なら点の二番目のセットは
    それらを(スケール化されていない)軸として表す矢印を持つ．}
  \item{col}{それぞれ第一と第二の点のセットの色を与える
    長さ 2 のベクトル
    (と対応する軸)．
    もし単一の色が与えられるとそれが両方のセットに対して使われる．
    もし欠損していれば既定色が
    \code{\link{palette}} 中で探される：
    もしあればそれと次の色が使われる：
    さもなければパレット中の最初の二つの色が使われる．}
  \item{cex}{点のラベルに使われる文字の拡大率．
    長さ 2 のベクトルを与えることで二つのセットで異なる大きさの
    ラベルを使うことが出来る．}
  \item{xlabs}{最初の点のセットのラベルの文字列ベクトル：
    既定では \code{x} の行の次元名を使う，又は
    もし次元名が \code{NULL} なら \code{1:n}．}
  \item{ylabs}{二番目の点のセットのラベルの文字列ベクトル：
    既定では \code{y} の行の次元名を使う，又は
    もし次元名が \code{NULL} なら \code{1:n}．}
  \item{expand}{二番目の点のセットをプロットするとき提供される
    最初のセットに相対的な拡大率．
    これは二つのセットを物理的に比較可能なスケールに微調整するのに
    使うことが出来る．}
  \item{arrow.len}{
    \code{var.axes} が真の時プロットされる矢印の矢尻の長さ．
    矢尻は \code{arrow.len = 0} で抑制できる．}
  \item{xlim, ylim}{最初の変数のセットの単位での
    x と y 軸の限界．}
  \item{main, sub, xlab, ylab, \dots}{グラフィカルパラメータ．}
}
\description{
  現在のデバイス上にバイプロットをプロットする．
}
\details{
  バイプロットは観測値と多変量データの行列の変数を
  同じプロット上に表現しようとするプロットである．
  バイプロットには様々な変種がある(参考文献を見よ)が，
  恐らく最も広く使われているものが \code{\link{biplot.princomp}} に
  実装されている．
  関数 \code{biplot.default} は
  二つの変数のセットを同じ図上にプロットする背景にある
  コードを単に提供する．

  グラフィカルパラメータを又
  \code{biplot} に与えることができる：
  \code{xlabs} と \code{ylabs} のサイズは
  \code{cex} で制御される．
}
\section{副作用}{
  現在のグラフィックスデバイス上にプロットが作られる．
}
\references{
  K. R. Gabriel (1971).  The biplot graphical display of matrices with
  application to principal component analysis. \emph{Biometrika}
  \bold{58}, 453--467.

  J.C. Gower and D. J. Hand (1996). \emph{Biplots}. Chapman & Hall.
}
\seealso{\code{\link{biplot.princomp}}，又その例．}
\keyword{hplot}
\keyword{multivariate}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/biplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{biplot}
%\alias{biplot}
%\alias{biplot.default}
%\title{Biplot of Multivariate Data}
%\usage{
%biplot(x, \dots)
%
%\method{biplot}{default}(x, y, var.axes = TRUE, col, cex = rep(par("cex"), 2),
%       xlabs = NULL, ylabs = NULL, expand = 1,
%       xlim  = NULL, ylim  = NULL, arrow.len = 0.1,
%       main = NULL, sub = NULL, xlab = NULL, ylab = NULL, \dots)
%}
%\arguments{
%  \item{x}{The \code{biplot}, a fitted object. For \code{biplot.default},
%    the first set of points (a two-column matrix), usually associated
%    with observations.}
%  \item{y}{The second set of points (a two-column matrix), usually associated
%    with variables.}
%  \item{var.axes}{If \code{TRUE} the second set of points have arrows
%    representing them as (unscaled) axes.}
%  \item{col}{A vector of length 2 giving the colours for the first and
%    second set of points respectively (and the corresponding axes). If a
%    single colour is specified it will be used for both sets.  If
%    missing the default colour is looked for in the
%    \code{\link{palette}}: if there it and the next colour as used,
%    otherwise the first two colours of the palette are used.}
%  \item{cex}{The character expansion factor used for labelling the
%    points. The labels can be of different sizes for the two sets by
%    supplying a vector of length two.}
%  \item{xlabs}{A vector of character strings to label the first set of
%    points: the default is to use the row dimname of \code{x}, or
%    \code{1:n} if the dimname is \code{NULL}.}
%  \item{ylabs}{A vector of character strings to label the second set of
%    points: the default is to use the row dimname of \code{y}, or
%    \code{1:n} if the dimname is \code{NULL}.}
%  \item{expand}{An expansion factor to apply when plotting the second set
%    of points relative to the first. This can be used to tweak the
%    scaling of the two sets to a physically comparable scale.}
%  \item{arrow.len}{The length of the arrow heads on the axes plotted in
%    \code{var.axes} is true. The arrow head can be suppressed by
%    \code{arrow.len = 0}.}
%  \item{xlim, ylim}{Limits for the x and y axes in the units of the
%    first set of variables.}
%  \item{main, sub, xlab, ylab, \dots}{graphical parameters.}
%}
%\description{
%  Plot a biplot on the current graphics device.
%}
%\details{
%  A biplot is plot which aims to represent both the observations and
%  variables of a matrix of multivariate data on the same plot. There are
%  many variations on biplots (see the references) and perhaps the most
%  widely used one is implemented by \code{\link{biplot.princomp}}.
%  The function \code{biplot.default} merely provides the
%  underlying code to plot two sets of variables on the same figure.
%
%  Graphical parameters can also be given to \code{biplot}: the size of
%  \code{xlabs} and \code{ylabs} is controlled by \code{cex}.
%}
%\section{Side Effects}{
%  a plot is produced on the current graphics device.
%}
%\references{
%  K. R. Gabriel (1971).  The biplot graphical display of matrices with
%  application to principal component analysis. \emph{Biometrika}
%  \bold{58}, 453--467.
%
%  J.C. Gower and D. J. Hand (1996). \emph{Biplots}. Chapman & Hall.
%}
%\seealso{\code{\link{biplot.princomp}}, also for examples.}
%\keyword{hplot}
%\keyword{multivariate}
%
%\encoding{UTF-8}
%