% File src/library/stats/man/contrasts.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{contrasts}
\alias{contrasts}%@%\alias{対比の設定}
\alias{contrasts<-}
\title{Get and Set Contrast Matrices}
\description{
  因子に関連した対比を設定したり眺めたりする．
}
\usage{
contrasts(x, contrasts = TRUE, sparse = FALSE)
contrasts(x, how.many) <- value
}
\arguments{
  \item{x}{因子化論理値変数．}
  \item{contrasts}{論理値．\sQuote{詳細}を見よ．}
  \item{sparse}{結果が疎であるべきかどうかを指示する論理値
    (クラス \code{\link[Matrix:dgCMatrix-class]{dgCMatrix}})で
    パッケージ \CRANpkg{Matrix} を使う．}
  \item{how.many}{幾つの対比を作るべきか．
    既定では \code{x} の水準数から 1 を引いたもの．
    これは \code{value} の列数と同じである必要はない．}
  \item{value}{数値行列か(又は
    パッケージ \CRANpkg{Matrix} の
    \code{\link[Matrix:dMatrix-class]{dMatrix}} を
    拡張するクラスの疎か密な行列)で
    その列が
    \code{x} の水準中の対比に対する係数を与える，
    又はそうした行列を計算する関数の(引用化された)名前．}
}
\details{
  もし因子に対して対比が設定されていないと
  \code{\link{options}("contrasts")} からの既定の関数が使われる．

  論理値ベクトル \code{x} は
  水準 \code{c(FALSE, TRUE)} を持つニ水準の因子に変換される
  (変数中にどのような水準が現れるかとは無関係に)．

  引数 \code{contrasts} はもし
  \code{x} が行列の
  \code{contrasts} 属性セットを持てば無視される．
  さもなければ，もし
  \code{contrasts = TRUE} ならばそれは
  \code{\link{contr.treatment}} のような関数に渡され，
  そしてもし \code{contrasts = FALSE} ならば単位行列が返される．
  適当な関数は水準の文字列ベクトルである最初の引数，
  名前付き引数
  \code{contrasts} (常に \code{contrasts = TRUE} と共に呼び出される) そして
  オプションで論理値引数
  \code{sparse} を持つ．

  もし \code{value} が
  \code{how.many} 以上の対比を提供すると，
  最初の \code{how.many} 個が使われる．
  もし少なすぎると
  \code{value} を拡張する適当な対比行列が
  その列が対比で
  (定数項に対して直交)で共線形でないように作られる．
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical models.}
  Chapter 2 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{C}},% ./zC.Rd
  \code{\link{contr.helmert}},
  \code{\link{contr.poly}},
  \code{\link{contr.sum}},
  \code{\link{contr.treatment}};
  \code{\link{glm}},
  \code{\link{aov}},
  \code{\link{lm}}.
}
\examples{
utils::example(factor)
fff <- ff[, drop = TRUE]  # 5 水準に縮小．
contrasts(fff) # 既定で処理対比
contrasts(C(fff, sum))
contrasts(fff, contrasts = FALSE) # 5x5 単位行列

contrasts(fff) <- contr.sum(5); contrasts(fff)  # 和対比を設定
contrasts(fff, 2) <- contr.sum(5); contrasts(fff)  # 2 対比を設定
# 2つの対比を設定し，もう2つを計算して4つの完全な対比を作る．
contrasts(fff) <- contr.sum(5)[, 1:2]; contrasts(fff)

\donttest{## 疎な対比を作る：% model.matrix() がこれらと共に動作すれば有用：
ffs <- fff
contrasts(ffs) <- contr.sum(5, sparse = TRUE)[, 1:2]; contrasts(ffs)
stopifnot(all.equal(ffs, fff))
contrasts(ffs) <- contr.sum(5, sparse = TRUE); contrasts(ffs)
}}
\keyword{design}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/contrasts.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{contrasts}
%\alias{contrasts}
%\alias{contrasts<-}
%\title{Get and Set Contrast Matrices}
%\description{
%  Set and view the contrasts associated with a factor.
%}
%\usage{
%contrasts(x, contrasts = TRUE, sparse = FALSE)
%contrasts(x, how.many) <- value
%}
%\arguments{
%  \item{x}{a factor or a logical variable.}
%  \item{contrasts}{logical.  See \sQuote{Details}.}
%  \item{sparse}{logical indicating if the result should be sparse
%    (of class \code{\link[Matrix:dgCMatrix-class]{dgCMatrix}}), using
%    package \CRANpkg{Matrix}.}
%  \item{how.many}{How many contrasts should be made. Defaults to one
%    less than the number of levels of \code{x}.  This need not be the
%    same as the number of columns of \code{value}.}
%  \item{value}{either a numeric matrix (or a sparse or dense matrix of a
%    class extending \code{\link[Matrix:dMatrix-class]{dMatrix}} from
%    package \CRANpkg{Matrix})  whose columns give coefficients for
%    contrasts in the levels of \code{x}, or the (quoted) name of a
%    function which computes such matrices.}
%}
%\details{
%  If contrasts are not set for a factor the default functions from
%  \code{\link{options}("contrasts")} are used.
%
%  A logical vector \code{x} is converted into a two-level factor with
%  levels \code{c(FALSE, TRUE)} (regardless of which levels occur in the
%  variable).
%
%  The argument \code{contrasts} is ignored if \code{x} has a matrix
%  \code{contrasts} attribute set.  Otherwise if \code{contrasts = TRUE}
%  it is passed to a contrasts function such as
%  \code{\link{contr.treatment}} and if \code{contrasts = FALSE}
%  an identity matrix is returned.  Suitable functions have a first
%  argument which is the character vector of levels, a named argument
%  \code{contrasts} (always called with \code{contrasts = TRUE}) and
%  optionally a logical argument \code{sparse}.
%
%  If \code{value} supplies more than \code{how.many} contrasts, the
%  first \code{how.many} are used.  If too few are supplied, a suitable
%  contrast matrix is created by extending \code{value} after ensuring
%  its columns are contrasts (orthogonal to the constant term) and not
%  collinear.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical models.}
%  Chapter 2 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{C}},% ./zC.Rd
%  \code{\link{contr.helmert}},
%  \code{\link{contr.poly}},
%  \code{\link{contr.sum}},
%  \code{\link{contr.treatment}};
%  \code{\link{glm}},
%  \code{\link{aov}},
%  \code{\link{lm}}.
%}
%\examples{
%utils::example(factor)
%fff <- ff[, drop = TRUE]  # reduce to 5 levels.
%contrasts(fff) # treatment contrasts by default
%contrasts(C(fff, sum))
%contrasts(fff, contrasts = FALSE) # the 5x5 identity matrix
%
%contrasts(fff) <- contr.sum(5); contrasts(fff)  # set sum contrasts
%contrasts(fff, 2) <- contr.sum(5); contrasts(fff)  # set 2 contrasts
%# supply 2 contrasts, compute 2 more to make full set of 4.
%contrasts(fff) <- contr.sum(5)[, 1:2]; contrasts(fff)
%
%\donttest{## using sparse contrasts: % useful, once model.matrix() works with these :
%ffs <- fff
%contrasts(ffs) <- contr.sum(5, sparse = TRUE)[, 1:2]; contrasts(ffs)
%stopifnot(all.equal(ffs, fff))
%contrasts(ffs) <- contr.sum(5, sparse = TRUE); contrasts(ffs)
%}}
%\keyword{design}
%\keyword{regression}
%
%\encoding{UTF-8}
%
