% File src/library/stats/man/fligner.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{fligner.test}
\alias{fligner.test}%@%\alias{分散の同質性に対する Fligner-Killeen 検定}
\alias{fligner.test.default}
\alias{fligner.test.formula}
\title{Fligner-Killeen Test of Homogeneity of Variances}
\description{
  各グループ(標本)の分散が同じであるという帰無仮説に対する
  Fligner-Killeen の(中央値)検定を実行する．
}
\usage{
fligner.test(x, \dots)

\method{fligner.test}{default}(x, g, \dots)

\method{fligner.test}{formula}(formula, data, subset, na.action, \dots)
}
\arguments{
  \item{x}{データ値の数値ベクトル，又は数値データベクトルのリスト．}
  \item{g}{\code{x} の要素のグループを与える因子オブジェクト又はベクトル．
    もし \code{x} がリストなら無視される．}
  \item{formula}{型式 \code{lhs ~ rhs} の公式で，ここで
    \code{lhs} はデータ値を与え，
    \code{rhs} は対応するグループを与える．}
  \item{data}{オプションの行列又はデータフレーム(又は類似物：
    \code{\link{model.frame}} を見よ)で
    公式 \code{formula} 中の変数を含む．既定では変数は
    \code{environment(formula)} から取られる．}
  \item{subset}{使われる観測値の部分集合を指定するオプションの
    ベクトル．}
  \item{na.action}{データが \code{NA} を含む時何が起こるかを指示する関数．
    既定では\cr
    \code{getOption("na.action")}．}
  \item{\dots}{メソッドから・へ渡される追加引数．}
}
\details{
  もし \code{x} がリストならば，その要素は分散の同質性を比較される標本とされ，
  従って数値データベクトルでなければならない．
  この場合 \code{g} は無視され，検定は単に
  \code{fligner.test(x)} を使う．もし標本が未だリストに
  含まれていなければ
  \code{fligner.test(list(x, ...))} を使う．

  さもなければ，\code{x} は数値データベクトルで，
  \code{g} は \code{x} と同じ長さのはベクトルか因子オブジェクト
  でなければならず，
  対応する \code{x} の要素に対するグループを与える．

  Fligner-Killeen (中央値)検定はシミュレーション研究で
  分散の同質性に対する多くの検定の中で正規性からの
  乖離に対して最も頑健であるとされた，
  Conover, Johnson & Johnson (1981) を見よ．
  これは \eqn{k} 標本の単純な線形ランクであり，
  中心化された標本の絶対値のランクと重み
  \eqn{a(i) = \mathrm{qnorm}((1 + i/(n+1))/2)}{a(i) = qnorm((1 +
    i/(n+1))/2)} を使う．ここで実装されたバージョンは
  各標本中の中央値で中心化されたものを使う
  (文献では F-K:med \eqn{X^2})．
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{Fligner-Killeen:med \eqn{X^2} 検定統計量．}
  \item{parameter}{検定統計量の近似カイ二乗分布の自由度．}
  \item{p.value}{検定の p 値．}
  \item{method}{文字列\sspace{}
    \code{"Fligner-Killeen test of homogeneity of variances"}.}
  \item{data.name}{データの名前を与える文字列．}
}
\references{
  William J. Conover, Mark E. Johnson and Myrle M. Johnson (1981).
  A comparative study of tests for homogeneity of variances, with
  applications to the outer continental shelf bidding data.
  \emph{Technometrics} \bold{23}, 351--361.
}
\seealso{
  スケールパラメータの違いに対するランクに基づく二標本検定は
  \code{\link{ansari.test}} と \code{\link{mood.test}}；
  分散の同質性に対するパラメトリックな検定は
  \code{\link{var.test}} と \code{\link{bartlett.test}}．
}

% FIXME: could use something more interesting here
\examples{
require(graphics)

plot(count ~ spray, data = InsectSprays)
fligner.test(InsectSprays$count, InsectSprays$spray)
fligner.test(count ~ spray, data = InsectSprays)
## これを bartlett.test() と比較せよ
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/fligner.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{fligner.test}
%\alias{fligner.test}
%\alias{fligner.test.default}
%\alias{fligner.test.formula}
%\title{Fligner-Killeen Test of Homogeneity of Variances}
%\description{
%  Performs a Fligner-Killeen (median) test of the null that the
%  variances in each of the groups (samples) are the same.
%}
%\usage{
%fligner.test(x, \dots)
%
%\method{fligner.test}{default}(x, g, \dots)
%
%\method{fligner.test}{formula}(formula, data, subset, na.action, \dots)
%}
%\arguments{
%  \item{x}{a numeric vector of data values, or a list of numeric data
%    vectors.}
%  \item{g}{a vector or factor object giving the group for the
%    corresponding elements of \code{x}.
%    Ignored if \code{x} is a list.}
%  \item{formula}{a formula of the form \code{lhs ~ rhs} where \code{lhs}
%    gives the data values and \code{rhs} the corresponding groups.}
%  \item{data}{an optional matrix or data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.}
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.  Defaults to
%    \code{getOption("na.action")}.}
%  \item{\dots}{further arguments to be passed to or from methods.}
%}
%\details{
%  If \code{x} is a list, its elements are taken as the samples to be
%  compared for homogeneity of variances, and hence have to be numeric
%  data vectors.  In this case, \code{g} is ignored, and one can simply
%  use \code{fligner.test(x)} to perform the test.  If the samples are
%  not yet contained in a list, use \code{fligner.test(list(x, ...))}.
%
%  Otherwise, \code{x} must be a numeric data vector, and \code{g} must
%  be a vector or factor object of the same length as \code{x} giving the
%  group for the corresponding elements of \code{x}.
%
%  The Fligner-Killeen (median) test has been determined in a simulation
%  study as one of the many tests for homogeneity of variances which is
%  most robust against departures from normality, see Conover, Johnson &
%  Johnson (1981).  It is a \eqn{k}-sample simple linear rank which uses
%  the ranks of the absolute values of the centered samples and weights
%  \eqn{a(i) = \mathrm{qnorm}((1 + i/(n+1))/2)}{a(i) = qnorm((1 +
%    i/(n+1))/2)}.  The version implemented here uses median centering in
%  each of the samples (F-K:med \eqn{X^2} in the reference).
%}
%\value{
%  A list of class \code{"htest"} containing the following components:
%  \item{statistic}{the Fligner-Killeen:med \eqn{X^2} test statistic.}
%  \item{parameter}{the degrees of freedom of the approximate chi-squared
%    distribution of the test statistic.}
%  \item{p.value}{the p-value of the test.}
%  \item{method}{the character string
%    \code{"Fligner-Killeen test of homogeneity of variances"}.}
%  \item{data.name}{a character string giving the names of the data.}
%}
%\references{
%  William J. Conover, Mark E. Johnson and Myrle M. Johnson (1981).
%  A comparative study of tests for homogeneity of variances, with
%  applications to the outer continental shelf bidding data.
%  \emph{Technometrics} \bold{23}, 351--361.
%}
%\seealso{
%  \code{\link{ansari.test}} and \code{\link{mood.test}} for rank-based
%  two-sample test for a difference in scale parameters;
%  \code{\link{var.test}} and \code{\link{bartlett.test}} for parametric
%  tests for the homogeneity of variances.
%}
%
%% FIXME: could use something more interesting here
%\examples{
%require(graphics)
%
%plot(count ~ spray, data = InsectSprays)
%fligner.test(InsectSprays$count, InsectSprays$spray)
%fligner.test(count ~ spray, data = InsectSprays)
%## Compare this to bartlett.test()
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
