% File src/library/stats/man/hclust.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{hclust}
\title{Hierarchical Clustering}
\alias{hclust}%@%\alias{階層的クラスタリング}
\alias{plot.hclust}
\alias{print.hclust}
\description{
  非類似度のセットに関する階層的クラスタリングと
  それを解析するメソッド．
}
\usage{
hclust(d, method = "complete", members = NULL)

\method{plot}{hclust}(x, labels = NULL, hang = 0.1, check = TRUE,
     axes = TRUE, frame.plot = FALSE, ann = TRUE,
     main = "Cluster Dendrogram",
     sub = NULL, xlab = NULL, ylab = "Height", \dots)
}
\arguments{
  \item{d}{\code{dist} によって作られた非類似度構造．}

  \item{method}{使われる集積化メソッド．
    これは以下の(曖昧さのない省略)の一つであるべきである；
    \code{"ward.D"}, \code{"ward.D2"}, \code{"single"}, \code{"complete"},
    \code{"average"} (= UPGMA), \code{"mcquitty"} (= WPGMA),
    \code{"median"} (= WPGMC) 又は \code{"centroid"} (= UPGMC)．}

  \item{members}{\code{NULL} 又は
    \code{d} のサイズの長さのベクトル．\sQuote{詳細}節を見よ．}

  \item{x}{\code{hclust} で作られるタイプのオブジェクト．}

  \item{hang}{
    ラベルがその分残りのプロットの下にぶら下げられる
    プロット高さの割合．
    負の値はラベルが 0 からぶら下げられるようにする．}

  \item{check}{
    \code{x} オブジェクトの適正さをチェックすべきかどうかを指示する論理値．
    このチェックは \code{x} が
    それが \code{hclust()} の直接の結果である時のように
    適正であることがわかっていれば不要である．
    不正な入力は内部のプロット用 C コードがメモリ乱用で \R を
    クラッシュさせるかもしれないので
    既定は \code{check=TRUE} である．}
    
  \item{labels}{ツリーの葉に対するラベルの文字列ベクトル．
    既定ではオリジナルのデータの行番号か列番号が
    使われる．
    もし \code{labels = FALSE} ならばラベルは一切プロットされない．}

  \item{axes, frame.plot, ann}{
    \code{\link{plot.default}} に於けるような論理フラグ．}

  \item{main, sub, xlab, ylab}{
    \code{\link{title}} に対する文字列．
    \code{tree$call} があれば NULL でない既定値を持つ．}
    
  \item{\dots}{追加のグラフィカル引数．
    他追えば \code{cex} は(もしプロットされれば)
    \code{\link{text}} と同様にラベルのサイズを制御する．}
}
\value{
  クラス \bold{hclust} のオブジェクトでクラスタ化で作られたツリーを
  記述する．オブジェクトは次の成分を持つリストである：
  \item{merge}{\eqn{n-1} x 2 行列．
    \code{merge} の行 \eqn{i} はクラスターのステップ
    \eqn{i} でのマージを記述する．
    もし行の要素 \eqn{j} が負ならば，
    観測値 \eqn{-j} がこの段階でマージされている．
    もし \eqn{j} が正ならばクラスターへのマージは
    アルゴリズムの(初期の)段階でなされている．
    このように \code{merge} 中の負の項目は
    単一のものの集積を指示し，正の項目は単一でないものの
    集積を指示する．}

  \item{height}{
    \eqn{n-1} 個の実数の集合(ウルトラメトリックなツリーに対しては
    非減少)．
    クラスタリングの\emph{高さ}：つまり，特定の集積に対する
    クラスタリングメソッドに関連する基準値．}

  \item{order}{
    オリジナルの観測値のプロットに相応しい置換を与えるベクトル．
    つまりこの順序と行列 \code{merge} を用いたクラスターのプロットは
    枝が交差しない．}

  \item{labels}{クラスター化される各オブジェクトに対するラベル．}

  \item{call}{結果を作り出した呼び出し．}

  \item{method}{使用されたクラスター手法．}

  \item{dist.method}{
    \code{d} を作るのに使われた距離
    (距離オブジェクトが
    \code{"method"} 属性を持つ時だけ返される)．}

  \code{\link{print}}, \code{\link{plot}} そして \code{identify}
  (\code{\link{identify.hclust}} を見よ)メソッドがあり，
  \code{hclust} オブジェクトに対する関数
  \code{\link{rect.hclust}()} がある．
}
\details{
  この関数はクラスター化される \eqn{n} 個のオブジェクトに対する
  非類似度のセットを用いた階層的クラスター解析を実行する．
  最初，各オブジェクトはそれ自体のクラスターを与えられ
  それからアルゴリズムは繰り返しながら進行する．
  各ステージで二つの最も類似したクラスターを結合し，
  たった一つのクラスターになるまで続けられる．
  各ステージでクラスター間の距離が
  使われる特定のクラスタリング手法に従い
  Lance--Williams の非類似度更新公式により
  再計算される．

  幾つかの異なったクラスタリング手法が低供されている．
  \emph{Ward} の最少分散法はコンパクトで球状のクラスターを
  目指す．
  \emph{完全リンケージ}法は類似したクラスターを探す．
  \emph{単一リンケージ}法(これは最少スパンニングツリーに密接な関係がある)
  は\sQuote{友人の友人}クラスタリング戦略を用いる．
  他の手法は単一法とと完全リンク法の間の
  特性を持つクラスターを目指していると見做せる．
  しかしながら，\code{"median"} 法と
  \code{"centroid"} 法は
  \emph{単調距離}測度に\emph{導かれない}ことを注意する．
  又は同値であるが結果のデンドログラムは
  解釈が困難であるがいわゆる
  \emph{逆}又は\emph{反転}を持つことが出来るが，
  Legendre and Legendre (2012) 中の三分法を注意しよう．

  Ward クラスタリングに対しては文献中に二つの異なった
  アルゴリズムがある．オプション \code{"ward.D"}
  \R バージョン \eqn{\le}{<=} 3.0.3 では唯一の Ward オプション
  \code{"ward"} に同値)は
  Ward (1963) のクラスタリング基準を実装
  \emph{していない}一方，
  オプション \code{"ward.D2"} はその基準
  (Murtagh and Legendre 2014)を実装している．
  後者に関しては非類似度はクラスタリング前に
  \emph{二乗}されている．
  \code{\link[cluster]{agnes}(*, method="ward")} は
  \code{hclust(*, "ward.D2")} に対応する．

  もし \code{members != NULL} ならば，\code{d} は
  単一物間の非類似度の代わりにクラスター間の非類似度行列
  とされ，\code{members} はクラスター当たりの観測値数を与える．
  このように階層的クラスターアルゴリズムは，
  例えばカットの上のツリー部分を再構成するために
  (例を見よ)，\sQuote{デンドログラムの中心から出発}することが出来る，
  クラスター間の非類似度は
  限られた距離/リンケージの組み合わせの数に対してだけ
  効率的に計算できる(例えば \code{hclust} 自体無しに)．
  最も簡単なものは\emph{二乗}ユークリッド距離とセントロイドリンケージ
  である．この場合クラスター間の非類似度はクラスター平均の間の
  ユークリッド距離の二乗である．

  階層的クラスターの表示では
  各マージでどの副ツリーが左に行きどれが右に行くかを指定する
  決定が必要になる．
  各 \eqn{n} 個の観測値に対しては \eqn{n-1} 個のマージがあるため，
  クラスターツリー又はデンドログラム中には \eqn{2^{(n-1)}} 通りの可能な
  葉の順序がある．
  \code{hclust} 中で使われるアルゴリズムは副ツリーを
  より密なクラスターが左
  (最後，つまり直近，の左の副ツリーが
  右の副ツリーの最後のマージよりも下の値に位置する)
  に行くように順序付ける．
  単一の観測値は可能な最も密なクラスターであり，
  そして二つの観測値を含むマージはそれらを
  それらの観測列番号の順序で置く．
}
\note{
  メソッド \code{"centroid"} に対しては典型的に
  \emph{二乗化}ユークリッド距離を用いることが含意されている．
}
\references{ 
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole. (S version.)

  Everitt, B. (1974).
  \emph{Cluster Analysis}.
  London: Heinemann Educ. Books.

  Hartigan, J.A. (1975).
  \emph{Clustering  Algorithms}.
  New York: Wiley.

  Sneath, P. H. A. and R. R. Sokal (1973).
  \emph{Numerical Taxonomy}.
  San Francisco: Freeman.

  Anderberg, M. R. (1973).
  \emph{Cluster Analysis for Applications}.
  Academic Press: New York.

  Gordon, A. D. (1999).
  \emph{Classification}. Second Edition.
  London: Chapman and Hall / CRC

  Murtagh, F. (1985).
  \dQuote{Multidimensional Clustering Algorithms}, in
  \emph{COMPSTAT Lectures 4}.
  Wuerzburg: Physica-Verlag
  (for algorithmic details of algorithms used).

  McQuitty, L.L. (1966).
  Similarity Analysis by Reciprocal Pairs for Discrete and Continuous
  Data.
  \emph{Educational and Psychological Measurement}, \bold{26}, 825--831.

  Legendre, P. and L. Legendre (2012).
  \emph{Numerical Ecology},
  3rd English ed. Amsterdam: Elsevier Science BV.

  Murtagh, Fionn and Legendre, Pierre (2014).
  Ward's hierarchical agglomerative clustering method: which algorithms
  implement Ward's criterion?
  \emph{Journal of Classification} \bold{31} (forthcoming).
}
\author{
  \code{hclust} 関数は
  F. Murtagh により STATLIB に提供された
  Fortran コードに基づく．
}
\seealso{
  \code{\link{identify.hclust}}, \code{\link{rect.hclust}},
  \code{\link{cutree}}, \code{\link{dendrogram}}, \code{\link{kmeans}}.

  Lance--Williams 公式とそれに一般に適用されるメソッドに
  対してはパッケージ \CRANpkg{cluster} の
  \code{\link[cluster]{agnes}} を見よ．
}
\examples{
require(graphics)

### 例 1：USの州の暴力犯罪率

hc <- hclust(dist(USArrests), "ave")
plot(hc)
plot(hc, hang = -1)

## 同じことをセントロイドクラスタリングと*二乗化*ユークリッド距離で行う，
## ツリーを10のクラスターに分割し，ツリーの上部をクラスター中心から再構成
hc <- hclust(dist(USArrests)^2, "cen")
memb <- cutree(hc, k = 10)
cent <- NULL
for(k in 1:10){
  cent <- rbind(cent, colMeans(USArrests[memb == k, , drop = FALSE]))
}
hc1 <- hclust(dist(cent)^2, method = "cen", members = table(memb))
opar <- par(mfrow = c(1, 2))
plot(hc,  labels = FALSE, hang = -1, main = "Original Tree")
plot(hc1, labels = FALSE, hang = -1, main = "Re-start from 10 clusters")
par(opar)

### 例 2：US の10の都市間の直線距離
##  アルゴリズム "ward.D" と "ward.D2" の結果を比較せよ

data(UScitiesD)

mds2 <- -cmdscale(UScitiesD)
plot(mds2, type="n", axes=FALSE, ann=FALSE)
text(mds2, labels=rownames(mds2), xpd = NA)

hcity.D  <- hclust(UScitiesD, "ward.D") # "wrong"
hcity.D2 <- hclust(UScitiesD, "ward.D2")
opar <- par(mfrow = c(1, 2))
plot(hcity.D,  hang=-1)
plot(hcity.D2, hang=-1)
par(opar)
}
\keyword{multivariate}
\keyword{cluster}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/hclust.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{hclust}
%\title{Hierarchical Clustering}
%\alias{hclust}
%\alias{plot.hclust}
%\alias{print.hclust}
%\description{
%  Hierarchical cluster analysis on a set of dissimilarities and
%  methods for analyzing it.
%}
%\usage{
%hclust(d, method = "complete", members = NULL)
%
%\method{plot}{hclust}(x, labels = NULL, hang = 0.1, check = TRUE,
%     axes = TRUE, frame.plot = FALSE, ann = TRUE,
%     main = "Cluster Dendrogram",
%     sub = NULL, xlab = NULL, ylab = "Height", \dots)
%}
%\arguments{
%  \item{d}{a dissimilarity structure as produced by \code{dist}.}
%
%  \item{method}{the agglomeration method to be used.  This should
%    be (an unambiguous abbreviation of) one of
%    \code{"ward.D"}, \code{"ward.D2"}, \code{"single"}, \code{"complete"},
%    \code{"average"} (= UPGMA), \code{"mcquitty"} (= WPGMA),
%    \code{"median"} (= WPGMC) or \code{"centroid"} (= UPGMC).}
%
%  \item{members}{\code{NULL} or a vector with length size of
%    \code{d}. See the \sQuote{Details} section.}
%
%  \item{x}{an object of the type produced by \code{hclust}.}
%
%  \item{hang}{The fraction of the plot height by which labels should hang
%    below the rest of the plot.
%    A negative value will cause the labels to hang down from 0.}
%  \item{check}{logical indicating if the \code{x} object should be
%    checked for validity.  This check is not necessary when \code{x}
%    is known to be valid such as when it is the direct result of
%    \code{hclust()}.  The default is \code{check=TRUE}, as invalid
%    inputs may crash \R due to memory violation in the internal C
%    plotting code.}
%  \item{labels}{A character vector of labels for the leaves of the
%    tree.  By default the row names or row numbers of the original data are
%    used.  If \code{labels = FALSE} no labels at all are plotted.}
%
%  \item{axes, frame.plot, ann}{logical flags as in \code{\link{plot.default}}.}
%
%  \item{main, sub, xlab, ylab}{character strings for
%    \code{\link{title}}.  \code{sub} and \code{xlab} have a non-NULL
%    default when there's a \code{tree$call}.}
%  \item{\dots}{Further graphical arguments.  E.g., \code{cex} controls
%    the size of the labels (if plotted) in the same way as \code{\link{text}}.}
%}
%\value{
%  An object of class \bold{hclust} which describes the
%  tree produced by the clustering process.
%  The object is a list with components:
%  \item{merge}{an \eqn{n-1} by 2 matrix.
%    Row \eqn{i} of \code{merge} describes the merging of clusters
%    at step \eqn{i} of the clustering.
%    If an element \eqn{j} in the row is negative,
%    then observation \eqn{-j} was merged at this stage.
%    If \eqn{j} is positive then the merge
%    was with the cluster formed at the (earlier) stage \eqn{j}
%    of the algorithm.
%    Thus negative entries in \code{merge} indicate agglomerations
%    of singletons, and positive entries indicate agglomerations
%    of non-singletons.}
%
%  \item{height}{a set of \eqn{n-1} real values (non-decreasing for
%    ultrametric trees).
%    The clustering \emph{height}: that is, the value of
%    the criterion associated with the clustering
%    \code{method} for the particular agglomeration.}
%
%  \item{order}{a vector giving the permutation of the original
%    observations suitable for plotting, in the sense that a cluster
%    plot using this ordering and matrix \code{merge} will not have
%    crossings of the branches.}
%
%  \item{labels}{labels for each of the objects being clustered.}
%
%  \item{call}{the call which produced the result.}
%
%  \item{method}{the cluster method that has been used.}
%
%  \item{dist.method}{the distance that has been used to create \code{d}
%    (only returned if the distance object has a \code{"method"}
%    attribute).}
%
%  There are \code{\link{print}}, \code{\link{plot}} and \code{identify}
%  (see \code{\link{identify.hclust}}) methods and the
%  \code{\link{rect.hclust}()} function for \code{hclust} objects.
%}
%\details{
%  This function performs a hierarchical cluster analysis
%  using a set of dissimilarities for the \eqn{n} objects being
%  clustered.  Initially, each object is assigned to its own
%  cluster and then the algorithm proceeds iteratively,
%  at each stage joining the two most similar clusters,
%  continuing until there is just a single cluster.
%  At each stage distances between clusters are recomputed
%  by the Lance--Williams dissimilarity update formula
%  according to the particular clustering method being used.
%
%  A number of different clustering methods are provided.  \emph{Ward's}
%  minimum variance method aims at finding compact, spherical clusters.
%  The \emph{complete linkage} method finds similar clusters. The
%  \emph{single linkage} method (which is closely related to the minimal
%  spanning tree) adopts a \sQuote{friends of friends} clustering
%  strategy.  The other methods can be regarded as aiming for clusters
%  with characteristics somewhere between the single and complete link
%  methods.  Note however, that methods \code{"median"} and
%  \code{"centroid"} are \emph{not} leading to a \emph{monotone distance}
%  measure, or equivalently the resulting dendrograms can have so called
%  \emph{inversions} or \emph{reversals} which are hard to interpret,
%  but note the trichotomies in Legendre and Legendre (2012).
%
%  Two different algorithms are found in the literature for Ward clustering.
%  The one used by option \code{"ward.D"} (equivalent to the only Ward
%  option \code{"ward"} in \R versions \eqn{\le}{<=} 3.0.3) \emph{does not} implement
%  Ward's (1963) clustering criterion, whereas option \code{"ward.D2"} implements
%  that criterion (Murtagh and Legendre 2014).  With the latter, the
%  dissimilarities are \emph{squared} before cluster updating.
%  Note that \code{\link[cluster]{agnes}(*, method="ward")} corresponds
%  to \code{hclust(*, "ward.D2")}.
%
%  If \code{members != NULL}, then \code{d} is taken to be a
%  dissimilarity matrix between clusters instead of dissimilarities
%  between singletons and \code{members} gives the number of observations
%  per cluster.  This way the hierarchical cluster algorithm can be
%  \sQuote{started in the middle of the dendrogram}, e.g., in order to
%  reconstruct the part of the tree above a cut (see examples).
%  Dissimilarities between clusters can be efficiently computed (i.e.,
%  without \code{hclust} itself) only for a limited number of
%  distance/linkage combinations, the simplest one being \emph{squared}
%  Euclidean distance and centroid linkage.  In this case the
%  dissimilarities between the clusters are the squared Euclidean
%  distances between cluster means.
%
%  In hierarchical cluster displays, a decision is needed at each merge to
%  specify which subtree should go on the left and which on the right.
%  Since, for \eqn{n} observations there are \eqn{n-1} merges,
%  there are \eqn{2^{(n-1)}} possible orderings for the leaves
%  in a cluster tree, or dendrogram.
%  The algorithm used in \code{hclust} is to order the subtree so that
%  the tighter cluster is on the left (the last, i.e., most recent,
%  merge of the left subtree is at a lower value than the last
%  merge of the right subtree).
%  Single observations are the tightest clusters possible,
%  and merges involving two observations place them in order by their
%  observation sequence number.
%}
%\note{
%  Method \code{"centroid"} is typically meant to be used with
%  \emph{squared} Euclidean distances.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole. (S version.)
%
%  Everitt, B. (1974).
%  \emph{Cluster Analysis}.
%  London: Heinemann Educ. Books.
%
%  Hartigan, J.A. (1975).
%  \emph{Clustering  Algorithms}.
%  New York: Wiley.
%
%  Sneath, P. H. A. and R. R. Sokal (1973).
%  \emph{Numerical Taxonomy}.
%  San Francisco: Freeman.
%
%  Anderberg, M. R. (1973).
%  \emph{Cluster Analysis for Applications}.
%  Academic Press: New York.
%
%  Gordon, A. D. (1999).
%  \emph{Classification}. Second Edition.
%  London: Chapman and Hall / CRC
%
%  Murtagh, F. (1985).
%  \dQuote{Multidimensional Clustering Algorithms}, in
%  \emph{COMPSTAT Lectures 4}.
%  Wuerzburg: Physica-Verlag
%  (for algorithmic details of algorithms used).
%
%  McQuitty, L.L. (1966).
%  Similarity Analysis by Reciprocal Pairs for Discrete and Continuous
%  Data.
%  \emph{Educational and Psychological Measurement}, \bold{26}, 825--831.
%
%  Legendre, P. and L. Legendre (2012).
%  \emph{Numerical Ecology},
%  3rd English ed. Amsterdam: Elsevier Science BV.
%
%  Murtagh, Fionn and Legendre, Pierre (2014).
%  Ward's hierarchical agglomerative clustering method: which algorithms
%  implement Ward's criterion?
%  \emph{Journal of Classification} \bold{31} (forthcoming).
%}
%\author{
%  The \code{hclust} function is based on Fortran code
%  contributed to STATLIB by F. Murtagh.
%}
%\seealso{
%  \code{\link{identify.hclust}}, \code{\link{rect.hclust}},
%  \code{\link{cutree}}, \code{\link{dendrogram}}, \code{\link{kmeans}}.
%
%  For the Lance--Williams formula and methods that apply it generally,
%  see \code{\link[cluster]{agnes}} from package \CRANpkg{cluster}.
%}
%\examples{
%require(graphics)
%
%### Example 1: Violent crime rates by US state
%
%hc <- hclust(dist(USArrests), "ave")
%plot(hc)
%plot(hc, hang = -1)
%
%## Do the same with centroid clustering and *squared* Euclidean distance,
%## cut the tree into ten clusters and reconstruct the upper part of the
%## tree from the cluster centers.
%hc <- hclust(dist(USArrests)^2, "cen")
%memb <- cutree(hc, k = 10)
%cent <- NULL
%for(k in 1:10){
%  cent <- rbind(cent, colMeans(USArrests[memb == k, , drop = FALSE]))
%}
%hc1 <- hclust(dist(cent)^2, method = "cen", members = table(memb))
%opar <- par(mfrow = c(1, 2))
%plot(hc,  labels = FALSE, hang = -1, main = "Original Tree")
%plot(hc1, labels = FALSE, hang = -1, main = "Re-start from 10 clusters")
%par(opar)
%
%### Example 2: Straight-line distances among 10 US cities
%##  Compare the results of algorithms "ward.D" and "ward.D2"
%
%data(UScitiesD)
%
%mds2 <- -cmdscale(UScitiesD)
%plot(mds2, type="n", axes=FALSE, ann=FALSE)
%text(mds2, labels=rownames(mds2), xpd = NA)
%
%hcity.D  <- hclust(UScitiesD, "ward.D") # "wrong"
%hcity.D2 <- hclust(UScitiesD, "ward.D2")
%opar <- par(mfrow = c(1, 2))
%plot(hcity.D,  hang=-1)
%plot(hcity.D2, hang=-1)
%par(opar)
%}
%\keyword{multivariate}
%\keyword{cluster}
%
%\encoding{UTF-8}
%
