% File src/library/stats/man/lsfit.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{lsfit}
\title{Find the Least Squares Fit}
\usage{
lsfit(x, y, wt = NULL, intercept = TRUE, tolerance = 1e-07,
      yname = NULL)
}
\alias{lsfit}%@%\alias{最少二乗当てはめの計算}
\arguments{
\item{x}{行がケースに列が変数に対応する行列．}
\item{y}{応答，もし複数の左辺値に当てはめたければ
  行列かもしれない．}
\item{wt}{重み付き最少二乗法の実行に対するオプションの重みベクトル．}
\item{intercept}{切片項を使うべきかどうか．}
\item{tolerance}{行列分解中で使われる許容度．}
\item{yname}{応答変数に使われるべき名前．}
}
\description{
モデル \deqn{\bold{Y} = \bold{X \beta} + \bold{\epsilon}}{y = X b + e}
中の \bold{\eqn{\beta}{b}} の最少二乗推定値が計算される．
}
\details{
もし重みが指定されると重み付き最少二乗法が実行され，
\emph{j} 番目のケースに与えられる重みは
\code{wt} 中の \emph{j} 番目の項目で与えられる．

もし観測値がどれかの列に欠損値を持てば，
解析が実行される前に観測値が除かれる．
これは多数の欠損値があれば極めて非効率的であり得る．

実装は複数の左辺値を許す
LINPACK のサブルーチンの修正を用いている．
}
\value{
次の名前付き成分を持つリスト：
\item{coef}{
  上で述べたモデル(\bold{\eqn{\beta}{b}})中の係数の最少二乗推定値．}
\item{residuals}{当てはめからの残差．}
\item{intercept}{切片項が当てはめられたかどうかを示す．}
\item{qr}{デザイン行列の QR 分解．}
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
普通より好ましい \code{\link{lm}}；
\code{\link{ls.print}}, \code{\link{ls.diag}}.
}
\examples{
\dontshow{utils::example("lm", echo = FALSE)}
##-- lm(.) の例と同じデータを使う：
lsD9 <- lsfit(x = unclass(gl(2, 10)), y = weight)
ls.print(lsD9)
}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/lsfit.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{lsfit}
%\title{Find the Least Squares Fit}
%\usage{
%lsfit(x, y, wt = NULL, intercept = TRUE, tolerance = 1e-07,
%      yname = NULL)
%}
%\alias{lsfit}
%\arguments{
%\item{x}{a matrix whose rows correspond to cases and whose columns
%  correspond to variables.}
%\item{y}{the responses, possibly a matrix if you want to fit multiple
%  left hand sides.}
%\item{wt}{an optional vector of weights for performing weighted least squares.}
%\item{intercept}{whether or not an intercept term should be used.}
%\item{tolerance}{the tolerance to be used in the matrix decomposition.}
%\item{yname}{names to be used for the response variables.}
%}
%\description{
%The least squares estimate of \bold{\eqn{\beta}{b}} in the model
%\deqn{\bold{Y} = \bold{X \beta} + \bold{\epsilon}}{y = X b + e}
%is found.
%}
%\details{
%If weights are specified then a weighted least squares is performed
%with the weight given to the \emph{j}th case specified by the \emph{j}th
%entry in \code{wt}.
%
%If any observation has a missing value in any field, that observation
%is removed before the analysis is carried out.
%This can be quite inefficient if there is a lot of missing data.
%
%The implementation is via a modification of the LINPACK subroutines
%which allow for multiple left-hand sides.
%}
%\value{
%A list with the following named components:
%\item{coef}{the least squares estimates of the coefficients in
%  the model (\bold{\eqn{\beta}{b}} as stated above).}
%\item{residuals}{residuals from the fit.}
%\item{intercept}{indicates whether an intercept was fitted.}
%\item{qr}{the QR decomposition of the design matrix.}
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%\code{\link{lm}} which usually is preferable;
%\code{\link{ls.print}}, \code{\link{ls.diag}}.
%}
%\examples{
%\dontshow{utils::example("lm", echo = FALSE)}
%##-- Using the same data as the lm(.) example:
%lsD9 <- lsfit(x = unclass(gl(2, 10)), y = weight)
%ls.print(lsD9)
%}
%\keyword{regression}
%
%\encoding{UTF-8}
%
