% File src/library/stats/man/mad.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{mad}
\title{Median Absolute Deviation}
\usage{
mad(x, center = median(x), constant = 1.4826, na.rm = FALSE,
    low = FALSE, high = FALSE)
}
\alias{mad}%@%\alias{メディアン絶対偏差(MAD)}
\arguments{
  \item{x}{数値ベクトル．}
  \item{center}{オプションで，中央：既定値はメディアン．}
  \item{constant}{スケール因子．}
  \item{na.rm}{もし \code{TRUE} なら \code{NA} は
    \code{x} から計算前に取り除かれる．}
  \item{low}{もし \code{TRUE} なら\sQuote{低メディアン}を計算する，
    つまり偶数の標本サイズに対しては二つのメディアンを平均せず，
    小さい方を取る．}
  \item{high}{もし \code{TRUE} なら\sQuote{高メディアン}を計算する，
    つまり偶数の標本サイズに対しては二つのメディアンの
    大きい方を取る．}
}
\description{
  メディアン絶対偏差を計算する，つまり
  メディアンからの絶対偏差の(低/高)メディアン．
  (既定で)漸近正規性による一致性因子で補正される．
}
\details{
  実際の計算された値は
  \code{constant * cMedian(abs(x - center))} で
  \code{center} の既定値は\cr
  \code{median(x)} で，
  \code{cMedian} は通常の\sQuote{低}又は\sQuote{高}メディアンである，
  上の \code{low} と \code{high} 引数の説明を見よ．

  既定では \code{constant = 1.4826} (近似的に
  \eqn{1/\Phi^{-1}(3/4)}{1/ \Phi^(-1)(3/4)} = \code{1/qnorm(3/4)})
  が一致性を保証する，つまり
  \eqn{X_i} が分布 \eqn{N(\mu, \sigma^2)} に従い
  \eqn{n} が大きければ
  \deqn{E[mad(X_1,\dots,X_n)] = \sigma}

  もし \code{na.rm} が \code{TRUE} ならば \code{NA} 値は
  計算がされる前に \code{x} から取り除かれる．
  もしこれをしなければ
  \code{x} 中の \code{NA} 値は \code{mad} に \code{NA}
  を返させる．
}
\seealso{
  簡単であるが頑健性が劣る \code{\link{IQR}}，
  \code{\link{median}}, \code{\link{var}}.
}
\examples{
mad(c(1:9))
print(mad(c(1:9),     constant = 1)) ==
      mad(c(1:8, 100), constant = 1)       # = 2 ; TRUE
x <- c(1,2,3,5,7,8)
sort(abs(x - median(x)))
c(mad(x, constant = 1),
  mad(x, constant = 1, low = TRUE),
  mad(x, constant = 1, high = TRUE))
}
\keyword{univar}
\keyword{robust}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/mad.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mad}
%\title{Median Absolute Deviation}
%\usage{
%mad(x, center = median(x), constant = 1.4826, na.rm = FALSE,
%    low = FALSE, high = FALSE)
%}
%\alias{mad}
%\arguments{
%  \item{x}{a numeric vector.}
%  \item{center}{Optionally, the centre: defaults to the median.}
%  \item{constant}{scale factor.}
%  \item{na.rm}{if \code{TRUE} then \code{NA} values are stripped
%    from \code{x} before computation takes place.}
%  \item{low}{if \code{TRUE}, compute the \sQuote{lo-median}, i.e., for even
%    sample size, do not average the two middle values, but take the
%    smaller one.}
%  \item{high}{if \code{TRUE}, compute the \sQuote{hi-median}, i.e., take the
%    larger of the two middle values for even sample size.}
%}
%\description{
%  Compute the median absolute deviation, i.e., the (lo-/hi-) median of
%  the absolute deviations from the median, and (by default) adjust by a
%  factor for asymptotically normal consistency.
%}
%\details{
%  The actual value calculated is \code{constant * cMedian(abs(x - center))}
%  with the default value of \code{center} being \code{median(x)}, and
%  \code{cMedian} being the usual, the \sQuote{low} or \sQuote{high} median, see
%  the arguments description for \code{low} and \code{high} above.
%
%  The default \code{constant = 1.4826} (approximately
%  \eqn{1/\Phi^{-1}(\frac 3 4)}{1/ \Phi^(-1)(3/4)} = \code{1/qnorm(3/4)})
%  ensures consistency, i.e.,
%  \deqn{E[mad(X_1,\dots,X_n)] = \sigma}
%  for \eqn{X_i} distributed as \eqn{N(\mu, \sigma^2)}
%  and large \eqn{n}.
%
%  If \code{na.rm} is \code{TRUE} then \code{NA}
%  values are stripped from \code{x} before computation takes place.
%  If this is not done then an \code{NA} value in
%  \code{x} will cause \code{mad} to return \code{NA}.
%}
%\seealso{
%  \code{\link{IQR}} which is simpler but less robust,
%  \code{\link{median}}, \code{\link{var}}.
%}
%\examples{
%mad(c(1:9))
%print(mad(c(1:9),     constant = 1)) ==
%      mad(c(1:8, 100), constant = 1)       # = 2 ; TRUE
%x <- c(1,2,3,5,7,8)
%sort(abs(x - median(x)))
%c(mad(x, constant = 1),
%  mad(x, constant = 1, low = TRUE),
%  mad(x, constant = 1, high = TRUE))
%}
%\keyword{univar}
%\keyword{robust}
%
%\encoding{UTF-8}
%
