% File src/library/stats/man/monthplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{monthplot}
\alias{monthplot}%@%\alias{時系列の季節副系列のプロット}
\alias{monthplot.default}
\alias{monthplot.ts}
\alias{monthplot.stl}
\alias{monthplot.StructTS}

\title{
Plot a Seasonal or other Subseries from a Time Series
}
\description{
  時系列からの季節(や他の)副系列をプロットする．
  各季節(又は他のカテゴリー)毎に時系列がプロットされる．
}
\usage{
monthplot(x, \dots)

\method{monthplot}{stl}(x, labels = NULL, ylab = choice, choice = "seasonal",
          \dots)

\method{monthplot}{StructTS}(x, labels = NULL, ylab = choice, choice = "sea", \dots)

\method{monthplot}{ts}(x, labels = NULL, times = time(x), phase = cycle(x),
             ylab = deparse(substitute(x)), \dots)

\method{monthplot}{default}(x, labels = 1L:12L,
          ylab = deparse(substitute(x)),
          times = seq_along(x),
          phase = (times - 1L)\%\%length(labels) + 1L, base = mean,
          axes = TRUE, type = c("l", "h"), box = TRUE,
          add = FALSE,
          col = par("col"), lty = par("lty"), lwd = par("lwd"),
          col.base = col, lty.base = lty, lwd.base = lwd, ...)
}
\arguments{
  \item{x}{時系列又は関連するオブジェクト．}
  \item{labels}{各\sQuote{季節}に対して使われるラベル．}
  \item{ylab}{y ラベル．}
  \item{times}{各観測値の時間．}
  \item{phase}{各\sQuote{季節}に対するインディケータ．}
  \item{base}{副系列に対する参照線に対して使われる関数．}
  \item{choice}{\code{stl} 又は \code{StructTS} オブジェクトのどの系列?}
  \item{\dots}{既定メソッドかグラフィカルパラメータに渡される引数．}
  \item{axes}{軸を描くべきか(もし \code{add = TRUE} なら無視される)?}
  \item{type}{プロットのタイプ．既定は点を線で結ぶ，そして
    \code{"h"} はヒストグラム風の垂直線．}
  \item{box}{囲みボックスを描くべきか(もし \code{add = TRUE} なら無視される)?}
  \item{add}{存在するプロットに単に付け加える．}
  \item{col, lty, lwd}{系列に対するグラフィカルパラメータ．}
  \item{col.base, lty.base, lwd.base}{参照線として
    使われる線分に対するグラフィックスパラメータ．}
}
\details{
  この関数は時系列から副系列を取り出しそれら全てをを一つの
  フレームにプロットする．
  \code{\link{ts}}, \code{\link{stl}} そして
  \code{\link{StructTS}} メソッドは内部的に記録された周波数と
  開始・終了時間をスケールと季節の設定に使う．
  既定メソッドは観測値が
  12毎のグループであることを仮定する(これは変更できるが)．

  もし \code{labels} が与えられず \code{phase} が与えられると，
  \code{labels} の既定値は
  \code{phase} のユニークな値である．
  もし双方が与えられると，
  \code{phase} 値は
  \code{labels} 配列の添字であると仮定される，つまり
  それらの範囲は 1 から \code{length(labels)} である．
}
\value{
  これらの関数は現在のグラフィカルウィンドに
  季節副系列をプロットするという副作用のために実行される．
}
\author{Duncan Murdoch}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{ts}}, \code{\link{stl}}, \code{\link{StructTS}}
}

\examples{
require(graphics)

## CO2 データ
fit <- stl(log(co2), s.window = 20, t.window = 20)
plot(fit)
op <- par(mfrow = c(2,2))
monthplot(co2, ylab = "data", cex.axis = 0.8)
monthplot(fit, choice = "seasonal", cex.axis = 0.8)
monthplot(fit, choice = "trend", cex.axis = 0.8)
monthplot(fit, choice = "remainder", type = "h", cex.axis = 0.8)
par(op)

## CO2 データ，四半期毎にグループ化
quarter <- (cycle(co2) - 1) \%/\% 3
monthplot(co2, phase = quarter)

## JohnsonJohnson も見よ
}
\keyword{ hplot }
\keyword{ ts }

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/monthplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{monthplot}
%\alias{monthplot}
%\alias{monthplot.default}
%\alias{monthplot.ts}
%\alias{monthplot.stl}
%\alias{monthplot.StructTS}
%
%\title{
%  Plot a Seasonal or other Subseries from a Time Series
%}
%\description{
%  These functions plot seasonal (or other) subseries of a time series.
%  For each season (or other category), a time series is plotted.
%}
%\usage{
%monthplot(x, \dots)
%
%\method{monthplot}{stl}(x, labels = NULL, ylab = choice, choice = "seasonal",
%          \dots)
%
%\method{monthplot}{StructTS}(x, labels = NULL, ylab = choice, choice = "sea", \dots)
%
%\method{monthplot}{ts}(x, labels = NULL, times = time(x), phase = cycle(x),
%             ylab = deparse(substitute(x)), \dots)
%
%\method{monthplot}{default}(x, labels = 1L:12L,
%          ylab = deparse(substitute(x)),
%          times = seq_along(x),
%          phase = (times - 1L)\%\%length(labels) + 1L, base = mean,
%          axes = TRUE, type = c("l", "h"), box = TRUE,
%          add = FALSE,
%          col = par("col"), lty = par("lty"), lwd = par("lwd"),
%          col.base = col, lty.base = lty, lwd.base = lwd, ...)
%}
%\arguments{
%  \item{x}{Time series or related object.}
%  \item{labels}{Labels to use for each \sQuote{season}.}
%  \item{ylab}{y label.}
%  \item{times}{Time of each observation.}
%  \item{phase}{Indicator for each \sQuote{season}.}
%  \item{base}{Function to use for reference line for subseries.}
%  \item{choice}{Which series of an \code{stl} or \code{StructTS} object?}
%  \item{\dots}{Arguments to be passed to the default method or
%    graphical parameters.}
%  \item{axes}{Should axes be drawn (ignored if \code{add = TRUE})?}
%  \item{type}{Type of plot.  The default is to join the points with
%    lines, and \code{"h"} is for histogram-like vertical lines.}
%  \item{box}{Should a box be drawn (ignored if \code{add = TRUE}?}
%  \item{add}{Should thus just add on an existing plot.}
%  \item{col, lty, lwd}{Graphics parameters for the series.}
%  \item{col.base, lty.base, lwd.base}{Graphics parameters for the
%    segments used for the reference lines.}
%}
%\details{
%  These functions extract subseries from a time series and plot them
%  all in one frame.  The \code{\link{ts}}, \code{\link{stl}}, and
%  \code{\link{StructTS}} methods use the internally recorded frequency and
%  start and finish times to set the scale and the seasons.  The default
%  method assumes observations come in groups of 12 (though this can be
%  changed).
%
%  If the \code{labels} are not given but the \code{phase} is given, then
%  the \code{labels} default to the unique values of the \code{phase}.  If
%  both are given, then the \code{phase} values are assumed to be indices
%  into the \code{labels} array, i.e., they should be in the range
%  from 1 to \code{length(labels)}.
%}
%\value{
%  These functions are executed for their side effect of
%  drawing a seasonal subseries plot on the current graphical
%  window.
%}
%\author{Duncan Murdoch}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{ts}}, \code{\link{stl}}, \code{\link{StructTS}}
%}
%
%\examples{
%require(graphics)
%
%## The CO2 data
%fit <- stl(log(co2), s.window = 20, t.window = 20)
%plot(fit)
%op <- par(mfrow = c(2,2))
%monthplot(co2, ylab = "data", cex.axis = 0.8)
%monthplot(fit, choice = "seasonal", cex.axis = 0.8)
%monthplot(fit, choice = "trend", cex.axis = 0.8)
%monthplot(fit, choice = "remainder", type = "h", cex.axis = 0.8)
%par(op)
%
%## The CO2 data, grouped quarterly
%quarter <- (cycle(co2) - 1) \%/\% 3
%monthplot(co2, phase = quarter)
%
%## see also JohnsonJohnson
%}
%\keyword{ hplot }
%\keyword{ ts }
%
%\encoding{UTF-8}
