% File src/library/stats/man/mood.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{mood.test}
\alias{mood.test}%@%\alias{スケールパラメータの差に関する Mood の二標本検定}
\alias{mood.test.default}
\alias{mood.test.formula}
\title{Mood Two-Sample Test of Scale}
\description{
  スケールパラメータの差に関する Mood の二標本検定を実行する．
}
\usage{
mood.test(x, \dots)

\method{mood.test}{default}(x, y,
          alternative = c("two.sided", "less", "greater"), \dots)

\method{mood.test}{formula}(formula, data, subset, na.action, \dots)
}
\arguments{
  \item{x, y}{データ値の数値ベクトル．}
  \item{alternative}{対立仮説を指示し，
    \code{"two.sided"} (既定), \code{"greater"} 又は
    \code{"less"} のどれかでなくてはならず，全てが短縮化出来る．}
  \item{formula}{
    形式 \code{lhs ~ rhs} の公式で，
    \code{lhs} はデータ値を与える数値変数で
    \code{rhs} は対応するグループを与える二水準の因子である．}
  \item{data}{オプションの行列かデータフレーム(又は類似物：
    \code{\link{model.frame}} を見よ)で
    公式 \code{formula} 中の変数を含む．既定では変数は
    \code{environment(formula)} から取られる．}
  \item{subset}{使われる観測値の部分集合を指定するオプションのベクトル．}
  \item{na.action}{
    データが \code{NA} を含む時何が起きるかを指示する関数．
    \code{getOption("na.action")} が既定．}
  \item{\dots}{メソッドに・から渡される追加引数．}
}
\details{
  基礎にあるモデルは二標本がそれぞれ
  \eqn{f(x-l)} と \eqn{f((x-l)/s)/s} から抽出されたという
  ものである．ここで \eqn{l} は共通の位置パラメータで
  \eqn{s} はスケールパラメータである．

  帰無仮説は \eqn{s = 1} である．

  この問題に対してはもっと有用な検定がある．

  タイのある場合は Mielke (1967) の定式化を用いた．
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{検定統計量の値．}
  \item{p.value}{検定の p 値．}
  \item{alternative}{対立仮説を記述する文字列．
    頭文字だけを指定すれば良い．}
  \item{method}{文字列 \code{"Mood two-sample test of scale"}．}
  \item{data.name}{データの名前を与える文字列．}
}
\references{
  William J. Conover (1971),
  \emph{Practical nonparametric statistics}.
  New York: John Wiley & Sons.
  Pages 234f.

  Paul W. Mielke, Jr. (1967),
  Note on some squared rank tests with existing ties.
  \emph{Technometrics}, \bold{9}/2, 312--314.
}
\seealso{
  分散の同質性のランクに基づく(ノンパラメトリック) k 標本検定に
  対しては \code{\link{fligner.test}}；
  スケールパラメータの差異に関する別のランクに基づく二標本検定に
  対しては \code{\link{ansari.test}}；
  分散の同質性に対するパラメトリックな検定に対しては
  \code{\link{var.test}} と \code{\link{bartlett.test}}．
}
\examples{
## Ansari-Bradley 検定に対するのと同じデータ：
## Hyland の対照血清による血清鉄分の同定
ramsay <- c(111, 107, 100, 99, 102, 106, 109, 108, 104, 99,
            101, 96, 97, 102, 107, 113, 116, 113, 110, 98)
jung.parekh <- c(107, 108, 106, 98, 105, 103, 110, 105, 104,
            100, 96, 108, 103, 104, 114, 114, 113, 108, 106, 99)
mood.test(ramsay, jung.parekh)
## これを ansari.test(ramsay, jung.parekh) と比較せよ
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/mood.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mood.test}
%\alias{mood.test}
%\alias{mood.test.default}
%\alias{mood.test.formula}
%\title{Mood Two-Sample Test of Scale}
%\description{
%  Performs Mood's two-sample test for a difference in scale parameters.
%}
%\usage{
%mood.test(x, \dots)
%
%\method{mood.test}{default}(x, y,
%          alternative = c("two.sided", "less", "greater"), \dots)
%
%\method{mood.test}{formula}(formula, data, subset, na.action, \dots)
%}
%\arguments{
%  \item{x, y}{numeric vectors of data values.}
%  \item{alternative}{indicates the alternative hypothesis and must be
%    one of \code{"two.sided"} (default), \code{"greater"} or
%    \code{"less"} all of which can be abbreviated.}
%  \item{formula}{a formula of the form \code{lhs ~ rhs} where \code{lhs}
%    is a numeric variable giving the data values and \code{rhs} a factor
%    with two levels giving the corresponding groups.}
%  \item{data}{an optional matrix or data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.}
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.  Defaults to
%    \code{getOption("na.action")}.}
%  \item{\dots}{further arguments to be passed to or from methods.}
%}
%\details{
%  The underlying model is that the two samples are drawn from
%  \eqn{f(x-l)} and \eqn{f((x-l)/s)/s}, respectively, where \eqn{l} is a
%  common location parameter and \eqn{s} is a scale parameter.
%
%  The null hypothesis is \eqn{s = 1}.
%
%  There are more useful tests for this problem.
%
%  In the case of ties, the formulation of Mielke (1967) is employed.
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of the test statistic.}
%  \item{p.value}{the p-value of the test.}
%  \item{alternative}{a character string describing the alternative
%    hypothesis.   You can specify just the initial letter.}
%  \item{method}{the character string \code{"Mood two-sample test of scale"}.}
%  \item{data.name}{a character string giving the names of the data.}
%}
%\references{
%  William J. Conover (1971),
%  \emph{Practical nonparametric statistics}.
%  New York: John Wiley & Sons.
%  Pages 234f.
%
%  Paul W. Mielke, Jr. (1967),
%  Note on some squared rank tests with existing ties.
%  \emph{Technometrics}, \bold{9}/2, 312--314.
%}
%\seealso{
%  \code{\link{fligner.test}} for a rank-based (nonparametric) k-sample
%  test for homogeneity of variances;
%  \code{\link{ansari.test}} for another rank-based two-sample test for a
%  difference in scale parameters;
%  \code{\link{var.test}} and \code{\link{bartlett.test}} for parametric
%  tests for the homogeneity in variance.
%}
%\examples{
%## Same data as for the Ansari-Bradley test:
%## Serum iron determination using Hyland control sera
%ramsay <- c(111, 107, 100, 99, 102, 106, 109, 108, 104, 99,
%            101, 96, 97, 102, 107, 113, 116, 113, 110, 98)
%jung.parekh <- c(107, 108, 106, 98, 105, 103, 110, 105, 104,
%            100, 96, 108, 103, 104, 114, 114, 113, 108, 106, 99)
%mood.test(ramsay, jung.parekh)
%## Compare this to ansari.test(ramsay, jung.parekh)
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
