% File src/library/stats/man/nlm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{nlm}
\alias{nlm}%@%\alias{非線形最小化}
\title{Non-Linear Minimization}
\concept{optimization}
\usage{
nlm(f, p, \dots, hessian = FALSE, typsize = rep(1, length(p)),
    fscale = 1, print.level = 0, ndigit = 12, gradtol = 1e-6,
    stepmax = max(1000 * sqrt(sum((p/typsize)^2)), 1000),
    steptol = 1e-6, iterlim = 100, check.analyticals = TRUE)
}
\description{
  この関数はニュートン法タイプのアルゴリズムを用いて
  関数 \code{f} の最小化を行う．詳細は参考文献を見よ．
}
\arguments{
  \item{f}{最小化される関数で，単一の数値を返す．
    これは最初の引数が長さ \code{p} のベクトルで，他の任意の引数は
    \code{\dots} 引数で指定される．

    もし関数が
    \code{gradient} という名前の属性，もしくは
    \code{gradient} と \code{hessian} 属性の双方を持てば，
    これらは更新パラメータの更新の計算に使われる．
    さもなければ数値微分が用いられる．
    \code{\link{deriv}} 関数は
    適当な \code{gradient} 属性を持つ関数を返し，オプションで
    \code{hessian} 属性を返す．}
  \item{p}{最小化に対する初期値．}
  \item{\dots}{
    \code{f} に渡される追加引数．}
  \item{hessian}{もし \code{TRUE} ならば，最小値におけるへッシアンが返される．}
  \item{typsize}{最小値における各パラメータのサイズの推定値．}
  \item{fscale}{
    最小値における \code{f} のサイズの推定値．}
  \item{print.level}{
    この引数は最小化の過程で示されるプリントのレベルを決める．
    既定値の \code{0} は何もプリントしないことを意味し，
    値 \code{1} は最初と最終の詳細のプリントを意味し，
    値 \code{2} は完全なトレース情報のプリントを意味する．}
  \item{ndigit}{
    関数 \code{f} 中の有効桁数．}
  \item{gradtol}{
    スケール化されたグラディエントがアルゴリズムを終了するのに
    十分ゼロに近いと見做せる許容度を与える正のスカラ．
    スケール化されたグラディエントは
    \code{p[i]} での相対的変化で割った \code{f} の各方向
    \code{p[i]} への相対的変化の目安である．}
  \item{stepmax}{最大の許容ステップ長を与える正のスカラ．
    \code{stepmax} は最適化関数が桁溢れするステップを防止するのに
    使われ，アルゴリズムがパラメータ空間の
    興味のある領域から外れるのを防ぎ，
    又はアルゴリズムの発散を防ぐ．
    \code{stepmax} はこれらの最初の二つを防ぐ程に十分小さく選ばれ
    なければならないが，予め予想される合理的なステップ
    よりも大きくあるべきである．}
  \item{steptol}{最少の許容相対ステップ長を与える正のスカラ．}
  \item{iterlim}{プログラムの終了までに実行される繰り返しの
    最大数を指定する正整数．}
  \item{check.analyticals}{
    解析的なグラディエントとへッシアンがもし提供されていれば，
    初期値で数値微分の値と比較すべきかどうかを指示する論理値スカラ．
    これは不正確に定式化されたグラディエントとへッシアンを検出するのに
    役立つ．}
}
\details{
  \code{\dots} の後の引数は正確にマッチされなければならないことを注意しよう．

  もしグラディエントかヘッシアンが提供されるが間違ったモードや長さに
  評価されれば，それは無視される．
  グラディエントが存在し適正チェックをパスしなければ
  へッシアンは評価もされない．

  オリジナルのコードで利用可能な三つの手法の内
  線形探索であるメソッド
  \dQuote{1} が用いられる．

  与えられる関数は常に有限
  (\code{NA} と \code{NaN} で無いことも含む)な値を返すべきである：
  関数値自体に関しては非有現値は
  警告と共に最大の可能な値に置き換えられる．
}
\value{
  次の成分を含むリスト：
  \item{minimum}{
    \code{f} の推定最小値．}
  \item{estimate}{
    \code{f} の最小値が得られた点．}
  \item{gradient}{
    \code{f} の推定最小値におけるグラディエント．}
  \item{hessian}{
    \code{f} の推定最小値におけるへッシアン(もし要求されれば)．}
  \item{code}{なぜ最適化過程が終了したかを指示する整数．
    \describe{
      \item{1:}{相対グラディエントがゼロに近い，現在の繰り返しが
        恐らく解．}
      \item{2:}{許容度範囲内の引き続く繰り返し，
        現在の繰り返しが恐らく解．}
      \item{3:}{最後の大局的ステップが
        \code{estimate} 以下の点の特定に失敗した．
	\code{estimate} が近似的な局所最小値か
	関数もしくは
	\code{steptol} が小さすぎる．}
      \item{4:}{繰り返しの限界を超えた．}
      \item{5:}{
	最大ステップサイズ \code{stepmax} が連続する5回超えた．
        関数が下に非有界か，ある方向に有限漸近値になったか，
	\code{stepmax} が小さすぎる．}
    }
  }
  \item{iterations}{実行された繰り返し数．}
}

\source{
  現在のコードは Saikat DebRoy と R Core team による．
  Richard H. Jones の Fortran コードの C 翻訳を用いた.
}
\references{
  Dennis, J. E. and Schnabel, R. B. (1983) \emph{Numerical Methods for
    Unconstrained Optimization and Nonlinear Equations.} Prentice-Hall,
  Englewood Cliffs, NJ.

  Schnabel, R. B., Koontz, J. E. and Weiss, B. E. (1985) A modular
  system of algorithms for unconstrained minimization.
  \emph{ACM Trans. Math. Software}, \bold{11}, 419--440.
}
\seealso{
  \code{\link{optim}} と \code{\link{nlminb}}.

  制約付き最適化は \code{\link{constrOptim}}，
  一次元最小化は \code{\link{optimize}} そして
  根を見つけるには \code{\link{uniroot}}．
  解析的な導関数を計算するには \code{\link{deriv}}．

  非線形回帰には \code{\link{nls}} の方が優れているかもしれない．
}
\examples{
f <- function(x) sum((x-1:length(x))^2)
nlm(f, c(10,10))
nlm(f, c(10,10), print.level = 2)
utils::str(nlm(f, c(5), hessian = TRUE))

f <- function(x, a) sum((x-a)^2)
nlm(f, c(10,10), a = c(3,5))
f <- function(x, a)
{
    res <- sum((x-a)^2)
    attr(res, "gradient") <- 2*(x-a)
    res
}
nlm(f, c(10,10), a = c(3,5))

## 導関数の使用を含むより多くの例．
\dontrun{demo(nlm)}
}
\keyword{nonlinear}
\keyword{optimize}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/nlm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{nlm}
%\alias{nlm}
%\title{Non-Linear Minimization}
%\concept{optimization}
%\usage{
%nlm(f, p, \dots, hessian = FALSE, typsize = rep(1, length(p)),
%    fscale = 1, print.level = 0, ndigit = 12, gradtol = 1e-6,
%    stepmax = max(1000 * sqrt(sum((p/typsize)^2)), 1000),
%    steptol = 1e-6, iterlim = 100, check.analyticals = TRUE)
%}
%\description{
%  This function carries out a minimization of the function \code{f}
%  using a Newton-type algorithm.  See the references for details.
%}
%\arguments{
%  \item{f}{the function to be minimized, returning a single numeric
%    value.  This should be a function with first argument a vector of
%    the length of \code{p} followed by any other arguments specified by
%    the \code{\dots} argument.
%
%    If the function value has an attribute called \code{gradient} or
%    both \code{gradient} and \code{hessian} attributes, these will be
%    used in the calculation of updated parameter values.  Otherwise,
%    numerical derivatives are used. \code{\link{deriv}} returns a
%    function with suitable \code{gradient} attribute and optionally a
%    \code{hessian} attribute.}
%  \item{p}{starting parameter values for the minimization.}
%  \item{\dots}{additional arguments to be passed to \code{f}.}
%  \item{hessian}{if \code{TRUE}, the hessian of \code{f}
%    at the minimum is returned.}
%  \item{typsize}{an estimate of the size of each parameter
%    at the minimum.}
%  \item{fscale}{an estimate of the size of \code{f} at the minimum.}
%  \item{print.level}{this argument determines the level of printing
%    which is done during the minimization process.  The default
%    value of \code{0} means that no printing occurs, a value of \code{1}
%    means that initial and final details are printed and a value
%    of 2 means that full tracing information is printed.}
%  \item{ndigit}{the number of significant digits in the function \code{f}.}
%  \item{gradtol}{a positive scalar giving the tolerance at which the
%    scaled gradient is considered close enough to zero to
%    terminate the algorithm.  The scaled gradient is a
%    measure of the relative change in \code{f} in each direction
%    \code{p[i]} divided by the relative change in \code{p[i]}.}
%  \item{stepmax}{a positive scalar which gives the maximum allowable
%    scaled step length.  \code{stepmax} is used to prevent steps which
%    would cause the optimization function to overflow, to prevent the
%    algorithm from leaving the area of interest in parameter space, or to
%    detect divergence in the algorithm. \code{stepmax} would be chosen
%    small enough to prevent the first two of these occurrences, but should
%    be larger than any anticipated reasonable step.}
%  \item{steptol}{A positive scalar providing the minimum allowable
%    relative step length.}
%  \item{iterlim}{a positive integer specifying the maximum number of
%    iterations to be performed before the program is terminated.}
%  \item{check.analyticals}{a logical scalar specifying whether the
%    analytic gradients and Hessians, if they are supplied, should be
%    checked against numerical derivatives at the initial parameter
%    values. This can help detect incorrectly formulated gradients or
%    Hessians.}
%}
%\details{
%  Note that arguments after \code{\dots} must be matched exactly.
%
%  If a gradient or hessian is supplied but evaluates to the wrong mode
%  or length, it will be ignored if \code{check.analyticals = TRUE} (the
%  default) with a warning.  The hessian is not even checked unless the
%  gradient is present and passes the sanity checks.
%
%  From the three methods available in the original source, we always use
%  method \dQuote{1} which is line search.
%
%  The functions supplied should always return finite (including not
%  \code{NA} and not \code{NaN}) values: for the function value itself
%  non-finite values are replaced by the maximum positive value with a warning.
%}
%\value{
%  A list containing the following components:
%  \item{minimum}{the value of the estimated minimum of \code{f}.}
%  \item{estimate}{the point at which the minimum value of
%    \code{f} is obtained.}
%  \item{gradient}{the gradient at the estimated minimum of \code{f}.}
%  \item{hessian}{the hessian at the estimated minimum of \code{f} (if
%    requested).}
%  \item{code}{an integer indicating why the optimization process terminated.
%    \describe{
%      \item{1:}{relative gradient is close to zero, current iterate is
%        probably solution.}
%      \item{2:}{successive iterates within tolerance, current iterate
%        is probably solution.}
%      \item{3:}{last global step failed to locate a point lower than
%        \code{estimate}.  Either \code{estimate} is an approximate local
%        minimum of the function or \code{steptol} is too small.}
%      \item{4:}{iteration limit exceeded.}
%      \item{5:}{maximum step size \code{stepmax} exceeded five consecutive
%        times.  Either the function is unbounded below,
%        becomes asymptotic to a finite value from above in
%        some direction or \code{stepmax} is too small.}
%    }
%  }
%  \item{iterations}{the number of iterations performed.}
%}
%
%\source{
%  The current code is by Saikat DebRoy and the R Core team, using a C
%  translation of Fortran code by Richard H. Jones.
%}
%\references{
%  Dennis, J. E. and Schnabel, R. B. (1983) \emph{Numerical Methods for
%    Unconstrained Optimization and Nonlinear Equations.} Prentice-Hall,
%  Englewood Cliffs, NJ.
%
%  Schnabel, R. B., Koontz, J. E. and Weiss, B. E. (1985) A modular
%  system of algorithms for unconstrained minimization.
%  \emph{ACM Trans. Math. Software}, \bold{11}, 419--440.
%}
%\seealso{
%  \code{\link{optim}} and \code{\link{nlminb}}.
%
%  \code{\link{constrOptim}} for constrained optimization,
%  \code{\link{optimize}} for one-dimensional
%  minimization and \code{\link{uniroot}} for root finding.
%  \code{\link{deriv}} to calculate analytical derivatives.
%
%  For nonlinear regression, \code{\link{nls}} may be better.
%}
%\examples{
%f <- function(x) sum((x-1:length(x))^2)
%nlm(f, c(10,10))
%nlm(f, c(10,10), print.level = 2)
%utils::str(nlm(f, c(5), hessian = TRUE))
%
%f <- function(x, a) sum((x-a)^2)
%nlm(f, c(10,10), a = c(3,5))
%f <- function(x, a)
%{
%    res <- sum((x-a)^2)
%    attr(res, "gradient") <- 2*(x-a)
%    res
%}
%nlm(f, c(10,10), a = c(3,5))
%
%## more examples, including the use of derivatives.
%\dontrun{demo(nlm)}
%}
%\keyword{nonlinear}
%\keyword{optimize}
%
%\encoding{UTF-8}
%
