% File src/library/stats/man/spec.ar.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{spec.ar}
\alias{spec.ar}%@%\alias{時系列のスペクトル密度の推定}
\title{Estimate Spectral Density of a Time Series from AR Fit}
\usage{
spec.ar(x, n.freq, order = NULL, plot = TRUE, na.action = na.fail,
        method = "yule-walker", \dots)
}
\arguments{
  \item{x}{一変量(多変量版は未移植)時系列又は
    \code{\link{ar}} による当てはめの結果．}
  \item{n.freq}{プロットされる点の数．}
  \item{order}{当てはめられる AR モデルの次数．もし省略されると次数は
    AIC で決められる．}
  \item{plot}{ペリオドグラムをプロットするか?}
  \item{na.action}{\code{NA} 値を扱う関数．}
  \item{method}{
    \code{\link{ar}} 当てはめに対するメソッド．}
  \item{\dots}{
    \code{\link{plot.spec}} に渡されるグラフィカルパラメータ．}
}
\description{
  \code{x} にARモデルを当てはめ(又は存在する当てはめを使い)そして
  当てはめモデルのスペクトル密度を計算する(そして既定ではプロットする)．
}
\value{
  クラス \code{"spec"} のオブジェクト．
  もし \code{plot} が真なら結果は不可視で返される．
}
\references{
  Thompson, D.J. (1990) Time series analysis of Holocene climate data.
  \emph{Phil. Trans. Roy. Soc. A} \bold{330}, 601--616.

  Venables, W.N. and Ripley, B.D. (2002) \emph{Modern Applied
    Statistics with S.} Fourth edition. Springer. (Especially
  page 402.)
}
\section{Warning}{
  例えば Thomson (1990) を始めとし，
  AR スペクトルは誤解を招くと強く反対するものがいる．
}

\seealso{\code{\link{ar}}, \code{\link{spectrum}}.}

\note{多変量ケースはまだ移植されていない．}

\examples{
require(graphics)

spec.ar(lh)

spec.ar(ldeaths)
spec.ar(ldeaths, method = "burg")

spec.ar(log(lynx))
spec.ar(log(lynx), method = "burg", add = TRUE, col = "purple")
spec.ar(log(lynx), method = "mle", add = TRUE, col = "forest green")
spec.ar(log(lynx), method = "ols", add = TRUE, col = "blue")
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/spec.ar.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{spec.ar}
%\alias{spec.ar}
%\title{Estimate Spectral Density of a Time Series from AR Fit}
%\usage{
%spec.ar(x, n.freq, order = NULL, plot = TRUE, na.action = na.fail,
%        method = "yule-walker", \dots)
%}
%\arguments{
%  \item{x}{A univariate (not yet:or multivariate) time series or the
%    result of a fit by \code{\link{ar}}.}
%  \item{n.freq}{The number of points at which to plot.}
%  \item{order}{The order of the AR model to be fitted.  If omitted,
%    the order is chosen by AIC.}
%  \item{plot}{Plot the periodogram?}
%  \item{na.action}{\code{NA} action function.}
%  \item{method}{\code{method} for \code{\link{ar}} fit.}
%  \item{\dots}{Graphical arguments passed to \code{\link{plot.spec}}.}
%}
%\description{
%  Fits an AR model to \code{x} (or uses the existing fit) and computes
%  (and by default plots) the spectral density of the fitted model.
%}
%\value{
%  An object of class \code{"spec"}.
%  The result is returned invisibly if \code{plot} is true.
%}
%\references{
%  Thompson, D.J. (1990) Time series analysis of Holocene climate data.
%  \emph{Phil. Trans. Roy. Soc. A} \bold{330}, 601--616.
%
%  Venables, W.N. and Ripley, B.D. (2002) \emph{Modern Applied
%    Statistics with S.} Fourth edition. Springer. (Especially
%  page 402.)
%}
%\section{Warning}{
%  Some authors, for example Thomson (1990), warn strongly
%  that AR spectra can be misleading.
%}
%
%\seealso{\code{\link{ar}}, \code{\link{spectrum}}.}
%
%\note{The multivariate case is not yet implemented.}
%
%\examples{
%require(graphics)
%
%spec.ar(lh)
%
%spec.ar(ldeaths)
%spec.ar(ldeaths, method = "burg")
%
%spec.ar(log(lynx))
%spec.ar(log(lynx), method = "burg", add = TRUE, col = "purple")
%spec.ar(log(lynx), method = "mle", add = TRUE, col = "forest green")
%spec.ar(log(lynx), method = "ols", add = TRUE, col = "blue")
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
