% File src/library/stats/man/summary.lm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{summary.lm}
\alias{summary.lm}%@%\alias{線形モデル当てはめの要約}
\alias{summary.mlm}% mlm is *not* mentioned at all
\alias{print.summary.lm}
\title{Summarizing Linear Model Fits}
\usage{
\method{summary}{lm}(object, correlation = FALSE, symbolic.cor = FALSE, \dots)

\method{print}{summary.lm}(x, digits = max(3, getOption("digits") - 3),
      symbolic.cor = x$symbolic.cor,
      signif.stars = getOption("show.signif.stars"), \dots)
}
\arguments{
  \item{object}{
    クラス \code{"lm"} のオブジェクトで，普通
    \code{\link{lm}} 呼び出しの結果．}
  \item{x}{
    クラス \code{"summary.lm"} のオブジェクトで，
    \code{summary.lm} 呼び出しの結果．}
  \item{correlation}{論理値：もし \code{TRUE} なら，
    推定パラメータの相関行列が返されプリントされる．}
  \item{digits}{プリントに使われる有効桁数．}
  \item{symbolic.cor}{論理値．もし \code{TRUE} なら相関を
    数値ではなくシンボリックに(\code{\link{symnum}} を見よ)プリントする．}
  \item{signif.stars}{論理値．もし \code{TRUE} なら，
    \sQuote{信頼星印}が各係数に対してプリントされる．}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
}
\description{
クラス \code{"lm"} に対する \code{summary} メソッド．
}
\details{
   \code{print.summary.lm} は
  係数，標準エラー等の整形をスマートにすべく試み，
  追加で
  もし \code{signif.stars} が \code{TRUE} なら\sQuote{信頼星印}
  を与える．

  別名化された係数は返り値オブジェクトからは除かれるが
  \code{print} メソッドにより保存される．

相関は二桁(又はシンボリックに)でプリントされる：
  実際の相関を見るには\cr
  \code{summary(object)$correlation} を直接プリントする．
}
\value{
  関数 \code{summary.lm} は
  \code{object} 中で与えられた当てはめ線形モデルの要約統計量
  のりストを  成分(リスト要素) \code{"call"} と \code{"terms"} を使い
  計算し返す，加えて次の成分を持つ
  \item{residuals}{\emph{重み付き}残差，通常の残差を
    呼び出し \code{lm} 中で指定された重みの平方根で再スケールする．}
  \item{coefficients}{
    \eqn{p \times 4}{p x 4} 行列で，
    推定係数，その標準エラー，
    t 統計量，そして対応する
    (両側) p 値の列を持つ．
    別名化された係数は除外される．}
  \item{aliased}{名前付き論理値でオリジナルの係数が別名化
    されているかどうかを示す．}
  \item{sigma}{ランダム誤差の推定分散の平方根
    \deqn{\hat\sigma^2 = \frac{1}{n-p}\sum_i{w_i R_i^2},}{\sigma^2 = 1/(n-p) Sum(w[i] R[i]^2),}
    ここで \eqn{R_i}{R[i]} は \eqn{i} 番目の残差 \code{residuals[i]}．}
  \item{df}{自由度を与える長さ3のベクトル
    \eqn{(p, n-p, p*)}，最初は
    非別名化係数の数，最後は係数の総数．}
  \item{fstatistic}{
    (非切片項を含むモデル用)
    F 統計量とその分子と分母の自由度の長さ3のベクトル．}
  \item{r.squared}{\eqn{R^2}，
    \sQuote{モデルで説明できる分散の割合}，
    \deqn{R^2 = 1 - \frac{\sum_i{R_i^2}}{\sum_i(y_i- y^*)^2},}{R^2 = 1 - Sum(R[i]^2) / Sum((y[i]- y*)^2),}
    ここで \eqn{y^*}{y*} は切片があれば \eqn{y_i}{y[i]} の平均で
    さもなければゼロ．}
  \item{adj.r.squared}{
    大きな \eqn{p} に対してペナルティーを与えた上の
    \sQuote{\emph{修正済み}} \eqn{R^2} 統計量．}
  \item{cov.unscaled}{
    (未スケール化の)
    \eqn{\hat\beta_j}{coef[j]}, \eqn{j=1, \dots, p} の
    \eqn{p \times p}{p x p} 共分散行列．}
  \item{correlation}{
    もし \code{correlation = TRUE} が指定されれば
    上の \code{cov.unscaled} に対応する相関行列．}
  \item{symbolic.cor}{(\code{correlation} が真の時だけ．)
    引数 \code{symbolic.cor} の値．}
  \item{na.action}{もしそこにあれば \code{object} から．}
}
\seealso{
  モデル当てはめ関数 \code{\link{lm}}, \code{\link{summary}}．

  関数 \code{\link{coef}} は標準エラー，t 統計量，そして
  p 値を持つ係数行列を取り出す．
}
\examples{
\dontshow{utils::example("lm", echo = FALSE)}
##-- lm(.) の例から続く：
coef(lm.D90)  # the bare coefficients
sld90 <- summary(lm.D90 <- lm(weight ~ group -1))  # 切片項を除外
sld90
coef(sld90)  # より多く

## *別名化* 係数を持つモデル：
lm.D9. <- lm(weight ~ group + I(group != "Ctl"))
Sm.D9. <- summary(lm.D9.)
Sm.D9. #  shows the NA NA NA NA  line
stopifnot(length(cc <- coef(lm.D9.)) == 3, is.na(cc[3]),
          dim(coef(Sm.D9.)) == c(2,4), Sm.D9.$df == c(2, 18, 3))
}
\keyword{regression}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/summary.lm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{summary.lm}
%\alias{summary.lm}
%\alias{summary.mlm}% mlm is *not* mentioned at all
%\alias{print.summary.lm}
%\title{Summarizing Linear Model Fits}
%\usage{
%\method{summary}{lm}(object, correlation = FALSE, symbolic.cor = FALSE, \dots)
%
%\method{print}{summary.lm}(x, digits = max(3, getOption("digits") - 3),
%      symbolic.cor = x$symbolic.cor,
%      signif.stars = getOption("show.signif.stars"), \dots)
%}
%\arguments{
%  \item{object}{an object of class \code{"lm"}, usually, a result of a
%    call to \code{\link{lm}}.}
%  \item{x}{an object of class \code{"summary.lm"}, usually, a result of a
%    call to \code{summary.lm}.}
%  \item{correlation}{logical; if \code{TRUE}, the correlation matrix of
%    the estimated parameters is returned and printed.}
%  \item{digits}{the number of significant digits to use when printing.}
%  \item{symbolic.cor}{logical. If \code{TRUE}, print the correlations in
%    a symbolic form (see \code{\link{symnum}}) rather than as numbers.}
%  \item{signif.stars}{logical. If \code{TRUE}, \sQuote{significance stars}
%    are printed for each coefficient.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\description{
%\code{summary} method for class \code{"lm"}.
%}
%\details{
%  \code{print.summary.lm} tries to be smart about formatting the
%  coefficients, standard errors, etc. and additionally gives
%  \sQuote{significance stars} if \code{signif.stars} is \code{TRUE}.
%
%  Aliased coefficients are omitted in the returned object but restored
%  by the \code{print} method.
%
%  Correlations are printed to two decimal places (or symbolically): to
%  see the actual correlations print \code{summary(object)$correlation}
%  directly.
%}
%\value{
%  The function \code{summary.lm} computes and returns a list of summary
%  statistics of the fitted linear model given in \code{object}, using
%  the components (list elements) \code{"call"} and \code{"terms"}
%  from its argument, plus
%  \item{residuals}{the \emph{weighted} residuals, the usual residuals
%    rescaled by the square root of the weights specified in the call to
%    \code{lm}.}
%  \item{coefficients}{a \eqn{p \times 4}{p x 4} matrix with columns for
%    the estimated coefficient, its standard error, t-statistic and
%    corresponding (two-sided) p-value.  Aliased coefficients are omitted.}
%  \item{aliased}{named logical vector showing if the original
%    coefficients are aliased.}
%  \item{sigma}{the square root of the estimated variance of the random
%    error
%    \deqn{\hat\sigma^2 = \frac{1}{n-p}\sum_i{w_i R_i^2},}{\sigma^2 = 1/(n-p) Sum(w[i] R[i]^2),}
%    where \eqn{R_i}{R[i]} is the \eqn{i}-th residual, \code{residuals[i]}.}
%  \item{df}{degrees of freedom, a 3-vector \eqn{(p, n-p, p*)}, the first
%    being the number of non-aliased coefficients, the last being the total
%    number of coefficients.}
%  \item{fstatistic}{(for models including non-intercept terms)
%    a 3-vector with the value of the F-statistic with
%    its numerator and denominator degrees of freedom.}
%  \item{r.squared}{\eqn{R^2}, the \sQuote{fraction of variance explained by
%    the model},
%    \deqn{R^2 = 1 - \frac{\sum_i{R_i^2}}{\sum_i(y_i- y^*)^2},}{R^2 = 1 - Sum(R[i]^2) / Sum((y[i]- y*)^2),}
%    where \eqn{y^*}{y*} is the mean of \eqn{y_i}{y[i]} if there is an
%    intercept and zero otherwise.}
%  \item{adj.r.squared}{the above \eqn{R^2} statistic
%    \sQuote{\emph{adjusted}}, penalizing for higher \eqn{p}.}
%  \item{cov.unscaled}{a \eqn{p \times p}{p x p} matrix of (unscaled)
%    covariances of the \eqn{\hat\beta_j}{coef[j]}, \eqn{j=1, \dots, p}.}
%  \item{correlation}{the correlation matrix corresponding to the above
%    \code{cov.unscaled}, if \code{correlation = TRUE} is specified.}
%  \item{symbolic.cor}{(only if \code{correlation} is true.)  The value
%    of the argument \code{symbolic.cor}.}
%  \item{na.action}{from \code{object}, if present there.}
%}
%\seealso{
%  The model fitting function \code{\link{lm}}, \code{\link{summary}}.
%
%  Function \code{\link{coef}} will extract the matrix of coefficients
%  with standard errors, t-statistics and p-values.
%}
%\examples{
%\dontshow{utils::example("lm", echo = FALSE)}
%##-- Continuing the  lm(.) example:
%coef(lm.D90)  # the bare coefficients
%sld90 <- summary(lm.D90 <- lm(weight ~ group -1))  # omitting intercept
%sld90
%coef(sld90)  # much more
%
%## model with *aliased* coefficient:
%lm.D9. <- lm(weight ~ group + I(group != "Ctl"))
%Sm.D9. <- summary(lm.D9.)
%Sm.D9. #  shows the NA NA NA NA  line
%stopifnot(length(cc <- coef(lm.D9.)) == 3, is.na(cc[3]),
%          dim(coef(Sm.D9.)) == c(2,4), Sm.D9.$df == c(2, 18, 3))
%}
%\keyword{regression}
%\keyword{models}
%
%\encoding{UTF-8}
%
