% File src/library/stats/man/supsmu.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{supsmu}
\alias{supsmu}%@%\alias{Friedman のスーパースムーザ―}
\title{Friedman's SuperSmoother}
\description{
  Smooth the (x, y) values by Friedman's \sQuote{super smoother}.
}
\usage{
supsmu(x, y, wt, span = "cv", periodic = FALSE, bass = 0)
}
\arguments{
  \item{x}{平滑化のための x 値．}
  \item{y}{平滑化のための y 値．}
  \item{wt}{ケースの重み，既定では全て等しい．}
  \item{span}{ランニング直線平滑化のスパン中の観測値の割合，
    又はこれを leave-one-out クロスバリデーションで選ぶ \code{"cv"}．}
  \item{periodic}{もし \code{TRUE} なら，x 値は
    \code{[0, 1]} 中にあり周期が 1 と仮定される．}
  \item{bass}{当てはめ曲線の滑らかさを制御する．
    10 までの値は平滑度の増加を意味する．}
}
\details{
  \code{supsmu} は直線に対して三つのスパンから選ぶランニング直線平滑化
  である．ランニング直線平滑化は対称で，
  予測値の両側に \code{k/2} 個のデータ値を持ち，
  \code{k} の値は \code{0.5 * n}, \code{0.2 * n} そして \code{0.05 * n} で，
  ここで \code{n} はデータ点の値である．
  もし \code{span} が指定されると，
  スパン \code{span * n} の単一平滑化が使われる．

  三つの平滑化の最良のものが各予測ごとにクロスバリデーションで
  選ばれる．最良のスパンはそれからランニング直線平滑化で平滑化
  され最終的な予測値は線形補間で選ばれる．


  FORTRAN コードは次のように述べている：
  \dQuote{少数の標本(\code{n < 40})又はもし x 値で近い観測値の間に
  相当の相関があれば，予め指定された固定スパン平滑化
  (\code{span > 0}) を使うべきである．合理的なスパン値は 0.2 から 0.4
  である．}

  Cases with non-finite values of
  \code{x}, \code{y} 又は \code{wt} の有限でない値を持つケースは
  警告と共に捨て去られる．
}
\value{
  次の成分を持つリスト
  \item{x}{重複点を除いた増加順の入力値．}
  \item{y}{当てはめ曲線上の対応 y 値．}
}
\references{
  Friedman, J. H. (1984)
  SMART User's Guide.
  Laboratory for Computational Statistics, Stanford University Technical
  Report No.\sspace{}1.

  Friedman, J. H. (1984)
  A variable span scatterplot smoother.
  Laboratory for Computational Statistics, Stanford University Technical
  Report No.\sspace{}5.
}
\seealso{\code{\link{ppr}}}

\examples{
require(graphics)

with(cars, {
    plot(speed, dist)
    lines(supsmu(speed, dist))
    lines(supsmu(speed, dist, bass = 7), lty = 2)
    })
}
\keyword{smooth}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/supsmu.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{supsmu}
%\alias{supsmu}
%\title{Friedman's SuperSmoother}
%\description{
%  Smooth the (x, y) values by Friedman's \sQuote{super smoother}.
%}
%\usage{
%supsmu(x, y, wt, span = "cv", periodic = FALSE, bass = 0)
%}
%\arguments{
%  \item{x}{x values for smoothing}
%  \item{y}{y values for smoothing}
%  \item{wt}{case weights, by default all equal}
%  \item{span}{the fraction of the observations in the span of the running
%    lines smoother, or \code{"cv"} to choose this by leave-one-out
%    cross-validation.}
%  \item{periodic}{if \code{TRUE}, the x values are assumed to be in
%    \code{[0, 1]} and of period 1.}
%  \item{bass}{controls the smoothness of the fitted curve. Values of up
%    to 10 indicate increasing smoothness.}
%}
%\details{
%  \code{supsmu} is a running lines smoother which chooses between three
%  spans for the lines. The running lines smoothers are symmetric, with
%  \code{k/2} data points each side of the predicted point, and values of
%  \code{k} as \code{0.5 * n}, \code{0.2 * n} and \code{0.05 * n}, where
%  \code{n} is the number of data points.  If \code{span} is specified,
%  a single smoother with span \code{span * n} is used.
%
%  The best of the three smoothers is chosen by cross-validation for each
%  prediction. The best spans are then smoothed by a running lines
%  smoother and the final prediction chosen by linear interpolation.
%
%  The FORTRAN code says: \dQuote{For small samples (\code{n < 40}) or if
%    there are substantial serial correlations between observations close
%    in x-value, then a pre-specified fixed span smoother (\code{span >
%      0}) should be used.  Reasonable span values are 0.2 to 0.4.}
%
%  Cases with non-finite values of \code{x}, \code{y} or \code{wt} are
%  dropped, with a warning.
%}
%\value{
%  A list with components
%  \item{x}{the input values in increasing order with duplicates removed.}
%  \item{y}{the corresponding y values on the fitted curve.}
%}
%\references{
%  Friedman, J. H. (1984)
%  SMART User's Guide.
%  Laboratory for Computational Statistics, Stanford University Technical
%  Report No.\sspace{}1.
%
%  Friedman, J. H. (1984)
%  A variable span scatterplot smoother.
%  Laboratory for Computational Statistics, Stanford University Technical
%  Report No.\sspace{}5.
%}
%\seealso{\code{\link{ppr}}}
%
%\examples{
%require(graphics)
%
%with(cars, {
%    plot(speed, dist)
%    lines(supsmu(speed, dist))
%    lines(supsmu(speed, dist, bass = 7), lty = 2)
%    })
%}
%\keyword{smooth}
%
%\encoding{UTF-8}
%
