% File src/library/stats/man/t.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{t.test}
\alias{t.test}%@%\alias{t 検定}
\alias{t.test.default}
\alias{t.test.formula}
\title{Student's t-Test}
\description{
  データのベクトルに一標本又は二標本 t 検定を実行．
}
\usage{
t.test(x, \dots)

\method{t.test}{default}(x, y = NULL,
       alternative = c("two.sided", "less", "greater"),
       mu = 0, paired = FALSE, var.equal = FALSE,
       conf.level = 0.95, \dots)

\method{t.test}{formula}(formula, data, subset, na.action, \dots)
}
\arguments{
  \item{x}{(空でない)データ値の数値ベクトル．}
  \item{y}{オプションの(空でない)データ値の数値ベクトル．}
  \item{alternative}{対立仮説を指示する文字列，
    \code{"two.sided"} (既定)，
    \code{"greater"} 又は \code{"less"} のどれかでなくてはならない．
    頭文字だけを指定すれば良い．}
  \item{mu}{真の平均(又は二標本検定なら平均の差)を指定する数値．}
  \item{paired}{対 t 検定を希望するかどうかを指示する論理値．}
  \item{var.equal}{
    二つの分散がひとしいとして扱うかどうかを指示する論理変数．
    もし \code{TRUE} なら分散の推定にプールされた分散が使われ，
    さもなければ
    Welch (又は Satterthwaite) の自由度の近似が使われる．}
  \item{conf.level}{区間の信頼水準．}
  \item{formula}{
    形式 \code{lhs ~ rhs} の公式で，ここで \code{lhs}
    はデータ値を与える数値変数で
    \code{rhs} は対応するグループを与える二つの因子である．}
  \item{data}{\code{formula} 中の変数を含む
    オプションの行列かデータフレーム(又は類似のもの：
    \code{\link{model.frame}} を見よ)．
    既定では変数は \code{environment(formula)} から取られる．}
  \item{subset}{
    使用される観測値の部分集合を指定するオプションのベクトル．}
   \item{na.action}{
    データが \code{NA} を含んでいる時何が起きるべきかを指示する関数．
    既定では \code{getOption("na.action")}．}
  \item{\dots}{メソッドに・から渡される追加引数．}
}
\details{
  公式インタフェイスは二標本検定だけに使える．

  \code{alternative = "greater"} は \code{x} が
  \code{y} よりも大きな平均を持つという対立仮説である．

  もし \code{paired} が \code{TRUE} なら，\code{x} と \code{y} は
  共に指定されなければならず，同じ長さでなければならない．
  欠損値は黙って取り除かれる(もし \code{paired} が \code{TRUE} なら
  対で)．もし
  \code{var.equal} が \code{TRUE} ならば分散のプール化推定値が
  使われる．
  既定では，もし \code{var.equal} が \code{FALSE}
  ならば分散は両方のグループで個別に推定され，
  Welch の自由度補正が使われる．

  もし入力データが実効的に定数であれば(二つの平均の大きい方と比べて)
  エラーになる．
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{t 統計量の値．}
  \item{parameter}{t 統計量の自由度．}
  \item{p.value}{検定の p 値．}
  \item{conf.int}{指定された対立仮説に適当な平均の信頼区間．}
  \item{estimate}{
   一標本か二標本かに応じた平均の推定値か平均の差の推定値．}
  \item{null.value}{
   一標本か二標本かに応じた平均か平均の差の帰無仮説値．}
  \item{alternative}{対立仮説を記述する文字列．}
  \item{method}{どのタイプの t 検定が行われたかを指示する文字列．}
  \item{data.name}{データの名前を与える文字列．}
}
\seealso{
  \code{\link{prop.test}}
}
\examples{
require(graphics)

t.test(1:10, y = c(7:20))      # P = .00001855
t.test(1:10, y = c(7:20, 200)) # P = .1245    -- 最早有意ではない

## 古典的な例：Student の睡眠データ
plot(extra ~ group, data = sleep)
## 伝統的なインタフェイス
with(sleep, t.test(extra[group == 1], extra[group == 2]))
## 公式インタフェイス
t.test(extra ~ group, data = sleep)
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/t.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{t.test}
%\alias{t.test}
%\alias{t.test.default}
%\alias{t.test.formula}
%\title{Student's t-Test}
%\description{
%  Performs one and two sample t-tests on vectors of data.
%}
%\usage{
%t.test(x, \dots)
%
%\method{t.test}{default}(x, y = NULL,
%       alternative = c("two.sided", "less", "greater"),
%       mu = 0, paired = FALSE, var.equal = FALSE,
%       conf.level = 0.95, \dots)
%
%\method{t.test}{formula}(formula, data, subset, na.action, \dots)
%}
%\arguments{
%  \item{x}{a (non-empty) numeric vector of data values.}
%  \item{y}{an optional (non-empty) numeric vector of data values.}
%  \item{alternative}{a character string specifying the alternative
%    hypothesis, must be one of \code{"two.sided"} (default),
%    \code{"greater"} or \code{"less"}.  You can specify just the initial
%    letter.}
%  \item{mu}{a number indicating the true value of the mean (or
%    difference in means if you are performing a two sample test).}
%  \item{paired}{a logical indicating whether you want a paired
%    t-test.}
%  \item{var.equal}{a logical variable indicating whether to treat the
%    two variances as being equal. If \code{TRUE} then the pooled
%    variance is used to estimate the variance otherwise the Welch
%    (or Satterthwaite) approximation to the degrees of freedom is used.}
%  \item{conf.level}{confidence level of the interval.}
%  \item{formula}{a formula of the form \code{lhs ~ rhs} where \code{lhs}
%    is a numeric variable giving the data values and \code{rhs} a factor
%    with two levels giving the corresponding groups.}
%  \item{data}{an optional matrix or data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.}
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.  Defaults to
%    \code{getOption("na.action")}.}
%  \item{\dots}{further arguments to be passed to or from methods.}
%}
%\details{
%  The formula interface is only applicable for the 2-sample tests.
%
%  \code{alternative = "greater"} is the alternative that \code{x} has a
%  larger mean than \code{y}.
%
%  If \code{paired} is \code{TRUE} then both \code{x} and \code{y} must
%  be specified and they must be the same length.  Missing values are
%  silently removed (in pairs if \code{paired} is \code{TRUE}).  If
%  \code{var.equal} is \code{TRUE} then the pooled estimate of the
%  variance is used.  By default, if \code{var.equal} is \code{FALSE}
%  then the variance is estimated separately for both groups and the
%  Welch modification to the degrees of freedom is used.
%
%  If the input data are effectively constant (compared to the larger of the
%  two means) an error is generated.
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of the t-statistic.}
%  \item{parameter}{the degrees of freedom for the t-statistic.}
%  \item{p.value}{the p-value for the test.}
%  \item{conf.int}{a confidence interval for the mean appropriate to the
%    specified alternative hypothesis.}
%  \item{estimate}{the estimated mean or difference in means depending on
%    whether it was a one-sample test or a two-sample test.}
%  \item{null.value}{the specified hypothesized value of the mean or mean
%    difference depending on whether it was a one-sample test or a
%    two-sample test.}
%  \item{alternative}{a character string describing the alternative
%    hypothesis.}
%  \item{method}{a character string indicating what type of t-test was
%    performed.}
%  \item{data.name}{a character string giving the name(s) of the data.}
%}
%\seealso{
%  \code{\link{prop.test}}
%}
%\examples{
%require(graphics)
%
%t.test(1:10, y = c(7:20))      # P = .00001855
%t.test(1:10, y = c(7:20, 200)) # P = .1245    -- NOT significant anymore
%
%## Classical example: Student's sleep data
%plot(extra ~ group, data = sleep)
%## Traditional interface
%with(sleep, t.test(extra[group == 1], extra[group == 2]))
%## Formula interface
%t.test(extra ~ group, data = sleep)
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
