% File src/library/stats/man/wilcox.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{wilcox.test}
\alias{wilcox.test}%@%\alias{Wilcoxon のランク和と符号付きランク検定}
\alias{wilcox.test.default}%@%\alias{Mann-Whitney 検定}
\alias{wilcox.test.formula}
\concept{Mann-Whitney Test}
\title{Wilcoxon Rank Sum and Signed Rank Tests}
\description{
  データのベクトルに対して一標本又は二標本 Wilcoxon 検定を実行する；
  後者はまた \sQuote{Mann-Whitney} 検定としても知られている．
}
\usage{
wilcox.test(x, \dots)

\method{wilcox.test}{default}(x, y = NULL,
            alternative = c("two.sided", "less", "greater"),
            mu = 0, paired = FALSE, exact = NULL, correct = TRUE,
            conf.int = FALSE, conf.level = 0.95, \dots)

\method{wilcox.test}{formula}(formula, data, subset, na.action, \dots)
}
\arguments{
  \item{x}{データ値の数値ベクトル．
    有限で無い値(例えば無限値や欠損値)は除かれる．}
  \item{y}{オプションのデータ値の数値ベクトル：
    \code{x} と同様に有現でない値は捨てられる．}
  \item{alternative}{対立仮説を指示する文字列．
    \code{"two.sided"} (既定),
    \code{"greater"} 又は \code{"less"} のどれか一つ．
    頭文字だけを指定すれば良い．}
  \item{mu}{帰無仮説を作るのに使われるオプションパラメータ
    を指示する数．\sQuote{詳細}節を見よ．}
  \item{paired}{対検定を希望するかどうかを指示する論理値．}
  \item{exact}{正確な p 値を計算すべきかどうかを指示する論理値．}
  \item{correct}{
    p 値に対する正規近似で連続補正を適用するかどうかを
    指示する論理値．}
  \item{conf.int}{信頼区間を計算すべきかどうかを指示する論理値．}
  \item{conf.level}{区間の信頼水準．}
  \item{formula}{
    形式 \code{lhs ~ rhs} の公式で，ここで \code{lhs}
    はデータ値を与える数値変数で
    \code{rhs} は対応するグループを与える二水準の因子．}
  \item{data}{
    オプションの行列かデータフレーム(又は類似物：
    \code{\link{model.frame}} を見よ)で
    公式 \code{formula} 中の変数を含む．既定では変数は
    \code{environment(formula)} から取られる．}
  \item{subset}{使われる観測値の部分集合を指定するオプションのベクトル．}
  \item{na.action}{
    データが \code{NA} 値を含む時何が起きるべきかを指示する関数．
    既定では\cr
    \code{getOption("na.action")}．}
  \item{\dots}{メソッドに・から渡される追加引数．}
}
\details{
  公式によるインタフェイスは二標本検定だけに適用できる．

  もし \code{x} だけが与えられるか，またもし
  \code{x} と \code{y} の双方が与えられ
  \code{paired} が \code{TRUE} ならば，
  \code{x} (一標本ケース)か，
  \code{x - y} (対になった二標本ケース)の分布が
  \code{mu} に関して対称という帰無仮説の
  Wilcoxon の符号付きランク検定が実行される．

  さもなければ，もし \code{x} と \code{y} の双方が与えられ \code{paired}
  が \code{FALSE} ならば，Wilcoxon のランク和検定
  (Mann-Whitney 検定と同値：ノートを見よ)が実行される．
  この場合，帰無仮説は \code{x} と \code{y} の分布は位置シフト
  \code{mu} だけ違うというもので，対立仮説は
  それらがある他の位置シフト分異なる
  (そして片側対立仮説
  \code{"greater"} は \code{x} が \code{y} の右側にシフトされている)
  というものである

  既定(\code{exact} が指定されていない)では，もし
  標本が50個未満の有限値を含みタイが無ければ正確な p 値が
  計算される．さもなければ正規近似が使われる．

  オプションで(もし引数 \code{conf.int} が真なら)，
  擬似メディアン(一標本ケース)か，\code{x-y} の位置パラメータの
  差のノンパラメトリックな信頼区間と推定値が与えられる．
  (分布 \eqn{F} の擬似メディアンは
  \eqn{(u+v)/2} の分布のメディアンで，ここで \eqn{u} と \eqn{v} は
  独立でそれぞれ分布 \eqn{F} に従う．もし \eqn{F} が対称ならば，
  擬似メディアンとメディアンは一致する．
  Hollander & Wolfe (1973), page 34 を見よ．)
  二標本ケースでは位置パラメータの差に対する推定値は
  メディアンの差を推定
  \bold{せず}(よくある誤解)，むしろ
  \code{x} からの標本と \code{y} からの標本の差のメディアンを
  推定することを注意する.
  
  もし正確な p 値が利用できれば，正確な信頼区間が
  Bauer (1972) で説明されているアルゴリズムで得られ，
  Hodges-Lehmann 推定量が用いられる．
  さもなければ，正規近似に基づく信頼区間と点推定値が返される．
  これらは区間に対する連続性補正がされているが，
  推定値はされていない
  (補正は \code{alternative} に依存するため)．

  少数の標本では非常に高い信頼区間被覆確率を達成するのは不可能かもしれない．
  もしこれが起きれば警告が出，より低い被覆確率の区間が与えられる．
}
\value{
  A list with class
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{名前付きの検定統計量の値．}
  \item{parameter}{検定統計量の正確な分布のパラメータ．}
  \item{p.value}{検定の p 値．}
  \item{null.value}{位置パラメータ \code{mu}．}
  \item{alternative}{対立仮説を記述する文字列．}
  \item{method}{適用される検定のタイプ．}
  \item{data.name}{データの名前を与える文字列．}
  \item{conf.int}{位置パラメータに対する信頼区間．
    (引数  \code{conf.int = TRUE} の時だけ存在．)}
  \item{estimate}{位置パラメータの推定値．
    (引数  \code{conf.int = TRUE} の時だけ存在．)}
}
\note{
  文献では Wilcoxon のランク和検定と
  Mann-Whitney 検定の定義に関して合意が無い．
  二つの最も普通の定義は最小値を引き去ったりしなかったりする
  最初の標本のランクの和に対応する：
  \R は引き去り S-PLUS はしないので，サイズ \eqn{m} の最初の標本に対して
  \eqn{m(m+1)/2} だけ大きな値を与える．
  (Wilcoxon のオリジナルの論文は補正されないランク和を使っているが，
  引き続く表は最小値を引き去っているように見える．)

  \R の値は又
  \code{y[j]} が \code{x[i]} より大きくない全ての対
  \code{(x[i], y[j])} の数として計算することも出来，
  これは Mann-Whitney 検定の最も普通の定義である．
}
\section{警告}{
  もし \code{exact = TRUE} で一つの標本が大量
  (数千以上)の時は，この関数は大量のメモリーとスタックを使う
  (そしてスタックの限界を超えると
  \R をクラッシュさせるかもしれない)
}
\references{
  David F. Bauer (1972),
  Constructing confidence sets using rank statistics.
  \emph{Journal of the American Statistical Association}
  \bold{67}, 687--690.

  Myles Hollander and Douglas A. Wolfe (1973),
  \emph{Nonparametric Statistical Methods.}
  New York: John Wiley & Sons.
  Pages 27--33 (one-sample), 68--75 (two-sample).\cr
  Or second edition (1999).
}
\seealso{
  \code{\link{psignrank}}, \code{\link{pwilcox}}.

  タイの存在を含む正確，近似そしてモンテカルロ
  \emph{条件付き} p 値に対してはパッケージ \CRANpkg{coin} 中の
  \code{\link[coin:LocationTests]{wilcox_test}}．

  二つ以上の標本中の位置パラメータの同質性の検定に対しては
  \code{\link{kruskal.test}}；
  正規分布の仮定[又は大標本]下での別法に対しては
  \code{\link{t.test}}．
}
\examples{
require(graphics)
## 一標本検定．
## Hollander & Wolfe (1973), 29f.
## 不安と抑鬱状態が混じった患者9人の Hamilton 抑鬱スケール因子測定
## 治療開始(精神安定剤投与)後最初(x)と二度目の来院(y)
x <- c(1.83,  0.50,  1.62,  2.48, 1.68, 1.88, 1.55, 3.06, 1.30)
y <- c(0.878, 0.647, 0.598, 2.05, 1.06, 1.29, 1.06, 3.14, 1.29)
wilcox.test(x, y, paired = TRUE, alternative = "greater")
wilcox.test(y - x, alternative = "less")    # 同じ．
wilcox.test(y - x, alternative = "less",
            exact = FALSE, correct = FALSE) # H&W 大きな標本
                                            # 近似

## 二標本検定．
## Hollander & Wolfe (1973), 69f.
## 妊娠末期(x)と妊娠期間12から26週(y)の人間の胎盤膜の浸透性定数
## 妊娠末期は胎盤膜の浸透性がより高いかどうかに興味がある
x <- c(0.80, 0.83, 1.89, 1.04, 1.45, 1.38, 1.91, 1.64, 0.73, 1.46)
y <- c(1.15, 0.88, 0.90, 0.74, 1.21)
wilcox.test(x, y, alternative = "g")        # より高い
wilcox.test(x, y, alternative = "greater",
            exact = FALSE, correct = FALSE) # H&W 大きな標本
                                            # 近似

wilcox.test(rnorm(10), rnorm(10, 2), conf.int = TRUE)

## 公式インタフェイス
boxplot(Ozone ~ Month, data = airquality)
wilcox.test(Ozone ~ Month, data = airquality,
            subset = Month \%in\% c(5, 8))
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/wilcox.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{wilcox.test}
%\alias{wilcox.test}
%\alias{wilcox.test.default}
%\alias{wilcox.test.formula}
%\concept{Mann-Whitney Test}
%\title{Wilcoxon Rank Sum and Signed Rank Tests}
%\description{
%  Performs one- and two-sample Wilcoxon tests on vectors of data; the
%  latter is also known as \sQuote{Mann-Whitney} test.
%}
%\usage{
%wilcox.test(x, \dots)
%
%\method{wilcox.test}{default}(x, y = NULL,
%            alternative = c("two.sided", "less", "greater"),
%            mu = 0, paired = FALSE, exact = NULL, correct = TRUE,
%            conf.int = FALSE, conf.level = 0.95, \dots)
%
%\method{wilcox.test}{formula}(formula, data, subset, na.action, \dots)
%}
%\arguments{
%  \item{x}{numeric vector of data values.  Non-finite (e.g., infinite or
%    missing) values will be omitted.}
%  \item{y}{an optional numeric vector of data values: as with \code{x}
%    non-finite values will be omitted.}
%  \item{alternative}{a character string specifying the alternative
%    hypothesis, must be one of \code{"two.sided"} (default),
%    \code{"greater"} or \code{"less"}.  You can specify just the initial
%    letter.}
%  \item{mu}{a number specifying an optional parameter used to form the
%    null hypothesis.  See \sQuote{Details}.}
%  \item{paired}{a logical indicating whether you want a paired test.}
%  \item{exact}{a logical indicating whether an exact p-value
%    should be computed.}
%  \item{correct}{a logical indicating whether to apply continuity
%    correction in the normal approximation for the p-value.}
%  \item{conf.int}{a logical indicating whether a confidence interval
%    should be computed.}
%  \item{conf.level}{confidence level of the interval.}
%  \item{formula}{a formula of the form \code{lhs ~ rhs} where \code{lhs}
%    is a numeric variable giving the data values and \code{rhs} a factor
%    with two levels giving the corresponding groups.}
%  \item{data}{an optional matrix or data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.}
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.  Defaults to
%    \code{getOption("na.action")}.}
%  \item{\dots}{further arguments to be passed to or from methods.}
%}
%\details{
%  The formula interface is only applicable for the 2-sample tests.
%
%  If only \code{x} is given, or if both \code{x} and \code{y} are given
%  and \code{paired} is \code{TRUE}, a Wilcoxon signed rank test of the
%  null that the distribution of \code{x} (in the one sample case) or of
%  \code{x - y} (in the paired two sample case) is symmetric about
%  \code{mu} is performed.
%
%  Otherwise, if both \code{x} and \code{y} are given and \code{paired}
%  is \code{FALSE}, a Wilcoxon rank sum test (equivalent to the
%  Mann-Whitney test: see the Note) is carried out.  In this case, the
%  null hypothesis is that the distributions of \code{x} and \code{y}
%  differ by a location shift of \code{mu} and the alternative is that
%  they differ by some other location shift (and the one-sided
%  alternative \code{"greater"} is that \code{x} is shifted to the right
%  of \code{y}).
%
%  By default (if \code{exact} is not specified), an exact p-value
%  is computed if the samples contain less than 50 finite values and
%  there are no ties.  Otherwise, a normal approximation is used.
%
%  Optionally (if argument \code{conf.int} is true), a nonparametric
%  confidence interval and an estimator for the pseudomedian (one-sample
%  case) or for the difference of the location parameters \code{x-y} is
%  computed.  (The pseudomedian of a distribution \eqn{F} is the median
%  of the distribution of \eqn{(u+v)/2}, where \eqn{u} and \eqn{v} are
%  independent, each with distribution \eqn{F}.  If \eqn{F} is symmetric,
%  then the pseudomedian and median coincide.  See Hollander & Wolfe
%  (1973), page 34.)  Note that in the two-sample case the estimator for
%  the difference in location parameters does \bold{not} estimate the
%  difference in medians (a common misconception) but rather the median
%  of the difference between a sample from \code{x} and a sample from
%  \code{y}.
%
%  If exact p-values are available, an exact confidence interval is
%  obtained by the algorithm described in Bauer (1972), and the
%  Hodges-Lehmann estimator is employed.  Otherwise, the returned
%  confidence interval and point estimate are based on normal
%  approximations.  These are continuity-corrected for the interval but
%  \emph{not} the estimate (as the correction depends on the
%  \code{alternative}).
%
%  With small samples it may not be possible to achieve very high
%  confidence interval coverages. If this happens a warning will be given
%  and an interval with lower coverage will be substituted.
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of the test statistic with a name
%    describing it.}
%  \item{parameter}{the parameter(s) for the exact distribution of the
%    test statistic.}
%  \item{p.value}{the p-value for the test.}
%  \item{null.value}{the location parameter \code{mu}.}
%  \item{alternative}{a character string describing the alternative
%    hypothesis.}
%  \item{method}{the type of test applied.}
%  \item{data.name}{a character string giving the names of the data.}
%  \item{conf.int}{a confidence interval for the location parameter.
%    (Only present if argument \code{conf.int = TRUE}.)}
%  \item{estimate}{an estimate of the location parameter.
%    (Only present if argument \code{conf.int = TRUE}.)}
%}
%\note{
%  The literature is not unanimous about the definitions of the Wilcoxon
%  rank sum and Mann-Whitney tests.  The two most common definitions
%  correspond to the sum of the ranks of the first sample with the
%  minimum value subtracted or not: \R subtracts and S-PLUS does not,
%  giving a value which is larger by \eqn{m(m+1)/2} for a first sample
%  of size \eqn{m}.  (It seems Wilcoxon's original paper used the
%  unadjusted sum of the ranks but subsequent tables subtracted the
%  minimum.)
%
%  \R's value can also be computed as the number of all pairs
%  \code{(x[i], y[j])} for which \code{y[j]} is not greater than
%  \code{x[i]}, the most common definition of the Mann-Whitney test.
%}
%\section{Warning}{
%  This function can use large amounts of memory and stack (and even
%  crash \R if the stack limit is exceeded) if \code{exact = TRUE} and
%  one sample is large (several thousands or more).
%}
%\references{
%  David F. Bauer (1972),
%  Constructing confidence sets using rank statistics.
%  \emph{Journal of the American Statistical Association}
%  \bold{67}, 687--690.
%
%  Myles Hollander and Douglas A. Wolfe (1973),
%  \emph{Nonparametric Statistical Methods.}
%  New York: John Wiley & Sons.
%  Pages 27--33 (one-sample), 68--75 (two-sample).\cr
%  Or second edition (1999).
%}
%\seealso{
%  \code{\link{psignrank}}, \code{\link{pwilcox}}.
%
%  \code{\link[coin:LocationTests]{wilcox_test}} in package
%  \CRANpkg{coin} for exact, asymptotic and Monte Carlo
%  \emph{conditional} p-values, including in the presence of ties.
%
%  \code{\link{kruskal.test}} for testing homogeneity in location
%  parameters in the case of two or more samples;
%  \code{\link{t.test}} for an alternative under normality
%  assumptions [or large samples]
%}
%\examples{
%require(graphics)
%## One-sample test.
%## Hollander & Wolfe (1973), 29f.
%## Hamilton depression scale factor measurements in 9 patients with
%##  mixed anxiety and depression, taken at the first (x) and second
%##  (y) visit after initiation of a therapy (administration of a
%##  tranquilizer).
%x <- c(1.83,  0.50,  1.62,  2.48, 1.68, 1.88, 1.55, 3.06, 1.30)
%y <- c(0.878, 0.647, 0.598, 2.05, 1.06, 1.29, 1.06, 3.14, 1.29)
%wilcox.test(x, y, paired = TRUE, alternative = "greater")
%wilcox.test(y - x, alternative = "less")    # The same.
%wilcox.test(y - x, alternative = "less",
%            exact = FALSE, correct = FALSE) # H&W large sample
%                                            # approximation
%
%## Two-sample test.
%## Hollander & Wolfe (1973), 69f.
%## Permeability constants of the human chorioamnion (a placental
%##  membrane) at term (x) and between 12 to 26 weeks gestational
%##  age (y).  The alternative of interest is greater permeability
%##  of the human chorioamnion for the term pregnancy.
%x <- c(0.80, 0.83, 1.89, 1.04, 1.45, 1.38, 1.91, 1.64, 0.73, 1.46)
%y <- c(1.15, 0.88, 0.90, 0.74, 1.21)
%wilcox.test(x, y, alternative = "g")        # greater
%wilcox.test(x, y, alternative = "greater",
%            exact = FALSE, correct = FALSE) # H&W large sample
%                                            # approximation
%
%wilcox.test(rnorm(10), rnorm(10, 2), conf.int = TRUE)
%
%## Formula interface.
%boxplot(Ozone ~ Month, data = airquality)
%wilcox.test(Ozone ~ Month, data = airquality,
%            subset = Month \%in\% c(5, 8))
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
